@@ -17,7 +17,6 @@ import abc
 import keystone.conf
 from keystone import exception
 
-
 # NOTE(henry-nash): From the manager and above perspective, the domain_id
 # attribute of a role is nullable.  However, to ensure uniqueness in
 # multi-process configurations, it is better to still use a sql uniqueness
@@ -29,7 +28,7 @@ NULL_DOMAIN_ID = '<<null>>'
 CONF = keystone.conf.CONF
 
 
-class RoleDriverBase(object, metaclass=abc.ABCMeta):
+class RoleDriverBase(metaclass=abc.ABCMeta):
 
     def _get_list_limit(self):
         return CONF.role.list_limit or CONF.list_limit
