@@ -14,7 +14,7 @@
 
 """Keystone Caching Layer Implementation."""
 
-import os
+import secrets
 
 from dogpile.cache import region
 from dogpile.cache import util
@@ -23,11 +23,10 @@ from oslo_cache import core as cache
 from keystone.common.cache import _context_cache
 import keystone.conf
 
-
 CONF = keystone.conf.CONF
 
 
-class RegionInvalidationManager(object):
+class RegionInvalidationManager:
 
     REGION_KEY_PREFIX = '<<<region>>>:'
 
@@ -36,12 +35,13 @@ class RegionInvalidationManager(object):
         self._region_key = self.REGION_KEY_PREFIX + region_name
 
     def _generate_new_id(self):
-        return os.urandom(10)
+        return secrets.token_bytes(10)
 
     @property
     def region_id(self):
         return self._invalidation_region.get_or_create(
-            self._region_key, self._generate_new_id, expiration_time=-1)
+            self._region_key, self._generate_new_id, expiration_time=-1
+        )
 
     def invalidate_region(self):
         new_region_id = self._generate_new_id()
@@ -83,10 +83,11 @@ def key_mangler_factory(invalidation_manager, orig_key_mangler):
         # If it were there would be no way to get to it, making the cache
         # effectively useless.
         if not invalidation_manager.is_region_key(key):
-            key = '%s:%s' % (key, invalidation_manager.region_id)
+            key = f'{key}:{invalidation_manager.region_id}'
         if orig_key_mangler:
             key = orig_key_mangler(key)
         return key
+
     return key_mangler
 
 
@@ -127,11 +128,14 @@ def configure_cache(region=None):
         region.wrap(_context_cache._ResponseCacheProxy)
 
         region_manager = RegionInvalidationManager(
-            CACHE_INVALIDATION_REGION, region.name)
+            CACHE_INVALIDATION_REGION, region.name
+        )
         region.key_mangler = key_mangler_factory(
-            region_manager, region.key_mangler)
+            region_manager, region.key_mangler
+        )
         region.region_invalidator = DistributedInvalidationStrategy(
-            region_manager)
+            region_manager
+        )
 
 
 def _sha1_mangle_key(key):
@@ -161,7 +165,8 @@ def configure_invalidation_region():
     config_dict['expiration_time'] = None  # we don't want an expiration
 
     CACHE_INVALIDATION_REGION.configure_from_config(
-        config_dict, '%s.' % CONF.cache.config_prefix)
+        config_dict, '%s.' % CONF.cache.config_prefix
+    )
 
     # NOTE(breton): Wrap the cache invalidation region to avoid excessive
     # calls to memcached, which would result in poor performance.
@@ -179,5 +184,6 @@ def configure_invalidation_region():
 def get_memoization_decorator(group, expiration_group=None, region=None):
     if region is None:
         region = CACHE_REGION
-    return cache.get_memoization_decorator(CONF, region, group,
-                                           expiration_group=expiration_group)
+    return cache.get_memoization_decorator(
+        CONF, region, group, expiration_group=expiration_group
+    )
