@@ -31,12 +31,16 @@ def truncated(f):
     'truncated' boolean to 'true' in the hints limit dict.
 
     """
+
     @functools.wraps(f)
     def wrapper(self, hints, *args, **kwargs):
         if not hasattr(hints, 'limit'):
             raise exception.UnexpectedError(
-                _('Cannot truncate a driver call without hints list as '
-                  'first parameter after self '))
+                _(
+                    'Cannot truncate a driver call without hints list as '
+                    'first parameter after self '
+                )
+            )
 
         if hints.limit is None or hints.filters:
             return f(self, hints, *args, **kwargs)
@@ -55,10 +59,11 @@ def truncated(f):
         else:
             hints.set_limit(list_limit)
             return ref_list
+
     return wrapper
 
 
-class Hints(object):
+class Hints:
     """Encapsulate driver hints for listing entities.
 
     Hints are modifiers that affect the return of entities from a
@@ -86,7 +91,6 @@ class Hints(object):
                       ``contains``, ``startswith`` or ``endswith``
     * ``case_sensitive``: whether any comparison should take account of
                           case
-    * ``type``: will always be 'filter'
 
     """
 
@@ -95,21 +99,25 @@ class Hints(object):
         self.filters = list()
         self.cannot_match = False
 
-    def add_filter(self, name, value, comparator='equals',
-                   case_sensitive=False):
-        """Adds a filter to the filters list, which is publicly accessible."""
-        self.filters.append({'name': name, 'value': value,
-                             'comparator': comparator,
-                             'case_sensitive': case_sensitive,
-                             'type': 'filter'})
+    def add_filter(
+        self, name, value, comparator='equals', case_sensitive=False
+    ):
+        """Add a filter to the filters list, which is publicly accessible."""
+        self.filters.append(
+            {
+                'name': name,
+                'value': value,
+                'comparator': comparator,
+                'case_sensitive': case_sensitive,
+            }
+        )
 
     def get_exact_filter_by_name(self, name):
         """Return a filter key and value if exact filter exists for name."""
         for entry in self.filters:
-            if (entry['type'] == 'filter' and entry['name'] == name and
-                    entry['comparator'] == 'equals'):
+            if entry['name'] == name and entry['comparator'] == 'equals':
                 return entry
 
     def set_limit(self, limit, truncated=False):
         """Set a limit to indicate the list should be truncated."""
-        self.limit = {'limit': limit, 'type': 'limit', 'truncated': truncated}
+        self.limit = {'limit': limit, 'truncated': truncated}
