@@ -10,17 +10,16 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import copy
 import functools
 
 import flask
 from oslo_log import log
+from oslo_policy import opts
 from oslo_policy import policy as common_policy
 from oslo_utils import strutils
 
 from keystone.common import authorization
 from keystone.common import context
-from keystone.common import controller
 from keystone.common import policies
 from keystone.common import provider_api
 from keystone.common import utils
@@ -28,31 +27,86 @@ import keystone.conf
 from keystone import exception
 from keystone.i18n import _
 
-
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 PROVIDER_APIS = provider_api.ProviderAPIs
 
 
-_POSSIBLE_TARGET_ACTIONS = frozenset([
-    rule.name for
-    rule in policies.list_rules() if not rule.deprecated_for_removal
-])
+_POSSIBLE_TARGET_ACTIONS = frozenset(
+    [
+        rule.name
+        for rule in policies.list_rules()
+        if not rule.deprecated_for_removal
+    ]
+)
 _ENFORCEMENT_CHECK_ATTR = 'keystone:RBAC:enforcement_called'
 
 
-class RBACEnforcer(object):
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
+
+class RBACEnforcer:
     """Enforce RBAC on API calls."""
 
-    __shared_state__ = {}
+    __shared_state__: dict = {}
     __ENFORCER = None
     ACTION_STORE_ATTR = 'keystone:RBAC:action_name'
+    # FOR TESTS ONLY
+    suppress_deprecation_warnings = False
 
     def __init__(self):
         # NOTE(morgan): All Enforcer Instances use the same shared state;
         # BORG pattern.
         self.__dict__ = self.__shared_state__
 
+    def _check_deprecated_rule(self, action):
+        def _name_is_changing(rule):
+            deprecated_rule = rule.deprecated_rule
+            return (
+                deprecated_rule
+                and deprecated_rule.name != rule.name
+                and deprecated_rule.name in self._enforcer.file_rules
+            )
+
+        def _check_str_is_changing(rule):
+            deprecated_rule = rule.deprecated_rule
+            return (
+                deprecated_rule
+                and deprecated_rule.check_str != rule.check_str
+                and rule.name not in self._enforcer.file_rules
+            )
+
+        def _is_deprecated_for_removal(rule):
+            return (
+                rule.deprecated_for_removal
+                and rule.name in self._enforcer.file_rules
+            )
+
+        def _emit_warning():
+            if not self._enforcer._warning_emitted:
+                LOG.warning(
+                    "Deprecated policy rules found. Use "
+                    "oslopolicy-policy-generator and "
+                    "oslopolicy-policy-upgrade to detect and resolve "
+                    "deprecated policies in your configuration."
+                )
+                self._enforcer._warning_emitted = True
+
+        registered_rule = self._enforcer.registered_rules.get(action)
+
+        if not registered_rule:
+            return
+        if (
+            _name_is_changing(registered_rule)
+            or _check_str_is_changing(registered_rule)
+            or _is_deprecated_for_removal(registered_rule)
+        ):
+            _emit_warning()
+
     def _enforce(self, credentials, action, target, do_raise=True):
         """Verify that the action is valid on the target in this context.
 
@@ -76,25 +130,16 @@ class RBACEnforcer(object):
         # Add the exception arguments if asked to do a raise
         extra = {}
         if do_raise:
-            extra.update(exc=exception.ForbiddenAction, action=action,
-                         do_raise=do_raise)
-
-        # NOTE(lbragstad): If there is a token in the credentials dictionary,
-        # it's going to be an instance of a TokenModel. We'll need to convert
-        # it to the a token response or dictionary before passing it to
-        # oslo.policy for enforcement. This is because oslo.policy shouldn't
-        # know how to deal with an internal object only used within keystone.
-        if 'token' in credentials:
-            token_ref = controller.render_token_response_from_model(
-                credentials['token']
+            extra.update(
+                exc=exception.ForbiddenAction, action=action, do_raise=do_raise
             )
-            credentials_copy = copy.deepcopy(credentials)
-            credentials_copy['token'] = token_ref
-            credentials = credentials_copy
 
         try:
-            return self._enforcer.enforce(
-                rule=action, target=target, creds=credentials, **extra)
+            result = self._enforcer.enforce(
+                rule=action, target=target, creds=credentials, **extra
+            )
+            self._check_deprecated_rule(action)
+            return result
         except common_policy.InvalidScope:
             raise exception.ForbiddenAction(action=action)
 
@@ -107,20 +152,39 @@ class RBACEnforcer(object):
         # The raw oslo-policy enforcer object
         if self.__ENFORCER is None:
             self.__ENFORCER = common_policy.Enforcer(CONF)
+            # NOTE(cmurphy) when running in the keystone server, suppress
+            # deprecation warnings for individual policy rules. Instead, we log
+            # a single notification at enforcement time indicating the
+            # oslo.policy tools the operator can use to detect and resolve
+            # deprecated policies. If there is no request context here, that
+            # means external tooling such as the oslo.policy tools are running
+            # this code, in which case we do want the full deprecation warnings
+            # emitted for individual polcy rules.
+            if flask.has_request_context():
+                self.__ENFORCER.suppress_deprecation_warnings = True
+            # NOTE(cmurphy) Tests may explicitly disable these warnings to
+            # prevent an explosion of test logs
+            if self.suppress_deprecation_warnings:
+                self.__ENFORCER.suppress_deprecation_warnings = True
             self.register_rules(self.__ENFORCER)
+            self.__ENFORCER._warning_emitted = False
         return self.__ENFORCER
 
     @staticmethod
     def _extract_filter_values(filters):
         """Extract filter data from query params for RBAC enforcement."""
         filters = filters or []
-        target = {i: flask.request.args[i] for
-                  i in filters if i in flask.request.args}
+        target = {
+            i: flask.request.args[i]
+            for i in filters
+            if i in flask.request.args
+        }
         if target:
             if LOG.logger.getEffectiveLevel() <= log.DEBUG:
                 LOG.debug(
                     'RBAC: Adding query filter params (%s)',
-                    ', '.join(['%s=%s' % (k, v) for k, v in target.items()]))
+                    ', '.join([f'{k}={v}' for k, v in target.items()]),
+                )
         return target
 
     @staticmethod
@@ -135,14 +199,19 @@ class RBACEnforcer(object):
         :rtype: dict
         """
         ret_dict = {}
-        if ((member_target is not None and member_target_type is None) or
-                (member_target is None and member_target_type is not None)):
-            LOG.warning('RBAC: Unknown target type or target reference. '
-                        'Rejecting as unauthorized. '
-                        '(member_target_type=%(target_type)r, '
-                        'member_target=%(target_ref)r)',
-                        {'target_type': member_target_type,
-                         'target_ref': member_target})
+        if (member_target is not None and member_target_type is None) or (
+            member_target is None and member_target_type is not None
+        ):
+            LOG.warning(
+                'RBAC: Unknown target type or target reference. '
+                'Rejecting as unauthorized. '
+                '(member_target_type=%(target_type)r, '
+                'member_target=%(target_ref)r)',
+                {
+                    'target_type': member_target_type,
+                    'target_ref': member_target,
+                },
+            )
             # Fast exit.
             return ret_dict
 
@@ -160,10 +229,18 @@ class RBACEnforcer(object):
                 # should be more protection against something wonky
                 # here.
                 resource = flask.current_app.view_functions[
-                    flask.request.endpoint].view_class
-                member_name = getattr(resource, 'member_name', None)
-                func = getattr(
-                    resource, 'get_member_from_driver', None)
+                    flask.request.endpoint
+                ].view_class
+                try:
+                    member_name = getattr(resource, 'member_key', None)
+                except ValueError:
+                    # NOTE(morgan): In the case that the ResourceBase keystone
+                    # class is used, we raise a value error when member_key
+                    # has not been set on the class. This is perfectly
+                    # normal and acceptable. Set member_name to None as though
+                    # it wasn't set.
+                    member_name = None
+                func = getattr(resource, 'get_member_from_driver', None)
                 if member_name is not None and callable(func):
                     key = '%s_id' % member_name
                     if key in (flask.request.view_args or {}):
@@ -177,9 +254,8 @@ class RBACEnforcer(object):
                         # TODO(morgan): add (future) support for passing class
                         # instantiation args.
                         ret_dict['target'] = {
-                            member_name: func(
-                                resource(),
-                                flask.request.view_args[key])[member_name]}
+                            member_name: func(flask.request.view_args[key])
+                        }
         return ret_dict
 
     @staticmethod
@@ -197,21 +273,25 @@ class RBACEnforcer(object):
         # of the auth paths.
         target = 'token'
         subject_token = flask.request.headers.get('X-Subject-Token')
+        access_rules_support = flask.request.headers.get(
+            authorization.ACCESS_RULES_HEADER
+        )
         if subject_token is not None:
-            allow_expired = (strutils.bool_from_string(
-                flask.request.args.get('allow_expired', False),
-                default=False))
+            allow_expired = strutils.bool_from_string(
+                flask.request.args.get('allow_expired', False), default=False
+            )
             if allow_expired:
                 window_seconds = CONF.token.allow_expired_window
             token = PROVIDER_APIS.token_provider_api.validate_token(
                 subject_token,
-                window_seconds=window_seconds
+                window_seconds=window_seconds,
+                access_rules_support=access_rules_support,
             )
             # TODO(morgan): Expand extracted data from the subject token.
             ret_dict[target] = {}
             ret_dict[target]['user_id'] = token.user_id
             try:
-                user_domain_id = token.user_domain_id
+                user_domain_id = token.user['domain_id']
             except exception.UnexpectedError:
                 user_domain_id = None
             if user_domain_id:
@@ -228,15 +308,21 @@ class RBACEnforcer(object):
     def _assert_is_authenticated(cls):
         ctx = cls._get_oslo_req_context()
         if ctx is None:
-            LOG.warning('RBAC: Error reading the request context generated by '
-                        'the Auth Middleware (there is no context). Rejecting '
-                        'request as unauthorized.')
+            LOG.warning(
+                'RBAC: Error reading the request context generated by '
+                'the Auth Middleware (there is no context). Rejecting '
+                'request as unauthorized.'
+            )
             raise exception.Unauthorized(
-                _('Internal error processing authentication and '
-                  'authorization.'))
+                _(
+                    'Internal error processing authentication and '
+                    'authorization.'
+                )
+            )
         if not ctx.authenticated:
             raise exception.Unauthorized(
-                _('auth_context did not decode anything useful'))
+                _('auth_context did not decode anything useful')
+            )
 
     @classmethod
     def _shared_admin_auth_token_set(cls):
@@ -244,9 +330,16 @@ class RBACEnforcer(object):
         return getattr(ctx, 'is_admin', False)
 
     @classmethod
-    def enforce_call(cls, enforcer=None, action=None, target_attr=None,
-                     member_target_type=None, member_target=None,
-                     filters=None):
+    def enforce_call(
+        cls,
+        enforcer=None,
+        action=None,
+        target_attr=None,
+        member_target_type=None,
+        member_target=None,
+        filters=None,
+        build_target=None,
+    ):
         """Enforce RBAC on the current request.
 
         This will do some legwork and then instantiate the Enforcer if an
@@ -277,12 +370,17 @@ class RBACEnforcer(object):
         :type member_target: dict
         :param filters: A variable number of optional string filters, these are
                         used to extract values from the query params. The
-                        filters are added to the reques data that is passed to
+                        filters are added to the request data that is passed to
                         the enforcer and may be used to determine policy
                         action. In practice these are mainly supplied in the
                         various "list" APIs and are un-used in the default
                         supplied policies.
         :type filters: iterable
+        :param build_target: A function to build the target for enforcement.
+                             This is explicitly done after authentication
+                             in order to not leak existance data before
+                             auth.
+        :type build_target: function
         """
         # NOTE(morgan) everything in the policy_dict may be used by the policy
         # DSL to action on RBAC and request information/response data.
@@ -293,11 +391,13 @@ class RBACEnforcer(object):
         # @policy_enforcer_action decorator was used.
         action = action or getattr(flask.g, cls.ACTION_STORE_ATTR, None)
         if action not in _POSSIBLE_TARGET_ACTIONS:
-            LOG.warning('RBAC: Unknown enforcement action name `%s`. '
-                        'Rejecting as Forbidden, this is a programming error '
-                        'and a bug should be filed with as much information '
-                        'about the request that caused this as possible.',
-                        action)
+            LOG.warning(
+                'RBAC: Unknown enforcement action name `%s`. '
+                'Rejecting as Forbidden, this is a programming error '
+                'and a bug should be filed with as much information '
+                'about the request that caused this as possible.',
+                action,
+            )
             # NOTE(morgan): While this is an internal error, a 500 is never
             # desirable, we have handled the case and the most appropriate
             # response here is to issue a 403 (FORBIDDEN) to any API calling
@@ -307,7 +407,9 @@ class RBACEnforcer(object):
             raise exception.Forbidden(
                 message=_(
                     'Internal RBAC enforcement error, invalid rule (action) '
-                    'name.'))
+                    'name.'
+                )
+            )
 
         # Mark flask.g as "enforce_call" has been called. This should occur
         # before anything except the "is this a valid action" check, ensuring
@@ -328,18 +430,56 @@ class RBACEnforcer(object):
         # The lowest priority values are set first and the highest priority
         # values are set last.
 
+        # Populate the input attributes (view args) directly to the policy
+        # dict. This is to allow the policy engine to have access to the
+        # view args for substitution. This is to mirror the old @protected
+        # mechanism and ensure current policy files continue to work as
+        # expected.
+        policy_dict.update(flask.request.view_args)
+
         # Get the Target Data Set.
-        if target_attr is None:
-            policy_dict.update(cls._extract_member_target_data(
-                member_target_type, member_target))
+        if target_attr is None and build_target is None:
+            try:
+                policy_dict.update(
+                    cls._extract_member_target_data(
+                        member_target_type, member_target
+                    )
+                )
+            except exception.NotFound:
+                # DEBUG LOG and bubble up the 404 error. This is expected
+                # behavior. This likely should be specific in each API. This
+                # should be revisited in the future and each API should make
+                # the explicit "existence" checks before enforcement.
+                LOG.debug(
+                    'Extracting inferred target data resulted in '
+                    '"NOT FOUND (404)".'
+                )
+                raise
+            except Exception as e:  # nosec
+                # NOTE(morgan): Errors should never bubble up at this point,
+                # if there is an error getting the target, log it and move
+                # on. Raise an explicit 403, we have failed policy checks.
+                LOG.warning(
+                    'Unable to extract inferred target data during '
+                    'enforcement'
+                )
+                LOG.debug(e, exc_info=True)
+                raise exception.ForbiddenAction(action=action)
 
             # Special Case, extract and add subject_token data.
             subj_token_target_data = cls._extract_subject_token_target_data()
             if subj_token_target_data:
                 policy_dict.setdefault('target', {}).update(
-                    subj_token_target_data)
+                    subj_token_target_data
+                )
         else:
-            policy_dict['target'] = target_attr
+            if target_attr and build_target:
+                raise ValueError(
+                    'Programming Error: A target_attr or '
+                    'build_target must be provided, but not both'
+                )
+
+            policy_dict['target'] = target_attr or build_target()
 
         # Pull the data from the submitted json body to generate
         # appropriate input/target attributes, we take an explicit copy here
@@ -350,46 +490,37 @@ class RBACEnforcer(object):
         # Generate the filter_attr dataset.
         policy_dict.update(cls._extract_filter_values(filters))
 
-        # Extract the cred data
-        creds = cls._extract_policy_check_credentials()
         flattened = utils.flatten_dict(policy_dict)
         if LOG.logger.getEffectiveLevel() <= log.DEBUG:
             # LOG the Args
             args_str = ', '.join(
-                ['%s=%s' % (k, v) for
-                 k, v in (flask.request.view_args or {}).items()])
+                [
+                    f'{k}={v}'
+                    for k, v in (flask.request.view_args or {}).items()
+                ]
+            )
             args_str = strutils.mask_password(args_str)
-            LOG.debug('RBAC: Authorizing `%(action)s(%(args)s)`',
-                      {'action': action, 'args': args_str})
-
-            # LOG the Cred Data
-            cred_str = ', '.join(
-                ['%s=%s' % (k, v) for k, v in creds.items()])
-            cred_str = strutils.mask_password(cred_str)
-            LOG.debug('RBAC: Policy Enforcement Cred Data '
-                      '`%(action)s creds(%(cred_str)s)`',
-                      {'action': action, 'cred_str': cred_str})
-
-            # Log the Target Data
-            target_str = ', '.join(
-                ['%s=%s' % (k, v) for k, v in flattened.items()])
-            target_str = strutils.mask_password(target_str)
-            LOG.debug('RBAC: Policy Enforcement Target Data '
-                      '`%(action)s => target(%(target_str)s)`',
-                      {'action': action, 'target_str': target_str})
+            LOG.debug(
+                'RBAC: Authorizing `%(action)s(%(args)s)`',
+                {'action': action, 'args': args_str},
+            )
 
+        ctxt = cls._get_oslo_req_context()
         # Instantiate the enforcer object if needed.
         enforcer_obj = enforcer or cls()
         enforcer_obj._enforce(
-            credentials=creds, action=action, target=flattened)
+            credentials=ctxt, action=action, target=flattened
+        )
         LOG.debug('RBAC: Authorization granted')
 
     @classmethod
     def policy_enforcer_action(cls, action):
         """Decorator to set policy enforcement action name."""
         if action not in _POSSIBLE_TARGET_ACTIONS:
-            raise ValueError('PROGRAMMING ERROR: Action must reference a '
-                             'valid Keystone policy enforcement name.')
+            raise ValueError(
+                'PROGRAMMING ERROR: Action must reference a '
+                'valid Keystone policy enforcement name.'
+            )
 
         def wrapper(f):
             @functools.wraps(f)
@@ -398,7 +529,9 @@ class RBACEnforcer(object):
                 # later.
                 setattr(flask.g, cls.ACTION_STORE_ATTR, action)
                 return f(*args, **kwargs)
+
             return inner
+
         return wrapper
 
     @staticmethod
