@@ -16,12 +16,10 @@ import re
 import jsonschema
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from keystone import exception
 from keystone.i18n import _
 
-
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
@@ -30,25 +28,30 @@ LOG = log.getLogger(__name__)
 def validate_password(password):
     pattern = CONF.security_compliance.password_regex
     if pattern:
-        if not isinstance(password, six.string_types):
+        if not isinstance(password, str):
             detail = _("Password must be a string type")
             raise exception.PasswordValidationError(detail=detail)
         try:
             if not re.match(pattern, password):
                 pattern_desc = (
-                    CONF.security_compliance.password_regex_description)
+                    CONF.security_compliance.password_regex_description
+                )
                 raise exception.PasswordRequirementsValidationError(
-                    detail=pattern_desc)
+                    detail=pattern_desc
+                )
         except re.error:
-            msg = ("Unable to validate password due to invalid regular "
-                   "expression - password_regex: ")
+            msg = (
+                "Unable to validate password due to invalid regular "
+                "expression - password_regex: %s"
+            )
             LOG.error(msg, pattern)
-            detail = _("Unable to validate password due to invalid "
-                       "configuration")
+            detail = _(
+                "Unable to validate password due to invalid configuration"
+            )
             raise exception.PasswordValidationError(detail=detail)
 
 
-class SchemaValidator(object):
+class SchemaValidator:
     """Resource reference validator class."""
 
     validator_org = jsonschema.Draft4Validator
@@ -62,8 +65,9 @@ class SchemaValidator(object):
         # didn't by default. See the Nova V3 validator for details on how this
         # is done.
         validators = {}
-        validator_cls = jsonschema.validators.extend(self.validator_org,
-                                                     validators)
+        validator_cls = jsonschema.validators.extend(
+            self.validator_org, validators
+        )
         fc = jsonschema.FormatChecker()
         self.validator = validator_cls(schema, format_checker=fc)
 
@@ -81,10 +85,10 @@ class SchemaValidator(object):
                 # too long, then we should build the masking in here so that
                 # we don't expose sensitive user information in the event it
                 # fails validation.
-                path = '/'.join(map(six.text_type, ex.path))
-                detail = _("Invalid input for field '%(path)s': "
-                           "%(message)s") % {'path': path,
-                                             'message': six.text_type(ex)}
+                path = '/'.join(map(str, ex.path))
+                detail = _(
+                    "Invalid input for field '%(path)s': %(message)s"
+                ) % {'path': path, 'message': str(ex)}
             else:
-                detail = six.text_type(ex)
+                detail = str(ex)
             raise exception.SchemaValidationError(detail=detail)
