@@ -17,8 +17,14 @@ package.
 """
 
 
-_DEFAULT_AUTH_METHODS = ['external', 'password', 'token', 'oauth1', 'mapped',
-                         'application_credential']
+_DEFAULT_AUTH_METHODS = [
+    'external',
+    'password',
+    'token',
+    'oauth1',
+    'mapped',
+    'application_credential',
+]
 
 _CERTFILE = '/etc/keystone/ssl/certs/signing_cert.pem'
 _KEYFILE = '/etc/keystone/ssl/private/signing_key.pem'
