@@ -14,17 +14,19 @@ from oslo_config import cfg
 
 from keystone.conf import utils
 
-
 driver = cfg.StrOpt(
     'driver',
     default='sql',
-    help=utils.fmt("""
+    help=utils.fmt(
+        """
 Entry point for the shadow users backend driver in the
 `keystone.identity.shadow_users` namespace. This driver is used for persisting
 local user references to externally-managed identities (via federation, LDAP,
 etc). Keystone only provides a `sql` driver, so there is no reason to change
 this option unless you are providing a custom entry point.
-"""))
+"""
+    ),
+)
 
 
 GROUP_NAME = __name__.split('.')[-1]
