@@ -24,22 +24,26 @@ from keystone import exception
 class CredentialModel(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'credential'
     attributes = [
-        'id', 'user_id', 'project_id', 'encrypted_blob', 'type', 'key_hash'
+        'id',
+        'user_id',
+        'project_id',
+        'encrypted_blob',
+        'type',
+        'key_hash',
     ]
     id = sql.Column(sql.String(64), primary_key=True)
-    user_id = sql.Column(sql.String(64),
-                         nullable=False)
+    user_id = sql.Column(sql.String(64), nullable=False)
     project_id = sql.Column(sql.String(64))
-    _encrypted_blob = sql.Column('encrypted_blob', sql.Text(), nullable=True)
+    _encrypted_blob = sql.Column('encrypted_blob', sql.Text(), nullable=False)
     type = sql.Column(sql.String(255), nullable=False)
-    key_hash = sql.Column(sql.String(64), nullable=True)
+    key_hash = sql.Column(sql.String(64), nullable=False)
     extra = sql.Column(sql.JsonBlob())
 
     @hybrid_property
     def encrypted_blob(self):
         return self._encrypted_blob
 
-    @encrypted_blob.setter
+    @encrypted_blob.setter  # type: ignore[no-redef]
     def encrypted_blob(self, encrypted_blob):
         # Make sure to hand over the encrypted credential as a string value
         # to the backend driver to avoid the sql drivers (esp. psycopg2)
@@ -64,8 +68,9 @@ class Credential(base.CredentialDriverBase):
     def list_credentials(self, hints):
         with sql.session_for_read() as session:
             credentials = session.query(CredentialModel)
-            credentials = sql.filter_limit_query(CredentialModel,
-                                                 credentials, hints)
+            credentials = sql.filter_limit_query(
+                CredentialModel, credentials, hints
+            )
             return [s.to_dict() for s in credentials]
 
     def list_credentials_for_user(self, user_id, type=None):
@@ -78,7 +83,7 @@ class Credential(base.CredentialDriverBase):
             return [ref.to_dict() for ref in refs]
 
     def _get_credential(self, session, credential_id):
-        ref = session.query(CredentialModel).get(credential_id)
+        ref = session.get(CredentialModel, credential_id)
         if ref is None:
             raise exception.CredentialNotFound(credential_id=credential_id)
         return ref
