@@ -16,6 +16,7 @@
 
 import json
 
+from keystone.common import cache
 from keystone.common import driver_hints
 from keystone.common import manager
 from keystone.common import provider_api
@@ -23,8 +24,8 @@ import keystone.conf
 from keystone import exception
 from keystone import notifications
 
-
 CONF = keystone.conf.CONF
+MEMOIZE = cache.get_memoization_decorator(group='credential')
 PROVIDERS = provider_api.ProviderAPIs
 
 
@@ -42,7 +43,7 @@ class Manager(manager.Manager):
     _CRED = 'credential'
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.credential.driver)
+        super().__init__(CONF.credential.driver)
 
     def _decrypt_credential(self, credential):
         """Return a decrypted credential reference."""
@@ -75,15 +76,20 @@ class Manager(manager.Manager):
             )
         else:
             encrypted_blob, key_hash = (
-                PROVIDERS.credential_provider_api.encrypt(
-                    credential['blob']
-                )
+                PROVIDERS.credential_provider_api.encrypt(credential['blob'])
             )
         credential_copy['encrypted_blob'] = encrypted_blob
         credential_copy['key_hash'] = key_hash
         credential_copy.pop('blob', None)
         return credential_copy
 
+    def _assert_limit_not_exceeded(self, user_id):
+        user_limit = CONF.credential.user_limit
+        if user_limit >= 0:
+            cred_count = len(self.list_credentials_for_user(user_id))
+            if cred_count >= user_limit:
+                raise exception.CredentialLimitExceeded(limit=user_limit)
+
     @manager.response_truncated
     def list_credentials(self, hints=None):
         credentials = self.driver.list_credentials(
@@ -94,29 +100,43 @@ class Manager(manager.Manager):
         return credentials
 
     def list_credentials_for_user(self, user_id, type=None):
-        """List credentials for a specific user."""
-        credentials = self.driver.list_credentials_for_user(user_id, type=type)
+        credentials = self._list_credentials_for_user(user_id, type)
         for credential in credentials:
             credential = self._decrypt_credential(credential)
         return credentials
 
+    @MEMOIZE
+    def _list_credentials_for_user(self, user_id, type):
+        """List credentials for a specific user."""
+        return self.driver.list_credentials_for_user(user_id, type)
+
     def get_credential(self, credential_id):
         """Return a credential reference."""
-        credential = self.driver.get_credential(credential_id)
+        credential = self._get_credential(credential_id)
         return self._decrypt_credential(credential)
 
-    def create_credential(self, credential_id, credential,
-                          initiator=None):
+    @MEMOIZE
+    def _get_credential(self, credential_id):
+        return self.driver.get_credential(credential_id)
+
+    def create_credential(self, credential_id, credential, initiator=None):
         """Create a credential."""
         credential_copy = self._encrypt_credential(credential)
+        user_id = credential_copy['user_id']
+        self._assert_limit_not_exceeded(user_id)
         ref = self.driver.create_credential(credential_id, credential_copy)
+        if MEMOIZE.should_cache(ref):
+            self._get_credential.set(ref, credential_copy, credential_id)
+            self._list_credentials_for_user.invalidate(
+                self, ref['user_id'], ref['type']
+            )
+            self._list_credentials_for_user.invalidate(
+                self, ref['user_id'], None
+            )
         ref.pop('key_hash', None)
         ref.pop('encrypted_blob', None)
         ref['blob'] = credential['blob']
-        notifications.Audit.created(
-            self._CRED,
-            credential_id,
-            initiator)
+        notifications.Audit.created(self._CRED, credential_id, initiator)
         return ref
 
     def _validate_credential_update(self, credential_id, credential):
@@ -124,12 +144,14 @@ class Manager(manager.Manager):
         # update, check the case where a non-ec2 credential changes its type
         # to be "ec2", but has no associated "project_id", either in the
         # request or already set in the database
-        if (credential.get('type', '').lower() == 'ec2' and
-                not credential.get('project_id')):
+        if credential.get('type', '').lower() == 'ec2' and not credential.get(
+            'project_id'
+        ):
             existing_cred = self.get_credential(credential_id)
             if not existing_cred['project_id']:
-                raise exception.ValidationError(attribute='project_id',
-                                                target='credential')
+                raise exception.ValidationError(
+                    attribute='project_id', target='credential'
+                )
 
     def update_credential(self, credential_id, credential):
         """Update an existing credential."""
@@ -141,6 +163,14 @@ class Manager(manager.Manager):
             existing_credential = self.get_credential(credential_id)
             existing_blob = existing_credential['blob']
         ref = self.driver.update_credential(credential_id, credential_copy)
+        if MEMOIZE.should_cache(ref):
+            self._get_credential.set(ref, self, credential_id)
+            self._list_credentials_for_user.invalidate(
+                self, ref['user_id'], ref['type']
+            )
+            self._list_credentials_for_user.invalidate(
+                self, ref['user_id'], None
+            )
         ref.pop('key_hash', None)
         ref.pop('encrypted_blob', None)
         # If the update request contains a `blob` attribute - we should return
@@ -152,9 +182,42 @@ class Manager(manager.Manager):
             ref['blob'] = existing_blob
         return ref
 
-    def delete_credential(self, credential_id,
-                          initiator=None):
+    def delete_credential(self, credential_id, initiator=None):
         """Delete a credential."""
+        cred = self.get_credential(credential_id)
         self.driver.delete_credential(credential_id)
-        notifications.Audit.deleted(
-            self._CRED, credential_id, initiator)
+        self._get_credential.invalidate(self, credential_id)
+        self._list_credentials_for_user.invalidate(
+            self, cred['user_id'], cred['type']
+        )
+        self._list_credentials_for_user.invalidate(self, cred['user_id'], None)
+        notifications.Audit.deleted(self._CRED, credential_id, initiator)
+
+    def delete_credentials_for_project(self, project_id):
+        """Delete all credentials for a project."""
+        hints = driver_hints.Hints()
+        hints.add_filter('project_id', project_id)
+        creds = self.driver.list_credentials(hints)
+
+        self.driver.delete_credentials_for_project(project_id)
+        for cred in creds:
+            self._get_credential.invalidate(self, cred['id'])
+            self._list_credentials_for_user.invalidate(
+                self, cred['user_id'], cred['type']
+            )
+            self._list_credentials_for_user.invalidate(
+                self, cred['user_id'], None
+            )
+
+    def delete_credentials_for_user(self, user_id):
+        """Delete all credentials for a user."""
+        creds = self.driver.list_credentials_for_user(user_id)
+        self.driver.delete_credentials_for_user(user_id)
+        for cred in creds:
+            self._get_credential.invalidate(self, cred['id'])
+            self._list_credentials_for_user.invalidate(
+                self, user_id, cred['type']
+            )
+            self._list_credentials_for_user.invalidate(
+                self, cred['user_id'], None
+            )
