@@ -14,19 +14,17 @@
 
 from oslo_log import log
 
-from keystone.common import dependency
 from keystone.common import manager
+from keystone.common import provider_api
 import keystone.conf
 from keystone import exception
-from keystone.i18n import _, _LE, _LW
-
+from keystone.i18n import _
 
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
+PROVIDERS = provider_api.ProviderAPIs
 
 
-@dependency.provider('endpoint_policy_api')
-@dependency.requires('catalog_api', 'policy_api')
 class Manager(manager.Manager):
     """Default pivot point for the Endpoint Policy backend.
 
@@ -36,9 +34,10 @@ class Manager(manager.Manager):
     """
 
     driver_namespace = 'keystone.endpoint_policy'
+    _provides_api = 'endpoint_policy_api'
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.endpoint_policy.driver)
+        super().__init__(CONF.endpoint_policy.driver)
 
     def _assert_valid_association(self, endpoint_id, service_id, region_id):
         """Assert that the association is supported.
@@ -50,48 +49,66 @@ class Manager(manager.Manager):
         - Service (in which case endpoint and region must be None)
 
         """
-        if (endpoint_id is not None and
-                service_id is None and region_id is None):
+        if (
+            endpoint_id is not None
+            and service_id is None
+            and region_id is None
+        ):
             return
-        if (service_id is not None and region_id is not None and
-                endpoint_id is None):
+        if (
+            service_id is not None
+            and region_id is not None
+            and endpoint_id is None
+        ):
             return
-        if (service_id is not None and
-                endpoint_id is None and region_id is None):
+        if (
+            service_id is not None
+            and endpoint_id is None
+            and region_id is None
+        ):
             return
 
-        raise exception.InvalidPolicyAssociation(endpoint_id=endpoint_id,
-                                                 service_id=service_id,
-                                                 region_id=region_id)
+        raise exception.InvalidPolicyAssociation(
+            endpoint_id=endpoint_id, service_id=service_id, region_id=region_id
+        )
 
-    def create_policy_association(self, policy_id, endpoint_id=None,
-                                  service_id=None, region_id=None):
+    def create_policy_association(
+        self, policy_id, endpoint_id=None, service_id=None, region_id=None
+    ):
         self._assert_valid_association(endpoint_id, service_id, region_id)
-        self.driver.create_policy_association(policy_id, endpoint_id,
-                                              service_id, region_id)
+        self.driver.create_policy_association(
+            policy_id, endpoint_id, service_id, region_id
+        )
 
-    def check_policy_association(self, policy_id, endpoint_id=None,
-                                 service_id=None, region_id=None):
+    def check_policy_association(
+        self, policy_id, endpoint_id=None, service_id=None, region_id=None
+    ):
         self._assert_valid_association(endpoint_id, service_id, region_id)
-        self.driver.check_policy_association(policy_id, endpoint_id,
-                                             service_id, region_id)
+        self.driver.check_policy_association(
+            policy_id, endpoint_id, service_id, region_id
+        )
 
-    def delete_policy_association(self, policy_id, endpoint_id=None,
-                                  service_id=None, region_id=None):
+    def delete_policy_association(
+        self, policy_id, endpoint_id=None, service_id=None, region_id=None
+    ):
         self._assert_valid_association(endpoint_id, service_id, region_id)
-        self.driver.delete_policy_association(policy_id, endpoint_id,
-                                              service_id, region_id)
+        self.driver.delete_policy_association(
+            policy_id, endpoint_id, service_id, region_id
+        )
 
     def list_endpoints_for_policy(self, policy_id):
 
         def _get_endpoint(endpoint_id, policy_id):
             try:
-                return self.catalog_api.get_endpoint(endpoint_id)
+                return PROVIDERS.catalog_api.get_endpoint(endpoint_id)
             except exception.EndpointNotFound:
-                msg = _LW('Endpoint %(endpoint_id)s referenced in '
-                          'association for policy %(policy_id)s not found.')
-                LOG.warning(msg, {'policy_id': policy_id,
-                                  'endpoint_id': endpoint_id})
+                msg = (
+                    'Endpoint %(endpoint_id)s referenced in '
+                    'association for policy %(policy_id)s not found.'
+                )
+                LOG.warning(
+                    msg, {'policy_id': policy_id, 'endpoint_id': endpoint_id}
+                )
                 raise
 
         def _get_endpoints_for_service(service_id, endpoints):
@@ -100,14 +117,20 @@ class Manager(manager.Manager):
             return [ep for ep in endpoints if ep['service_id'] == service_id]
 
         def _get_endpoints_for_service_and_region(
-                service_id, region_id, endpoints, regions):
+            service_id, region_id, endpoints, regions
+        ):
             # TODO(henry-nash): Consider optimizing this in the future.
             # The lack of a two-way pointer in the region tree structure
             # makes this somewhat inefficient.
 
             def _recursively_get_endpoints_for_region(
-                region_id, service_id, endpoint_list, region_list,
-                    endpoints_found, regions_examined):
+                region_id,
+                service_id,
+                endpoint_list,
+                region_list,
+                endpoints_found,
+                regions_examined,
+            ):
                 """Recursively search down a region tree for endpoints.
 
                 :param region_id: the point in the tree to examine
@@ -125,63 +148,89 @@ class Manager(manager.Manager):
 
                 """
                 if region_id in regions_examined:
-                    msg = _LE('Circular reference or a repeated entry found '
-                              'in region tree - %(region_id)s.')
+                    msg = (
+                        'Circular reference or a repeated entry found '
+                        'in region tree - %(region_id)s.'
+                    )
                     LOG.error(msg, {'region_id': ref.region_id})
                     return
 
                 regions_examined.append(region_id)
-                endpoints_found += (
-                    [ep for ep in endpoint_list if
-                     ep['service_id'] == service_id and
-                     ep['region_id'] == region_id])
+                endpoints_found += [
+                    ep
+                    for ep in endpoint_list
+                    if ep['service_id'] == service_id
+                    and ep['region_id'] == region_id
+                ]
 
                 for region in region_list:
                     if region['parent_region_id'] == region_id:
                         _recursively_get_endpoints_for_region(
-                            region['id'], service_id, endpoints, regions,
-                            endpoints_found, regions_examined)
+                            region['id'],
+                            service_id,
+                            endpoints,
+                            regions,
+                            endpoints_found,
+                            regions_examined,
+                        )
 
             endpoints_found = []
             regions_examined = []
 
             # Now walk down the region tree
             _recursively_get_endpoints_for_region(
-                region_id, service_id, endpoints, regions,
-                endpoints_found, regions_examined)
+                region_id,
+                service_id,
+                endpoints,
+                regions,
+                endpoints_found,
+                regions_examined,
+            )
 
             return endpoints_found
 
         matching_endpoints = []
-        endpoints = self.catalog_api.list_endpoints()
-        regions = self.catalog_api.list_regions()
+        endpoints = PROVIDERS.catalog_api.list_endpoints()
+        regions = PROVIDERS.catalog_api.list_regions()
         for ref in self.list_associations_for_policy(policy_id):
             if ref.get('endpoint_id') is not None:
                 matching_endpoints.append(
-                    _get_endpoint(ref['endpoint_id'], policy_id))
+                    _get_endpoint(ref['endpoint_id'], policy_id)
+                )
                 continue
 
-            if (ref.get('service_id') is not None and
-                    ref.get('region_id') is None):
+            if (
+                ref.get('service_id') is not None
+                and ref.get('region_id') is None
+            ):
                 matching_endpoints += _get_endpoints_for_service(
-                    ref['service_id'], endpoints)
+                    ref['service_id'], endpoints
+                )
                 continue
 
-            if (ref.get('service_id') is not None and
-                    ref.get('region_id') is not None):
-                matching_endpoints += (
-                    _get_endpoints_for_service_and_region(
-                        ref['service_id'], ref['region_id'],
-                        endpoints, regions))
+            if (
+                ref.get('service_id') is not None
+                and ref.get('region_id') is not None
+            ):
+                matching_endpoints += _get_endpoints_for_service_and_region(
+                    ref['service_id'], ref['region_id'], endpoints, regions
+                )
                 continue
 
-            msg = _LW('Unsupported policy association found - '
-                      'Policy %(policy_id)s, Endpoint %(endpoint_id)s, '
-                      'Service %(service_id)s, Region %(region_id)s, ')
-            LOG.warning(msg, {'policy_id': policy_id,
-                              'endpoint_id': ref['endpoint_id'],
-                              'service_id': ref['service_id'],
-                              'region_id': ref['region_id']})
+            msg = (
+                'Unsupported policy association found - '
+                'Policy %(policy_id)s, Endpoint %(endpoint_id)s, '
+                'Service %(service_id)s, Region %(region_id)s, '
+            )
+            LOG.warning(
+                msg,
+                {
+                    'policy_id': policy_id,
+                    'endpoint_id': ref['endpoint_id'],
+                    'service_id': ref['service_id'],
+                    'region_id': ref['region_id'],
+                },
+            )
 
         return matching_endpoints
 
@@ -189,12 +238,15 @@ class Manager(manager.Manager):
 
         def _get_policy(policy_id, endpoint_id):
             try:
-                return self.policy_api.get_policy(policy_id)
+                return PROVIDERS.policy_api.get_policy(policy_id)
             except exception.PolicyNotFound:
-                msg = _LW('Policy %(policy_id)s referenced in association '
-                          'for endpoint %(endpoint_id)s not found.')
-                LOG.warning(msg, {'policy_id': policy_id,
-                                  'endpoint_id': endpoint_id})
+                msg = (
+                    'Policy %(policy_id)s referenced in association '
+                    'for endpoint %(endpoint_id)s not found.'
+                )
+                LOG.warning(
+                    msg, {'policy_id': policy_id, 'endpoint_id': endpoint_id}
+                )
                 raise
 
         def _look_for_policy_for_region_and_service(endpoint):
@@ -210,8 +262,8 @@ class Manager(manager.Manager):
             while region_id is not None:
                 try:
                     ref = self.get_policy_association(
-                        service_id=endpoint['service_id'],
-                        region_id=region_id)
+                        service_id=endpoint['service_id'], region_id=region_id
+                    )
                     return ref['policy_id']
                 except exception.PolicyAssociationNotFound:  # nosec
                     # There wasn't one for that region & service, handle below.
@@ -220,13 +272,15 @@ class Manager(manager.Manager):
                 # There wasn't one for that region & service, let's
                 # chase up the region tree
                 regions_examined.append(region_id)
-                region = self.catalog_api.get_region(region_id)
+                region = PROVIDERS.catalog_api.get_region(region_id)
                 region_id = None
                 if region.get('parent_region_id') is not None:
                     region_id = region['parent_region_id']
                     if region_id in regions_examined:
-                        msg = _LE('Circular reference or a repeated entry '
-                                  'found in region tree - %(region_id)s.')
+                        msg = (
+                            'Circular reference or a repeated entry '
+                            'found in region tree - %(region_id)s.'
+                        )
                         LOG.error(msg, {'region_id': region_id})
                         break
 
@@ -244,7 +298,7 @@ class Manager(manager.Manager):
         # There wasn't a policy explicitly defined for this endpoint, so
         # now let's see if there is one for the Region & Service.
 
-        endpoint = self.catalog_api.get_endpoint(endpoint_id)
+        endpoint = PROVIDERS.catalog_api.get_endpoint(endpoint_id)
         policy_id = _look_for_policy_for_region_and_service(endpoint)
         if policy_id is not None:
             return _get_policy(policy_id, endpoint_id)
@@ -252,12 +306,14 @@ class Manager(manager.Manager):
         # Finally, just check if there is one for the service.
         try:
             ref = self.get_policy_association(
-                service_id=endpoint['service_id'])
+                service_id=endpoint['service_id']
+            )
             return _get_policy(ref['policy_id'], endpoint_id)
         except exception.PolicyAssociationNotFound:  # nosec
             # No policy is associated with endpoint, handled below.
             pass
 
-        msg = _('No policy is associated with endpoint '
-                '%(endpoint_id)s.') % {'endpoint_id': endpoint_id}
+        msg = _('No policy is associated with endpoint %(endpoint_id)s.') % {
+            'endpoint_id': endpoint_id
+        }
         raise exception.NotFound(msg)
