@@ -11,7 +11,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import absolute_import
 import uuid
 
 import ldap.filter
@@ -25,13 +24,14 @@ from keystone.identity.backends import base
 from keystone.identity.backends.ldap import common as common_ldap
 from keystone.identity.backends.ldap import models
 
-
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
-_DEPRECATION_MSG = ('%s for the LDAP identity backend has been deprecated in '
-                    'the Mitaka release in favor of read-only identity LDAP '
-                    'access. It will be removed in the "O" release.')
+_DEPRECATION_MSG = (
+    '%s for the LDAP identity backend has been deprecated in '
+    'the Mitaka release in favor of read-only identity LDAP '
+    'access. It will be removed in the "O" release.'
+)
 
 READ_ONLY_LDAP_ERROR_MESSAGE = _("LDAP does not support write operations")
 
@@ -40,7 +40,7 @@ LDAP_MATCHING_RULE_IN_CHAIN = "1.2.840.113556.1.4.1941"
 
 class Identity(base.IdentityDriverBase):
     def __init__(self, conf=None):
-        super(Identity, self).__init__()
+        super().__init__()
         if conf is None:
             self.conf = CONF
         else:
@@ -65,8 +65,9 @@ class Identity(base.IdentityDriverBase):
             raise AssertionError(_('Invalid user / password'))
         conn = None
         try:
-            conn = self.user.get_connection(user_ref['dn'],
-                                            password, end_user_auth=True)
+            conn = self.user.get_connection(
+                user_ref['dn'], password, end_user_auth=True
+            )
             if not conn:
                 raise AssertionError(_('Invalid user / password'))
         except Exception:
@@ -129,9 +130,11 @@ class Identity(base.IdentityDriverBase):
             try:
                 users.append(self.user.get_filtered(user_id))
             except exception.UserNotFound:
-                msg = ('Group member `%(user_id)s` for group `%(group_id)s`'
-                       ' not found in the directory. The user should be'
-                       ' removed from the group. The user will be ignored.')
+                msg = (
+                    'Group member `%(user_id)s` for group `%(group_id)s`'
+                    ' not found in the directory. The user should be'
+                    ' removed from the group. The user will be ignored.'
+                )
                 LOG.debug(msg, dict(user_id=user_id, group_id=group_id))
         return users
 
@@ -145,10 +148,10 @@ class Identity(base.IdentityDriverBase):
             if group_member_id == user_id:
                 break
         else:
-            raise exception.NotFound(_("User '%(user_id)s' not found in"
-                                       " group '%(group_id)s'") %
-                                     {'user_id': user_id,
-                                      'group_id': group_id})
+            raise exception.NotFound(
+                _("User '%(user_id)s' not found in group '%(group_id)s'")
+                % {'user_id': user_id, 'group_id': group_id}
+            )
 
     # Unsupported methods
     def _disallow_write(self):
@@ -166,6 +169,9 @@ class Identity(base.IdentityDriverBase):
     def delete_user(self, user_id):
         raise exception.Forbidden(READ_ONLY_LDAP_ERROR_MESSAGE)
 
+    def reset_last_active(self):
+        raise exception.Forbidden(READ_ONLY_LDAP_ERROR_MESSAGE)
+
     def change_password(self, user_id, new_password):
         raise exception.Forbidden(READ_ONLY_LDAP_ERROR_MESSAGE)
 
@@ -239,29 +245,30 @@ class UserApi(common_ldap.EnabledEmuMixIn, common_ldap.BaseLdap):
     DEFAULT_OBJECTCLASS = 'inetOrgPerson'
     NotFound = exception.UserNotFound
     options_name = 'user'
-    attribute_options_names = {'password': 'pass',
-                               'email': 'mail',
-                               'name': 'name',
-                               'description': 'description',
-                               'enabled': 'enabled',
-                               'default_project_id': 'default_project_id'}
+    attribute_options_names = {
+        'password': 'pass',
+        'email': 'mail',
+        'name': 'name',
+        'description': 'description',
+        'enabled': 'enabled',
+        'default_project_id': 'default_project_id',
+    }
     immutable_attrs = ['id']
 
     model = models.User
 
     def __init__(self, conf):
-        super(UserApi, self).__init__(conf)
+        super().__init__(conf)
         self.enabled_mask = conf.ldap.user_enabled_mask
         self.enabled_default = conf.ldap.user_enabled_default
         self.enabled_invert = conf.ldap.user_enabled_invert
         self.enabled_emulation = conf.ldap.user_enabled_emulation
 
     def _ldap_res_to_model(self, res):
-        obj = super(UserApi, self)._ldap_res_to_model(res)
+        obj = super()._ldap_res_to_model(res)
         if self.enabled_mask != 0:
             enabled = int(obj.get('enabled', self.enabled_default))
-            obj['enabled'] = ((enabled & self.enabled_mask) !=
-                              self.enabled_mask)
+            obj['enabled'] = (enabled & self.enabled_mask) != self.enabled_mask
         elif self.enabled_invert and not self.enabled_emulation:
             # This could be a bool or a string.  If it's a string,
             # we need to convert it so we can invert it properly.
@@ -279,8 +286,9 @@ class UserApi(common_ldap.EnabledEmuMixIn, common_ldap.BaseLdap):
     def mask_enabled_attribute(self, values):
         value = values['enabled']
         values.setdefault('enabled_nomask', int(self.enabled_default))
-        if value != ((values['enabled_nomask'] & self.enabled_mask) !=
-                     self.enabled_mask):
+        if value != (
+            (values['enabled_nomask'] & self.enabled_mask) != self.enabled_mask
+        ):
             values['enabled_nomask'] ^= self.enabled_mask
         values['enabled'] = values['enabled_nomask']
         del values['enabled_nomask']
@@ -297,15 +305,16 @@ class UserApi(common_ldap.EnabledEmuMixIn, common_ldap.BaseLdap):
                 values['enabled'] = not orig_enabled
             else:
                 values['enabled'] = self.enabled_default
-        values = super(UserApi, self).create(values)
-        if self.enabled_mask or (self.enabled_invert and
-                                 not self.enabled_emulation):
+        values = super().create(values)
+        if self.enabled_mask or (
+            self.enabled_invert and not self.enabled_emulation
+        ):
             values['enabled'] = orig_enabled
         values['options'] = {}  # options always empty
         return values
 
     def get(self, user_id, ldap_filter=None):
-        obj = super(UserApi, self).get(user_id, ldap_filter=ldap_filter)
+        obj = super().get(user_id, ldap_filter=ldap_filter)
         obj['options'] = {}  # options always empty
         return obj
 
@@ -317,16 +326,16 @@ class UserApi(common_ldap.EnabledEmuMixIn, common_ldap.BaseLdap):
             raise self.NotFound(user_id=user_id)
 
     def get_all(self, ldap_filter=None, hints=None):
-        objs = super(UserApi, self).get_all(ldap_filter=ldap_filter,
-                                            hints=hints)
+        objs = super().get_all(ldap_filter=ldap_filter, hints=hints)
         for obj in objs:
             obj['options'] = {}  # options always empty
         return objs
 
     def get_all_filtered(self, hints):
         query = self.filter_query(hints, self.ldap_filter)
-        return [self.filter_attributes(user)
-                for user in self.get_all(query, hints)]
+        return [
+            self.filter_attributes(user) for user in self.get_all(query, hints)
+        ]
 
     def filter_attributes(self, user):
         return base.filter_user(common_ldap.filter_entity(user))
@@ -348,7 +357,7 @@ class UserApi(common_ldap.EnabledEmuMixIn, common_ldap.BaseLdap):
             old_obj.pop('options')
         if 'options' in values:
             values.pop('options')
-        values = super(UserApi, self).update(user_id, values, old_obj)
+        values = super().update(user_id, values, old_obj)
         values['options'] = {}  # options always empty
         return values
 
@@ -361,21 +370,21 @@ class GroupApi(common_ldap.BaseLdap):
     DEFAULT_MEMBER_ATTRIBUTE = 'member'
     NotFound = exception.GroupNotFound
     options_name = 'group'
-    attribute_options_names = {'description': 'desc',
-                               'name': 'name'}
+    attribute_options_names = {'description': 'desc', 'name': 'name'}
     immutable_attrs = ['name']
     model = models.Group
 
     def _ldap_res_to_model(self, res):
-        model = super(GroupApi, self)._ldap_res_to_model(res)
+        model = super()._ldap_res_to_model(res)
         model['dn'] = res[0]
         return model
 
     def __init__(self, conf):
-        super(GroupApi, self).__init__(conf)
+        super().__init__(conf)
         self.group_ad_nesting = conf.ldap.group_ad_nesting
-        self.member_attribute = (conf.ldap.group_member_attribute
-                                 or self.DEFAULT_MEMBER_ATTRIBUTE)
+        self.member_attribute = (
+            conf.ldap.group_member_attribute or self.DEFAULT_MEMBER_ATTRIBUTE
+        )
 
     def create(self, values):
         data = values.copy()
@@ -383,33 +392,34 @@ class GroupApi(common_ldap.BaseLdap):
             data['id'] = uuid.uuid4().hex
         if 'description' in data and data['description'] in ['', None]:
             data.pop('description')
-        return super(GroupApi, self).create(data)
+        return super().create(data)
 
     def update(self, group_id, values):
         old_obj = self.get(group_id)
-        return super(GroupApi, self).update(group_id, values, old_obj)
+        return super().update(group_id, values, old_obj)
 
     def add_user(self, user_dn, group_id, user_id):
         group_ref = self.get(group_id)
         group_dn = group_ref['dn']
         try:
-            super(GroupApi, self).add_member(user_dn, group_dn)
+            super().add_member(user_dn, group_dn)
         except exception.Conflict:
-            raise exception.Conflict(_(
-                'User %(user_id)s is already a member of group %(group_id)s') %
-                {'user_id': user_id, 'group_id': group_id})
+            raise exception.Conflict(
+                _('User %(user_id)s is already a member of group %(group_id)s')
+                % {'user_id': user_id, 'group_id': group_id}
+            )
 
     def list_user_groups(self, user_dn):
         """Return a list of groups for which the user is a member."""
         user_dn_esc = ldap.filter.escape_filter_chars(user_dn)
         if self.group_ad_nesting:
-            query = '(%s:%s:=%s)' % (
+            query = '({}:{}:={})'.format(
                 self.member_attribute,
                 LDAP_MATCHING_RULE_IN_CHAIN,
-                user_dn_esc)
+                user_dn_esc,
+            )
         else:
-            query = '(%s=%s)' % (self.member_attribute,
-                                 user_dn_esc)
+            query = f'({self.member_attribute}={user_dn_esc})'
         return self.get_all(query)
 
     def list_user_groups_filtered(self, user_dn, hints):
@@ -419,12 +429,12 @@ class GroupApi(common_ldap.BaseLdap):
             # Hardcoded to member as that is how the Matching Rule in Chain
             # Mechanisms expects it.  The member_attribute might actually be
             # member_of elsewhere, so they are not the same.
-            query = '(member:%s:=%s)' % (
+            query = '(member:{}:={})'.format(
                 LDAP_MATCHING_RULE_IN_CHAIN,
-                user_dn_esc)
+                user_dn_esc,
+            )
         else:
-            query = '(%s=%s)' % (self.member_attribute,
-                                 user_dn_esc)
+            query = f'({self.member_attribute}={user_dn_esc})'
         return self.get_all_filtered(hints, query)
 
     def list_group_users(self, group_id):
@@ -438,14 +448,17 @@ class GroupApi(common_ldap.BaseLdap):
                 # coding to SCOPE_SUBTREE to get through the unit tests.
                 # However, it is also probably more correct.
                 attrs = self._ldap_get_list(
-                    self.tree_dn, self.LDAP_SCOPE,
+                    self.tree_dn,
+                    self.LDAP_SCOPE,
                     query_params={
-                        "member:%s:" % LDAP_MATCHING_RULE_IN_CHAIN:
-                        group_dn},
-                    attrlist=[self.member_attribute])
+                        "member:%s:" % LDAP_MATCHING_RULE_IN_CHAIN: group_dn
+                    },
+                    attrlist=[self.member_attribute],
+                )
             else:
-                attrs = self._ldap_get_list(group_dn, ldap.SCOPE_BASE,
-                                            attrlist=[self.member_attribute])
+                attrs = self._ldap_get_list(
+                    group_dn, ldap.SCOPE_BASE, attrlist=[self.member_attribute]
+                )
 
         except ldap.NO_SUCH_OBJECT:
             raise self.NotFound(group_id=group_id)
@@ -469,5 +482,7 @@ class GroupApi(common_ldap.BaseLdap):
         if self.ldap_filter:
             query = (query or '') + self.ldap_filter
         query = self.filter_query(hints, query)
-        return [common_ldap.filter_entity(group)
-                for group in self.get_all(query, hints)]
+        return [
+            common_ldap.filter_entity(group)
+            for group in self.get_all(query, hints)
+        ]
