@@ -13,7 +13,9 @@
 # under the License.
 
 import datetime
+import typing as ty
 
+from oslo_utils import timeutils
 import sqlalchemy
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy import orm
@@ -25,14 +27,20 @@ from keystone.common import sql
 import keystone.conf
 from keystone.identity.backends import resource_options as iro
 
-
 CONF = keystone.conf.CONF
 
 
 class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
     __tablename__ = 'user'
-    attributes = ['id', 'name', 'domain_id', 'password', 'enabled',
-                  'default_project_id', 'password_expires_at']
+    attributes = [
+        'id',
+        'name',
+        'domain_id',
+        'password',
+        'enabled',
+        'default_project_id',
+        'password_expires_at',
+    ]
     readonly_attributes = ['id', 'password_expires_at', 'password']
     resource_options_registry = iro.USER_OPTIONS_REGISTRY
     id = sql.Column(sql.String(64), primary_key=True)
@@ -46,30 +54,43 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
         cascade='all,delete,delete-orphan',
         lazy='subquery',
         backref='user',
-        collection_class=collections.attribute_mapped_collection('option_id'))
-    local_user = orm.relationship('LocalUser', uselist=False,
-                                  single_parent=True, lazy='joined',
-                                  cascade='all,delete-orphan', backref='user')
-    federated_users = orm.relationship('FederatedUser',
-                                       single_parent=True,
-                                       lazy='joined',
-                                       cascade='all,delete-orphan',
-                                       backref='user')
-    nonlocal_user = orm.relationship('NonLocalUser',
-                                     uselist=False,
-                                     single_parent=True,
-                                     lazy='joined',
-                                     cascade='all,delete-orphan',
-                                     backref='user')
+        collection_class=collections.attribute_mapped_collection('option_id'),
+    )
+    local_user = orm.relationship(
+        'LocalUser',
+        uselist=False,
+        single_parent=True,
+        lazy='joined',
+        cascade='all,delete-orphan',
+        backref='user',
+    )
+    federated_users = orm.relationship(
+        'FederatedUser',
+        single_parent=True,
+        lazy='joined',
+        cascade='all,delete-orphan',
+        backref='user',
+    )
+    nonlocal_user = orm.relationship(
+        'NonLocalUser',
+        uselist=False,
+        single_parent=True,
+        lazy='joined',
+        cascade='all,delete-orphan',
+        backref='user',
+    )
     expiring_user_group_memberships = orm.relationship(
         'ExpiringUserGroupMembership',
         cascade='all, delete-orphan',
-        backref="user"
+        backref="user",
     )
     created_at = sql.Column(sql.DateTime, nullable=True)
     last_active_at = sql.Column(sql.Date, nullable=True)
     # unique constraint needed here to support composite fk constraints
-    __table_args__ = (sql.UniqueConstraint('id', 'domain_id'), {})
+    __table_args__: ty.Any = (
+        sql.UniqueConstraint('id', 'domain_id'),
+        {},
+    )
 
     # NOTE(stevemar): we use a hybrid property here because we leverage the
     # expression method, see `@name.expression` and `LocalUser.name` below.
@@ -85,7 +106,7 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
         else:
             return None
 
-    @name.setter
+    @name.setter  # type: ignore[no-redef]
     def name(self, value):
         if self.federated_users:
             self.federated_users[0].display_name = value
@@ -95,7 +116,7 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
             self.local_user = LocalUser()
             self.local_user.name = value
 
-    @name.expression
+    @name.expression  # type: ignore[no-redef]
     def name(cls):
         return LocalUser.name
 
@@ -135,12 +156,12 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
     def password_is_expired(self):
         """Return whether password is expired or not."""
         if self.password_expires_at and not self._password_expiry_exempt():
-            return datetime.datetime.utcnow() >= self.password_expires_at
+            return timeutils.utcnow() >= self.password_expires_at
         return False
 
-    @password.setter
+    @password.setter  # type: ignore[no-redef]
     def password(self, value):
-        now = datetime.datetime.utcnow()
+        now = timeutils.utcnow()
         if not self.local_user:
             self.local_user = LocalUser()
         # truncate extra passwords
@@ -176,18 +197,20 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
         return getattr(
             self.get_resource_option(iro.IGNORE_PASSWORD_EXPIRY_OPT.option_id),
             'option_value',
-            False)
+            False,
+        )
 
     def _get_password_expires_at(self, created_at):
         expires_days = CONF.security_compliance.password_expires_days
         if not self._password_expiry_exempt():
             if expires_days:
-                expired_date = (created_at +
-                                datetime.timedelta(days=expires_days))
+                expired_date = created_at + datetime.timedelta(
+                    days=expires_days
+                )
                 return expired_date.replace(microsecond=0)
         return None
 
-    @password.expression
+    @password.expression  # type: ignore[no-redef]
     def password(cls):
         return Password.password_hash
 
@@ -198,33 +221,38 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
         """Return whether user is enabled or not."""
         if self._enabled:
             max_days = (
-                CONF.security_compliance.disable_user_account_days_inactive)
+                CONF.security_compliance.disable_user_account_days_inactive
+            )
             inactivity_exempt = getattr(
                 self.get_resource_option(
-                    iro.IGNORE_USER_INACTIVITY_OPT.option_id),
+                    iro.IGNORE_USER_INACTIVITY_OPT.option_id
+                ),
                 'option_value',
-                False)
+                False,
+            )
             last_active = self.last_active_at
             if not last_active and self.created_at:
                 last_active = self.created_at.date()
             if max_days and last_active:
-                now = datetime.datetime.utcnow().date()
+                now = timeutils.utcnow().date()
                 days_inactive = (now - last_active).days
                 if days_inactive >= max_days and not inactivity_exempt:
                     self._enabled = False
         return self._enabled
 
-    @enabled.setter
+    @enabled.setter  # type: ignore[no-redef]
     def enabled(self, value):
-        if (value and
-                CONF.security_compliance.disable_user_account_days_inactive):
-            self.last_active_at = datetime.datetime.utcnow().date()
+        if (
+            value
+            and CONF.security_compliance.disable_user_account_days_inactive
+        ):
+            self.last_active_at = timeutils.utcnow().date()
         if value and self.local_user:
             self.local_user.failed_auth_count = 0
             self.local_user.failed_auth_at = None
         self._enabled = value
 
-    @enabled.expression
+    @enabled.expression  # type: ignore[no-redef]
     def enabled(cls):
         return User._enabled
 
@@ -234,7 +262,7 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
         return None
 
     def to_dict(self, include_extra_dict=False):
-        d = super(User, self).to_dict(include_extra_dict=include_extra_dict)
+        d = super().to_dict(include_extra_dict=include_extra_dict)
         if 'default_project_id' in d and d['default_project_id'] is None:
             del d['default_project_id']
         # NOTE(notmorgan): Eventually it may make sense to drop the empty
@@ -267,7 +295,7 @@ class User(sql.ModelBase, sql.ModelDictMixinWithExtras):
                 if opt_value is not None:
                     opt.validator(opt_value)
                 resource_options[opt.option_id] = opt_value
-        user_obj = super(User, cls).from_dict(new_dict)
+        user_obj = super().from_dict(new_dict)
         setattr(user_obj, '_resource_options', resource_options)
         return user_obj
 
@@ -279,27 +307,37 @@ class LocalUser(sql.ModelBase, sql.ModelDictMixin):
     user_id = sql.Column(sql.String(64), nullable=False)
     domain_id = sql.Column(sql.String(64), nullable=False)
     name = sql.Column(sql.String(255), nullable=False)
-    passwords = orm.relationship('Password',
-                                 single_parent=True,
-                                 cascade='all,delete-orphan',
-                                 lazy='joined',
-                                 backref='local_user',
-                                 order_by='Password.created_at_int')
+    passwords = orm.relationship(
+        'Password',
+        single_parent=True,
+        cascade='all,delete-orphan',
+        lazy='joined',
+        backref='local_user',
+        order_by='Password.created_at_int',
+    )
     failed_auth_count = sql.Column(sql.Integer, nullable=True)
     failed_auth_at = sql.Column(sql.DateTime, nullable=True)
     __table_args__ = (
         sql.UniqueConstraint('user_id'),
         sql.UniqueConstraint('domain_id', 'name'),
-        sqlalchemy.ForeignKeyConstraint(['user_id', 'domain_id'],
-                                        ['user.id', 'user.domain_id'],
-                                        onupdate='CASCADE', ondelete='CASCADE')
+        sqlalchemy.ForeignKeyConstraint(
+            ['user_id', 'domain_id'],
+            ['user.id', 'user.domain_id'],
+            onupdate='CASCADE',
+            ondelete='CASCADE',
+        ),
     )
 
 
 class Password(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'password'
-    attributes = ['id', 'local_user_id', 'password_hash', 'created_at',
-                  'expires_at']
+    attributes = [
+        'id',
+        'local_user_id',
+        'password_hash',
+        'created_at',
+        'expires_at',
+    ]
     id = sql.Column(sql.Integer, primary_key=True)
     local_user_id = sql.Column(
         sql.Integer,
@@ -314,8 +352,12 @@ class Password(sql.ModelBase, sql.ModelDictMixin):
     # big integers. The old datetime columns and their corresponding attributes
     # in the model are no longer required.
     # created_at default set here to safe guard in case it gets missed
-    _created_at = sql.Column('created_at', sql.DateTime, nullable=False,
-                             default=datetime.datetime.utcnow)
+    _created_at = sql.Column(
+        'created_at',
+        sql.DateTime,
+        nullable=False,
+        default=timeutils.utcnow,
+    )
     _expires_at = sql.Column('expires_at', sql.DateTime, nullable=True)
     # set the default to 0, a 0 indicates it is unset.
     created_at_int = sql.Column(
@@ -336,7 +378,7 @@ class Password(sql.ModelBase, sql.ModelDictMixin):
     def created_at(self):
         return self.created_at_int or self._created_at
 
-    @created_at.setter
+    @created_at.setter  # type: ignore[no-redef]
     def created_at(self, value):
         self._created_at = value
         self.created_at_int = value
@@ -345,7 +387,7 @@ class Password(sql.ModelBase, sql.ModelDictMixin):
     def expires_at(self):
         return self.expires_at_int or self._expires_at
 
-    @expires_at.setter
+    @expires_at.setter  # type: ignore[no-redef]
     def expires_at(self, value):
         self._expires_at = value
         self.expires_at_int = value
@@ -353,8 +395,14 @@ class Password(sql.ModelBase, sql.ModelDictMixin):
 
 class FederatedUser(sql.ModelBase, sql.ModelDictMixin):
     __tablename__ = 'federated_user'
-    attributes = ['id', 'user_id', 'idp_id', 'protocol_id', 'unique_id',
-                  'display_name']
+    attributes = [
+        'id',
+        'user_id',
+        'idp_id',
+        'protocol_id',
+        'unique_id',
+        'display_name',
+    ]
     id = sql.Column(sql.Integer, primary_key=True)
     user_id = sql.Column(
         sql.String(64),
@@ -371,10 +419,11 @@ class FederatedUser(sql.ModelBase, sql.ModelDictMixin):
     display_name = sql.Column(sql.String(255), nullable=True)
     __table_args__ = (
         sql.UniqueConstraint('idp_id', 'protocol_id', 'unique_id'),
-        sqlalchemy.ForeignKeyConstraint(['protocol_id', 'idp_id'],
-                                        ['federation_protocol.id',
-                                         'federation_protocol.idp_id'],
-                                        ondelete='CASCADE')
+        sqlalchemy.ForeignKeyConstraint(
+            ['protocol_id', 'idp_id'],
+            ['federation_protocol.id', 'federation_protocol.idp_id'],
+            ondelete='CASCADE',
+        ),
     )
 
 
@@ -389,8 +438,12 @@ class NonLocalUser(sql.ModelBase, sql.ModelDictMixin):
     __table_args__ = (
         sql.UniqueConstraint('user_id'),
         sqlalchemy.ForeignKeyConstraint(
-            ['user_id', 'domain_id'], ['user.id', 'user.domain_id'],
-            onupdate='CASCADE', ondelete='CASCADE'),)
+            ['user_id', 'domain_id'],
+            ['user.id', 'user.domain_id'],
+            onupdate='CASCADE',
+            ondelete='CASCADE',
+        ),
+    )
 
 
 class Group(sql.ModelBase, sql.ModelDictMixinWithExtras):
@@ -404,7 +457,7 @@ class Group(sql.ModelBase, sql.ModelDictMixinWithExtras):
     expiring_user_group_memberships = orm.relationship(
         'ExpiringUserGroupMembership',
         cascade='all, delete-orphan',
-        backref="group"
+        backref="group",
     )
     # Unique constraint across two columns to create the separation
     # rather than just only 'name' being unique
@@ -415,28 +468,29 @@ class UserGroupMembership(sql.ModelBase, sql.ModelDictMixin):
     """Group membership join table."""
 
     __tablename__ = 'user_group_membership'
-    user_id = sql.Column(sql.String(64),
-                         sql.ForeignKey('user.id'),
-                         primary_key=True)
-    group_id = sql.Column(sql.String(64),
-                          sql.ForeignKey('group.id'),
-                          primary_key=True)
+    user_id = sql.Column(
+        sql.String(64), sql.ForeignKey('user.id'), primary_key=True
+    )
+    group_id = sql.Column(
+        sql.String(64), sql.ForeignKey('group.id'), primary_key=True
+    )
 
 
 class ExpiringUserGroupMembership(sql.ModelBase, sql.ModelDictMixin):
     """Expiring group membership through federation mapping rules."""
 
     __tablename__ = 'expiring_user_group_membership'
-    user_id = sql.Column(sql.String(64),
-                         sql.ForeignKey('user.id'),
-                         primary_key=True)
-    group_id = sql.Column(sql.String(64),
-                          sql.ForeignKey('group.id'),
-                          primary_key=True)
-    idp_id = sql.Column(sql.String(64),
-                        sql.ForeignKey('identity_provider.id',
-                                       ondelete='CASCADE'),
-                        primary_key=True)
+    user_id = sql.Column(
+        sql.String(64), sql.ForeignKey('user.id'), primary_key=True
+    )
+    group_id = sql.Column(
+        sql.String(64), sql.ForeignKey('group.id'), primary_key=True
+    )
+    idp_id = sql.Column(
+        sql.String(64),
+        sql.ForeignKey('identity_provider.id', ondelete='CASCADE'),
+        primary_key=True,
+    )
     last_verified = sql.Column(sql.DateTime, nullable=False)
 
     @hybrid_property
@@ -448,16 +502,18 @@ class ExpiringUserGroupMembership(sql.ModelBase, sql.ModelDictMixin):
 
     @hybrid_property
     def expired(self):
-        return self.expires <= datetime.datetime.utcnow()
+        return self.expires <= timeutils.utcnow()
 
 
 class UserOption(sql.ModelBase):
     __tablename__ = 'user_option'
-    user_id = sql.Column(sql.String(64), sql.ForeignKey('user.id',
-                         ondelete='CASCADE'), nullable=False,
-                         primary_key=True)
-    option_id = sql.Column(sql.String(4), nullable=False,
-                           primary_key=True)
+    user_id = sql.Column(
+        sql.String(64),
+        sql.ForeignKey('user.id', ondelete='CASCADE'),
+        nullable=False,
+        primary_key=True,
+    )
+    option_id = sql.Column(sql.String(4), nullable=False, primary_key=True)
     option_value = sql.Column(sql.JsonBlob, nullable=True)
 
     def __init__(self, option_id, option_value):
