@@ -14,10 +14,10 @@
 # under the License.
 
 import copy
-import sqlalchemy
-from sqlalchemy.ext.hybrid import hybrid_property
 
 from oslo_db import exception as db_exception
+import sqlalchemy
+from sqlalchemy.ext.hybrid import hybrid_property
 
 from keystone.common import driver_hints
 from keystone.common import sql
@@ -35,21 +35,21 @@ class RegisteredLimitModel(sql.ModelBase, sql.ModelDictMixin):
         'region_id',
         'resource_name',
         'default_limit',
-        'description'
+        'description',
     ]
 
     internal_id = sql.Column(sql.Integer, primary_key=True, nullable=False)
     id = sql.Column(sql.String(length=64), nullable=False, unique=True)
-    service_id = sql.Column(sql.String(255),
-                            sql.ForeignKey('service.id'))
-    region_id = sql.Column(sql.String(64),
-                           sql.ForeignKey('region.id'), nullable=True)
+    service_id = sql.Column(sql.String(255), sql.ForeignKey('service.id'))
+    region_id = sql.Column(
+        sql.String(64), sql.ForeignKey('region.id'), nullable=True
+    )
     resource_name = sql.Column(sql.String(255))
     default_limit = sql.Column(sql.Integer, nullable=False)
     description = sql.Column(sql.Text())
 
     def to_dict(self):
-        ref = super(RegisteredLimitModel, self).to_dict()
+        ref = super().to_dict()
         ref.pop('internal_id')
         return ref
 
@@ -66,22 +66,18 @@ class LimitModel(sql.ModelBase, sql.ModelDictMixin):
         'resource_name',
         'resource_limit',
         'description',
-        'registered_limit_id'
+        'registered_limit_id',
     ]
 
-    # TODO(wxy): Drop "service_id", "region_id" and "resource_name" columns
-    # in T release.
     internal_id = sql.Column(sql.Integer, primary_key=True, nullable=False)
     id = sql.Column(sql.String(length=64), nullable=False, unique=True)
     project_id = sql.Column(sql.String(64))
     domain_id = sql.Column(sql.String(64))
-    _service_id = sql.Column('service_id', sql.String(255))
-    _region_id = sql.Column('region_id', sql.String(64), nullable=True)
-    _resource_name = sql.Column('resource_name', sql.String(255))
     resource_limit = sql.Column(sql.Integer, nullable=False)
     description = sql.Column(sql.Text())
-    registered_limit_id = sql.Column(sql.String(64),
-                                     sql.ForeignKey('registered_limit.id'))
+    registered_limit_id = sql.Column(
+        sql.String(64), sql.ForeignKey('registered_limit.id')
+    )
 
     registered_limit = sqlalchemy.orm.relationship('RegisteredLimitModel')
 
@@ -89,29 +85,21 @@ class LimitModel(sql.ModelBase, sql.ModelDictMixin):
     def service_id(self):
         if self.registered_limit:
             return self.registered_limit.service_id
-        return self._service_id
+        return None
 
-    @service_id.setter
-    def service_id(self, value):
-        self._service_id = value
-
-    @service_id.expression
+    @service_id.expression  # type: ignore[no-redef]
     def service_id(self):
-        return LimitModel._service_id
+        return RegisteredLimitModel.service_id
 
     @hybrid_property
     def region_id(self):
         if self.registered_limit:
             return self.registered_limit.region_id
-        return self._region_id
+        return None
 
-    @region_id.setter
-    def region_id(self, value):
-        self._region_id = value
-
-    @region_id.expression
+    @region_id.expression  # type: ignore[no-redef]
     def region_id(self):
-        return LimitModel._region_id
+        return RegisteredLimitModel.region_id
 
     @hybrid_property
     def resource_name(self):
@@ -119,25 +107,16 @@ class LimitModel(sql.ModelBase, sql.ModelDictMixin):
             return self.registered_limit.resource_name
         return self._resource_name
 
-    @resource_name.setter
-    def resource_name(self, value):
-        self._resource_name = value
-
-    @resource_name.expression
+    @resource_name.expression  # type: ignore[no-redef]
     def resource_name(self):
-        return LimitModel._resource_name
-
-    @classmethod
-    def from_dict(cls, limit):
-        obj = super(LimitModel, cls).from_dict(limit)
-        with sql.session_for_read() as session:
-            query = session.query(RegisteredLimitModel).filter_by(
-                id=obj.registered_limit_id)
-            obj.registered_limit = query.first()
-        return obj
+        return RegisteredLimitModel.resource_name
 
     def to_dict(self):
-        ref = super(LimitModel, self).to_dict()
+        ref = super().to_dict()
+        if self.registered_limit:
+            ref['service_id'] = self.registered_limit.service_id
+            ref['region_id'] = self.registered_limit.region_id
+            ref['resource_name'] = self.registered_limit.resource_name
         ref.pop('internal_id')
         ref.pop('registered_limit_id')
         return ref
@@ -145,51 +124,38 @@ class LimitModel(sql.ModelBase, sql.ModelDictMixin):
 
 class UnifiedLimit(base.UnifiedLimitDriverBase):
 
-    def _check_unified_limit_unique(self, unified_limit,
-                                    is_registered_limit=True):
+    def _check_unified_limit_unique(
+        self, unified_limit, is_registered_limit=True
+    ):
         # Ensure the new created or updated unified limit won't break the
         # current reference between registered limit and limit. i.e. We should
         # ensure that there is no duplicate entry.
         hints = driver_hints.Hints()
-        hints.add_filter('service_id', unified_limit['service_id'])
-        hints.add_filter('resource_name', unified_limit['resource_name'])
-        hints.add_filter('region_id', unified_limit.get('region_id'))
         if is_registered_limit:
+            hints.add_filter('service_id', unified_limit['service_id'])
+            hints.add_filter('resource_name', unified_limit['resource_name'])
+            hints.add_filter('region_id', unified_limit.get('region_id'))
             with sql.session_for_read() as session:
                 query = session.query(RegisteredLimitModel)
-                unified_limits = sql.filter_limit_query(RegisteredLimitModel,
-                                                        query,
-                                                        hints).all()
+                unified_limits = sql.filter_limit_query(
+                    RegisteredLimitModel, query, hints
+                ).all()
         else:
-            is_project_limit = (True if unified_limit.get('project_id')
-                                else False)
+            hints.add_filter(
+                'registered_limit_id', unified_limit['registered_limit_id']
+            )
+            is_project_limit = (
+                True if unified_limit.get('project_id') else False
+            )
             if is_project_limit:
                 hints.add_filter('project_id', unified_limit['project_id'])
             else:
                 hints.add_filter('domain_id', unified_limit['domain_id'])
             with sql.session_for_read() as session:
                 query = session.query(LimitModel)
-                old_unified_limits = sql.filter_limit_query(LimitModel,
-                                                            query,
-                                                            hints).all()
-                query = session.query(
-                    LimitModel).outerjoin(RegisteredLimitModel)
-                query = query.filter(
-                    RegisteredLimitModel.service_id ==
-                    unified_limit['service_id'],
-                    RegisteredLimitModel.region_id ==
-                    unified_limit.get('region_id'),
-                    RegisteredLimitModel.resource_name ==
-                    unified_limit['resource_name'])
-                if is_project_limit:
-                    query = query.filter(
-                        LimitModel.project_id == unified_limit['project_id'])
-                else:
-                    query = query.filter(
-                        LimitModel.domain_id == unified_limit['domain_id'])
-                new_unified_limits = query.all()
-
-                unified_limits = old_unified_limits + new_unified_limits
+                unified_limits = sql.filter_limit_query(
+                    LimitModel, query, hints
+                ).all()
 
         if unified_limits:
             msg = _('Duplicate entry')
@@ -201,7 +167,8 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
         # is no reference limit.
         with sql.session_for_read() as session:
             limits = session.query(LimitModel).filter_by(
-                registered_limit_id=registered_limit['id'])
+                registered_limit_id=registered_limit['id']
+            )
         if limits.all():
             raise exception.RegisteredLimitError(id=registered_limit.id)
 
@@ -224,16 +191,16 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
                 self._check_referenced_limit_reference(ref)
                 old_dict = ref.to_dict()
                 old_dict.update(registered_limit)
-                if (registered_limit.get('service_id') or
-                        'region_id' in registered_limit or
-                        registered_limit.get('resource_name')):
+                if (
+                    registered_limit.get('service_id')
+                    or 'region_id' in registered_limit
+                    or registered_limit.get('resource_name')
+                ):
                     self._check_unified_limit_unique(old_dict)
-                new_registered_limit = RegisteredLimitModel.from_dict(
-                    old_dict)
+                new_registered_limit = RegisteredLimitModel.from_dict(old_dict)
                 for attr in registered_limit:
                     if attr != 'id':
-                        setattr(ref, attr, getattr(new_registered_limit,
-                                                   attr))
+                        setattr(ref, attr, getattr(new_registered_limit, attr))
                 return ref.to_dict()
         except db_exception.DBReferenceError:
             raise exception.RegisteredLimitError(id=registered_limit_id)
@@ -242,14 +209,15 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
     def list_registered_limits(self, hints):
         with sql.session_for_read() as session:
             registered_limits = session.query(RegisteredLimitModel)
-            registered_limits = sql.filter_limit_query(RegisteredLimitModel,
-                                                       registered_limits,
-                                                       hints)
+            registered_limits = sql.filter_limit_query(
+                RegisteredLimitModel, registered_limits, hints
+            )
             return [s.to_dict() for s in registered_limits]
 
     def _get_registered_limit(self, session, registered_limit_id):
         query = session.query(RegisteredLimitModel).filter_by(
-            id=registered_limit_id)
+            id=registered_limit_id
+        )
         ref = query.first()
         if ref is None:
             raise exception.RegisteredLimitNotFound(id=registered_limit_id)
@@ -258,13 +226,13 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
     def get_registered_limit(self, registered_limit_id):
         with sql.session_for_read() as session:
             return self._get_registered_limit(
-                session, registered_limit_id).to_dict()
+                session, registered_limit_id
+            ).to_dict()
 
     def delete_registered_limit(self, registered_limit_id):
         try:
             with sql.session_for_write() as session:
-                ref = self._get_registered_limit(session,
-                                                 registered_limit_id)
+                ref = self._get_registered_limit(session, registered_limit_id)
                 self._check_referenced_limit_reference(ref)
                 session.delete(ref)
         except db_exception.DBReferenceError:
@@ -282,7 +250,8 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
         with sql.session_for_read() as session:
             registered_limits = session.query(RegisteredLimitModel)
             registered_limits = sql.filter_limit_query(
-                RegisteredLimitModel, registered_limits, hints)
+                RegisteredLimitModel, registered_limits, hints
+            )
         reg_limits = registered_limits.all()
         if not reg_limits:
             raise exception.NoLimitReference
@@ -296,12 +265,17 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
             with sql.session_for_write() as session:
                 new_limits = []
                 for limit in limits:
-                    self._check_unified_limit_unique(limit,
-                                                     is_registered_limit=False)
                     target = self._check_and_fill_registered_limit_id(limit)
+                    self._check_unified_limit_unique(
+                        target, is_registered_limit=False
+                    )
                     ref = LimitModel.from_dict(target)
                     session.add(ref)
-                    new_limits.append(ref.to_dict())
+                    new_limit = ref.to_dict()
+                    new_limit['service_id'] = limit['service_id']
+                    new_limit['region_id'] = limit.get('region_id')
+                    new_limit['resource_name'] = limit['resource_name']
+                    new_limits.append(new_limit)
                 return new_limits
         except db_exception.DBReferenceError:
             raise exception.NoLimitReference()
@@ -310,43 +284,18 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
     def update_limit(self, limit_id, limit):
         with sql.session_for_write() as session:
             ref = self._get_limit(session, limit_id)
-            old_dict = ref.to_dict()
-            old_dict.update(limit)
-            new_limit = LimitModel.from_dict(old_dict)
-            ref.resource_limit = new_limit.resource_limit
-            ref.description = new_limit.description
+            if limit.get('resource_limit'):
+                ref.resource_limit = limit['resource_limit']
+            if limit.get('description'):
+                ref.description = limit['description']
             return ref.to_dict()
 
     @driver_hints.truncated
     def list_limits(self, hints):
-        hint_copy = copy.deepcopy(hints)
-        new_format_data = []
         with sql.session_for_read() as session:
-            query = session.query(LimitModel)
-            limits = sql.filter_limit_query(LimitModel,
-                                            query,
-                                            hints)
-            old_format_data = [s.to_dict() for s in limits]
-            project_filter = hint_copy.get_exact_filter_by_name('project_id')
-            domain_filter = hint_copy.get_exact_filter_by_name('domain_id')
-            if hint_copy.filters and (not (project_filter or domain_filter)
-                                      or len(hint_copy.filters) > 1):
-                # If the hints contain "service_id", "region_id" or
-                # "resource_name", we should combine the registered_limit table
-                # first to fetch these information.
-                query_new = session.query(
-                    LimitModel).outerjoin(RegisteredLimitModel)
-                limits = sql.filter_limit_query(RegisteredLimitModel,
-                                                query_new,
-                                                hint_copy)
-                if project_filter:
-                    limits = limits.filter(
-                        LimitModel.project_id == project_filter['value'])
-                elif domain_filter:
-                    limits = limits.filter(
-                        LimitModel.domain_id == domain_filter['value'])
-                new_format_data = [s.to_dict() for s in limits]
-            return old_format_data + new_format_data
+            query = session.query(LimitModel).outerjoin(RegisteredLimitModel)
+            limits = sql.filter_limit_query(LimitModel, query, hints)
+            return [limit.to_dict() for limit in limits]
 
     def _get_limit(self, session, limit_id):
         query = session.query(LimitModel).filter_by(id=limit_id)
@@ -357,13 +306,11 @@ class UnifiedLimit(base.UnifiedLimitDriverBase):
 
     def get_limit(self, limit_id):
         with sql.session_for_read() as session:
-            return self._get_limit(session,
-                                   limit_id).to_dict()
+            return self._get_limit(session, limit_id).to_dict()
 
     def delete_limit(self, limit_id):
         with sql.session_for_write() as session:
-            ref = self._get_limit(session,
-                                  limit_id)
+            ref = self._get_limit(session, limit_id)
             session.delete(ref)
 
     def delete_limits_for_project(self, project_id):
