@@ -14,8 +14,6 @@
 
 """Main entry point into the OAuth1 service."""
 
-from __future__ import absolute_import
-
 import uuid
 
 import oauthlib.common
@@ -28,7 +26,6 @@ from keystone import exception
 from keystone.i18n import _
 from keystone import notifications
 
-
 RequestValidator = oauth1.RequestValidator
 Client = oauth1.Client
 AccessTokenEndpoint = oauth1.AccessTokenEndpoint
@@ -39,7 +36,7 @@ RequestTokenEndpoint = oauth1.RequestTokenEndpoint
 oRequest = oauthlib.common.Request
 
 
-class Token(object):
+class Token:
     def __init__(self, key, secret):
         self.key = key
         self.secret = secret
@@ -89,17 +86,31 @@ def validate_oauth_params(query_string):
     params_fitered = {k: v for k, v in params if not k.startswith('oauth_')}
     if params_fitered:
         if 'error' in params_fitered:
-            msg = _(
+            msg = (
                 'Validation failed with errors: %(error)s, detail '
-                'message is: %(desc)s.') % {
-                    'error': params_fitered['error'],
-                    'desc': params_fitered['error_description']}
+                'message is: %(desc)s.'
+            ) % {
+                'error': params_fitered['error'],
+                'desc': params_fitered['error_description'],
+            }
+            tr_msg = _(
+                'Validation failed with errors: %(error)s, detail '
+                'message is: %(desc)s.'
+            ) % {
+                'error': params_fitered['error'],
+                'desc': params_fitered['error_description'],
+            }
         else:
-            msg = _(
-                'Unknown parameters found, '
-                'please provide only oauth parameters.')
+            msg = (
+                'Unknown parameters found,'
+                'please provide only oauth parameters.'
+            )
+            tr_msg = _(
+                'Unknown parameters found,'
+                'please provide only oauth parameters.'
+            )
         LOG.warning(msg)
-        raise exception.ValidationError(message=msg)
+        raise exception.ValidationError(message=tr_msg)
 
 
 class Manager(manager.Manager):
@@ -113,12 +124,12 @@ class Manager(manager.Manager):
     driver_namespace = 'keystone.oauth1'
     _provides_api = 'oauth_api'
 
-    _ACCESS_TOKEN = "OS-OAUTH1:access_token"
-    _REQUEST_TOKEN = "OS-OAUTH1:request_token"
+    _ACCESS_TOKEN = "OS-OAUTH1:access_token"  # nosec
+    _REQUEST_TOKEN = "OS-OAUTH1:request_token"  # nosec
     _CONSUMER = "OS-OAUTH1:consumer"
 
     def __init__(self):
-        super(Manager, self).__init__(CONF.oauth1.driver)
+        super().__init__(CONF.oauth1.driver)
 
     def create_consumer(self, consumer_ref, initiator=None):
         consumer_ref = consumer_ref.copy()
@@ -137,23 +148,31 @@ class Manager(manager.Manager):
         notifications.Audit.deleted(self._CONSUMER, consumer_id, initiator)
         return ret
 
-    def create_access_token(self, request_id, access_token_duration,
-                            initiator=None):
-        ret = self.driver.create_access_token(request_id,
-                                              access_token_duration)
+    def create_access_token(
+        self, request_id, access_token_duration, initiator=None
+    ):
+        ret = self.driver.create_access_token(
+            request_id, access_token_duration
+        )
         notifications.Audit.created(self._ACCESS_TOKEN, ret['id'], initiator)
         return ret
 
     def delete_access_token(self, user_id, access_token_id, initiator=None):
         ret = self.driver.delete_access_token(user_id, access_token_id)
-        notifications.Audit.deleted(self._ACCESS_TOKEN, access_token_id,
-                                    initiator)
+        notifications.Audit.deleted(
+            self._ACCESS_TOKEN, access_token_id, initiator
+        )
         return ret
 
-    def create_request_token(self, consumer_id, requested_project,
-                             request_token_duration, initiator=None):
+    def create_request_token(
+        self,
+        consumer_id,
+        requested_project,
+        request_token_duration,
+        initiator=None,
+    ):
         ret = self.driver.create_request_token(
-            consumer_id, requested_project, request_token_duration)
-        notifications.Audit.created(self._REQUEST_TOKEN, ret['id'],
-                                    initiator)
+            consumer_id, requested_project, request_token_duration
+        )
+        notifications.Audit.created(self._REQUEST_TOKEN, ret['id'], initiator)
         return ret
