@@ -11,17 +11,14 @@
 # under the License.
 
 import abc
-import six
 
 import keystone.conf
 from keystone import exception
 
-
 CONF = keystone.conf.CONF
 
 
-@six.add_metaclass(abc.ABCMeta)
-class PolicyDriverBase(object):
+class PolicyDriverBase(metaclass=abc.ABCMeta):
 
     def _get_list_limit(self):
         return CONF.policy.list_limit or CONF.list_limit
