@@ -29,7 +29,6 @@ import keystone.conf
 from keystone import exception
 from keystone.i18n import _
 
-
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
 
@@ -39,7 +38,7 @@ TIMESTAMP_START = 1
 TIMESTAMP_END = 9
 
 
-class ReceiptFormatter(object):
+class ReceiptFormatter:
     """Packs and unpacks payloads into receipts for transport."""
 
     @property
@@ -58,7 +57,7 @@ class ReceiptFormatter(object):
         fernet_utils = utils.FernetUtils(
             CONF.fernet_receipts.key_repository,
             CONF.fernet_receipts.max_active_keys,
-            'fernet_receipts'
+            'fernet_receipts',
         )
         keys = fernet_utils.load_keys()
 
@@ -91,7 +90,8 @@ class ReceiptFormatter(object):
             return self.crypto.decrypt(receipt.encode('utf-8'))
         except fernet.InvalidToken:
             raise exception.ValidationError(
-                _('This is not a recognized Fernet receipt %s') % receipt)
+                _('This is not a recognized Fernet receipt %s') % receipt
+            )
 
     @classmethod
     def restore_padding(cls, receipt):
@@ -122,7 +122,8 @@ class ReceiptFormatter(object):
         # Fernet receipts are base64 encoded, so we need to unpack them first
         # urlsafe_b64decode() requires bytes
         receipt_bytes = base64.urlsafe_b64decode(
-            fernet_receipt.encode('utf-8'))
+            fernet_receipt.encode('utf-8')
+        )
 
         # slice into the byte array to get just the timestamp
         timestamp_bytes = receipt_bytes[TIMESTAMP_START:TIMESTAMP_END]
@@ -132,7 +133,9 @@ class ReceiptFormatter(object):
         timestamp_int = struct.unpack(">Q", timestamp_bytes)[0]
 
         # and with an integer, it's trivial to produce a datetime object
-        issued_at = datetime.datetime.utcfromtimestamp(timestamp_int)
+        issued_at = datetime.datetime.fromtimestamp(
+            timestamp_int, datetime.timezone.utc
+        ).replace(tzinfo=None)
 
         return issued_at
 
@@ -150,9 +153,11 @@ class ReceiptFormatter(object):
         # anywhere, we can't say it isn't being stored somewhere else with
         # those kind of backend constraints.
         if len(receipt) > 255:
-            LOG.info('Fernet receipt created with length of %d '
-                     'characters, which exceeds 255 characters',
-                     len(receipt))
+            LOG.info(
+                'Fernet receipt created with length of %d '
+                'characters, which exceeds 255 characters',
+                len(receipt),
+            )
 
         return receipt
 
@@ -177,7 +182,7 @@ class ReceiptFormatter(object):
         return (user_id, methods, issued_at, expires_at)
 
 
-class ReceiptPayload(object):
+class ReceiptPayload:
 
     @classmethod
     def assemble(cls, user_id, methods, expires_at):
@@ -246,8 +251,12 @@ class ReceiptPayload(object):
 
         """
         time_object = timeutils.parse_isotime(time_string)
-        return (timeutils.normalize_time(time_object) -
-                datetime.datetime.utcfromtimestamp(0)).total_seconds()
+        return (
+            timeutils.normalize_time(time_object)
+            - datetime.datetime.fromtimestamp(
+                0, datetime.timezone.utc
+            ).replace(tzinfo=None)
+        ).total_seconds()
 
     @classmethod
     def _convert_float_to_time_string(cls, time_float):
@@ -257,7 +266,9 @@ class ReceiptPayload(object):
         :returns: a time formatted strings
 
         """
-        time_object = datetime.datetime.utcfromtimestamp(time_float)
+        time_object = datetime.datetime.fromtimestamp(
+            time_float, datetime.timezone.utc
+        ).replace(tzinfo=None)
         return ks_utils.isotime(time_object, subsecond=True)
 
     @classmethod
