@@ -27,6 +27,7 @@ from keystone import identity
 from keystone import limit
 from keystone import oauth1
 from keystone import policy
+from keystone import receipt
 from keystone import resource
 from keystone import revoke
 from keystone import token
@@ -43,18 +44,33 @@ def load_backends():
     cache.configure_cache(region=assignment.COMPUTED_ASSIGNMENTS_REGION)
     cache.configure_cache(region=revoke.REVOKE_REGION)
     cache.configure_cache(region=token.provider.TOKENS_REGION)
+    cache.configure_cache(region=receipt.provider.RECEIPTS_REGION)
     cache.configure_cache(region=identity.ID_MAPPING_REGION)
     cache.configure_invalidation_region()
 
-    managers = [application_credential.Manager, assignment.Manager,
-                catalog.Manager, credential.Manager,
-                credential.provider.Manager, resource.DomainConfigManager,
-                endpoint_policy.Manager, federation.Manager,
-                identity.generator.Manager, identity.MappingManager,
-                identity.Manager, identity.ShadowUsersManager,
-                limit.Manager, oauth1.Manager, policy.Manager,
-                resource.Manager, revoke.Manager, assignment.RoleManager,
-                trust.Manager, token.provider.Manager]
+    managers = [
+        application_credential.Manager,
+        assignment.Manager,
+        catalog.Manager,
+        credential.Manager,
+        credential.provider.Manager,
+        resource.DomainConfigManager,
+        endpoint_policy.Manager,
+        federation.Manager,
+        identity.generator.Manager,
+        identity.MappingManager,
+        identity.Manager,
+        identity.ShadowUsersManager,
+        limit.Manager,
+        oauth1.Manager,
+        policy.Manager,
+        resource.Manager,
+        revoke.Manager,
+        assignment.RoleManager,
+        receipt.provider.Manager,
+        trust.Manager,
+        token.provider.Manager,
+    ]
 
     drivers = {d._provides_api: d() for d in managers}
 
