@@ -11,10 +11,11 @@
 #    under the License.
 
 import datetime
+import http.client
 import uuid
 
-import http.client
 from oslo_serialization import jsonutils
+from oslo_utils import timeutils
 
 from keystone.common.policies import base as base_policy
 from keystone.common import provider_api
@@ -32,14 +33,20 @@ PROVIDERS = provider_api.ProviderAPIs
 class _TestAppCredBase(base_classes.TestCaseWithBootstrap):
     """Base class for application credential tests."""
 
-    def _new_app_cred_data(self, user_id=None, project_id=None, name=None,
-                           expires=None, system=None):
+    def _new_app_cred_data(
+        self,
+        user_id=None,
+        project_id=None,
+        name=None,
+        expires=None,
+        system=None,
+    ):
         if not user_id:
             user_id = self.app_cred_user_id
         if not name:
             name = uuid.uuid4().hex
         if not expires:
-            expires = datetime.datetime.utcnow() + datetime.timedelta(days=365)
+            expires = timeutils.utcnow() + datetime.timedelta(days=365)
         if not system:
             system = uuid.uuid4().hex
         if not project_id:
@@ -56,38 +63,38 @@ class _TestAppCredBase(base_classes.TestCaseWithBootstrap):
                 {'id': self.bootstrapper.member_role_id},
             ],
             'secret': uuid.uuid4().hex,
-            'unrestricted': False
+            'unrestricted': False,
         }
         return app_cred_data
 
     def setUp(self):
-        super(_TestAppCredBase, self).setUp()
+        super().setUp()
 
         # create a user and project for app cred testing
         new_user_ref = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        app_cred_user_ref = PROVIDERS.identity_api.create_user(
-            new_user_ref
-        )
+        app_cred_user_ref = PROVIDERS.identity_api.create_user(new_user_ref)
         self.app_cred_user_id = app_cred_user_ref['id']
         self.app_cred_user_password = new_user_ref['password']
         app_cred_project_ref = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
         self.app_cred_project_id = app_cred_project_ref['id']
         PROVIDERS.assignment_api.create_grant(
             self.bootstrapper.member_role_id,
             user_id=self.app_cred_user_id,
-            project_id=self.app_cred_project_id
+            project_id=self.app_cred_project_id,
         )
 
     def _create_application_credential(self):
         app_cred = self._new_app_cred_data()
-        return \
+        return (
             PROVIDERS.application_credential_api.create_application_credential(
-                app_cred)
+                app_cred
+            )
+        )
 
     def _override_policy(self):
         # TODO(gyee): Remove this once the deprecated policies in
@@ -101,18 +108,22 @@ class _TestAppCredBase(base_classes.TestCaseWithBootstrap):
         with open(self.policy_file_name, 'w') as f:
             overridden_policies = {
                 'identity:get_application_credential': (
-                    base_policy.RULE_SYSTEM_READER_OR_OWNER),
+                    base_policy.RULE_SYSTEM_READER_OR_OWNER
+                ),
                 'identity:list_application_credentials': (
-                    base_policy.RULE_SYSTEM_READER_OR_OWNER),
+                    base_policy.RULE_SYSTEM_READER_OR_OWNER
+                ),
                 'identity:create_application_credential': (
-                    base_policy.RULE_OWNER),
+                    base_policy.RULE_OWNER
+                ),
                 'identity:delete_application_credential': (
-                    base_policy.RULE_SYSTEM_ADMIN_OR_OWNER),
+                    base_policy.RULE_SYSTEM_ADMIN_OR_OWNER
+                ),
             }
             f.write(jsonutils.dumps(overridden_policies))
 
 
-class _DomainAndProjectUserTests(object):
+class _DomainAndProjectUserTests:
     """Domain and project user tests.
 
     Domain and project users should not be able to manage application
@@ -125,62 +136,68 @@ class _DomainAndProjectUserTests(object):
         self._create_application_credential()
 
         with self.test_client() as c:
-            c.get('/v3/users/%s/application_credentials' % (
-                  self.app_cred_user_id),
-                  expected_status_code=http.client.FORBIDDEN,
-                  headers=self.headers)
+            c.get(
+                '/v3/users/%s/application_credentials'
+                % (self.app_cred_user_id),
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_get_application_credential(self):
         app_cred = self._create_application_credential()
 
         with self.test_client() as c:
-            c.get('/v3/users/%s/application_credentials/%s' % (
-                  self.app_cred_user_id,
-                  app_cred['id']),
-                  expected_status_code=http.client.FORBIDDEN,
-                  headers=self.headers)
+            c.get(
+                '/v3/users/%s/application_credentials/%s'
+                % (self.app_cred_user_id, app_cred['id']),
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_lookup_application_credential(self):
         app_cred = self._create_application_credential()
 
         with self.test_client() as c:
-            c.get('/v3/users/%s/application_credentials?name=%s' % (
-                  self.app_cred_user_id,
-                  app_cred['name']),
-                  expected_status_code=http.client.FORBIDDEN,
-                  headers=self.headers)
+            c.get(
+                '/v3/users/%s/application_credentials?name=%s'
+                % (self.app_cred_user_id, app_cred['name']),
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_delete_application_credential(self):
         app_cred = self._create_application_credential()
 
         with self.test_client() as c:
             c.delete(
-                '/v3/users/%s/application_credentials/%s' % (
-                    self.app_cred_user_id,
-                    app_cred['id']),
+                '/v3/users/%s/application_credentials/%s'
+                % (self.app_cred_user_id, app_cred['id']),
                 expected_status_code=http.client.FORBIDDEN,
-                headers=self.headers)
+                headers=self.headers,
+            )
 
     def test_user_cannot_lookup_non_existent_application_credential(self):
         with self.test_client() as c:
-            c.get('/v3/users/%s/application_credentials?name=%s' % (
-                  self.app_cred_user_id,
-                  uuid.uuid4().hex),
-                  expected_status_code=http.client.FORBIDDEN,
-                  headers=self.headers)
+            c.get(
+                '/v3/users/%s/application_credentials?name=%s'
+                % (self.app_cred_user_id, uuid.uuid4().hex),
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_create_app_credential_for_another_user(self):
         # create another user
         another_user = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        another_user_id = PROVIDERS.identity_api.create_user(
-            another_user
-        )['id']
+        another_user_id = PROVIDERS.identity_api.create_user(another_user)[
+            'id'
+        ]
 
         app_cred_body = {
             'application_credential': unit.new_application_credential_ref(
-                roles=[{'id': self.bootstrapper.member_role_id}])
+                roles=[{'id': self.bootstrapper.member_role_id}]
+            )
         }
 
         with self.test_client() as c:
@@ -188,10 +205,11 @@ class _DomainAndProjectUserTests(object):
                 '/v3/users/%s/application_credentials' % another_user_id,
                 json=app_cred_body,
                 expected_status_code=http.client.FORBIDDEN,
-                headers=self.headers)
+                headers=self.headers,
+            )
 
 
-class _SystemUserAndOwnerTests(object):
+class _SystemUserAndOwnerTests:
     """Common default functionality for all system users and owner."""
 
     def test_user_can_list_application_credentials(self):
@@ -201,9 +219,10 @@ class _SystemUserAndOwnerTests(object):
 
         with self.test_client() as c:
             r = c.get(
-                '/v3/users/%s/application_credentials' % (
-                    self.app_cred_user_id),
-                headers=self.headers)
+                '/v3/users/%s/application_credentials'
+                % (self.app_cred_user_id),
+                headers=self.headers,
+            )
             self.assertEqual(2, len(r.json['application_credentials']))
 
     def test_user_can_get_application_credential(self):
@@ -211,10 +230,10 @@ class _SystemUserAndOwnerTests(object):
 
         with self.test_client() as c:
             r = c.get(
-                '/v3/users/%s/application_credentials/%s' % (
-                    self.app_cred_user_id,
-                    app_cred['id']),
-                headers=self.headers)
+                '/v3/users/%s/application_credentials/%s'
+                % (self.app_cred_user_id, app_cred['id']),
+                headers=self.headers,
+            )
             actual_app_cred = r.json['application_credential']
             self.assertEqual(app_cred['id'], actual_app_cred['id'])
 
@@ -223,39 +242,40 @@ class _SystemUserAndOwnerTests(object):
 
         with self.test_client() as c:
             r = c.get(
-                '/v3/users/%s/application_credentials?name=%s' % (
-                    self.app_cred_user_id,
-                    app_cred['name']),
-                headers=self.headers)
+                '/v3/users/%s/application_credentials?name=%s'
+                % (self.app_cred_user_id, app_cred['name']),
+                headers=self.headers,
+            )
             self.assertEqual(1, len(r.json['application_credentials']))
             actual_app_cred = r.json['application_credentials'][0]
             self.assertEqual(app_cred['id'], actual_app_cred['id'])
 
     def _test_delete_application_credential(
-            self,
-            expected_status_code=http.client.NO_CONTENT):
+        self, expected_status_code=http.client.NO_CONTENT
+    ):
         app_cred = self._create_application_credential()
 
         with self.test_client() as c:
             c.delete(
-                '/v3/users/%s/application_credentials/%s' % (
-                    self.app_cred_user_id,
-                    app_cred['id']),
+                '/v3/users/%s/application_credentials/%s'
+                % (self.app_cred_user_id, app_cred['id']),
                 expected_status_code=expected_status_code,
-                headers=self.headers)
+                headers=self.headers,
+            )
 
     def test_user_cannot_create_app_credential_for_another_user(self):
         # create another user
         another_user = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        another_user_id = PROVIDERS.identity_api.create_user(
-            another_user
-        )['id']
+        another_user_id = PROVIDERS.identity_api.create_user(another_user)[
+            'id'
+        ]
 
         app_cred_body = {
             'application_credential': unit.new_application_credential_ref(
-                roles=[{'id': self.bootstrapper.member_role_id}])
+                roles=[{'id': self.bootstrapper.member_role_id}]
+            )
         }
 
         with self.test_client() as c:
@@ -263,15 +283,16 @@ class _SystemUserAndOwnerTests(object):
                 '/v3/users/%s/application_credentials' % another_user_id,
                 json=app_cred_body,
                 expected_status_code=http.client.FORBIDDEN,
-                headers=self.headers)
+                headers=self.headers,
+            )
 
 
-class SystemReaderTests(_TestAppCredBase,
-                        common_auth.AuthTestMixin,
-                        _SystemUserAndOwnerTests):
+class SystemReaderTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _SystemUserAndOwnerTests
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -279,16 +300,15 @@ class SystemReaderTests(_TestAppCredBase,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -300,15 +320,16 @@ class SystemReaderTests(_TestAppCredBase,
 
     def test_system_reader_cannot_delete_application_credential_for_user(self):
         self._test_delete_application_credential(
-            expected_status_code=http.client.FORBIDDEN)
+            expected_status_code=http.client.FORBIDDEN
+        )
 
 
-class SystemMemberTests(_TestAppCredBase,
-                        common_auth.AuthTestMixin,
-                        _SystemUserAndOwnerTests):
+class SystemMemberTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _SystemUserAndOwnerTests
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -316,16 +337,15 @@ class SystemMemberTests(_TestAppCredBase,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -337,15 +357,16 @@ class SystemMemberTests(_TestAppCredBase,
 
     def test_system_reader_cannot_delete_application_credential_for_user(self):
         self._test_delete_application_credential(
-            expected_status_code=http.client.FORBIDDEN)
+            expected_status_code=http.client.FORBIDDEN
+        )
 
 
-class SystemAdminTests(_TestAppCredBase,
-                       common_auth.AuthTestMixin,
-                       _SystemUserAndOwnerTests):
+class SystemAdminTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _SystemUserAndOwnerTests
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -354,7 +375,7 @@ class SystemAdminTests(_TestAppCredBase,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -368,12 +389,12 @@ class SystemAdminTests(_TestAppCredBase,
         self._test_delete_application_credential()
 
 
-class OwnerTests(_TestAppCredBase,
-                 common_auth.AuthTestMixin,
-                 _SystemUserAndOwnerTests):
+class OwnerTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _SystemUserAndOwnerTests
+):
 
     def setUp(self):
-        super(OwnerTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -393,7 +414,7 @@ class OwnerTests(_TestAppCredBase,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.app_cred_user_password,
-            project_id=self.app_cred_project_id
+            project_id=self.app_cred_project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -413,7 +434,8 @@ class OwnerTests(_TestAppCredBase,
                 '/v3/users/%s/application_credentials' % self.user_id,
                 json=app_cred_body,
                 expected_status_code=http.client.CREATED,
-                headers=self.headers)
+                headers=self.headers,
+            )
 
     def test_owner_can_delete_application_credential(self):
         self._test_delete_application_credential()
@@ -423,13 +445,12 @@ class OwnerTests(_TestAppCredBase,
         another_user = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        another_user_id = PROVIDERS.identity_api.create_user(
-            another_user
-        )['id']
+        another_user_id = PROVIDERS.identity_api.create_user(another_user)[
+            'id'
+        ]
 
         auth = self.build_authentication_request(
-            user_id=another_user_id,
-            password=another_user['password']
+            user_id=another_user_id, password=another_user['password']
         )
 
         # authenticate for a token as a completely different user with
@@ -445,24 +466,23 @@ class OwnerTests(_TestAppCredBase,
         # attempt to lookup the application credential as another user
         with self.test_client() as c:
             c.get(
-                '/v3/users/%s/application_credentials/%s' % (
-                    another_user_id,
-                    app_cred['id']),
+                '/v3/users/%s/application_credentials/%s'
+                % (another_user_id, app_cred['id']),
                 expected_status_code=http.client.FORBIDDEN,
-                headers={'X-Auth-Token': another_user_token})
+                headers={'X-Auth-Token': another_user_token},
+            )
 
     def test_user_cannot_delete_application_credential_for_another_user(self):
         # create another user
         another_user = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        another_user_id = PROVIDERS.identity_api.create_user(
-            another_user
-        )['id']
+        another_user_id = PROVIDERS.identity_api.create_user(another_user)[
+            'id'
+        ]
 
         auth = self.build_authentication_request(
-            user_id=another_user_id,
-            password=another_user['password']
+            user_id=another_user_id, password=another_user['password']
         )
 
         # authenticate for a token as a completely different user with
@@ -478,19 +498,19 @@ class OwnerTests(_TestAppCredBase,
         # attempt to delete the application credential as another user
         with self.test_client() as c:
             c.delete(
-                '/v3/users/%s/application_credentials/%s' % (
-                    another_user_id,
-                    app_cred['id']),
+                '/v3/users/%s/application_credentials/%s'
+                % (another_user_id, app_cred['id']),
                 expected_status_code=http.client.FORBIDDEN,
-                headers={'X-Auth-Token': another_user_token})
+                headers={'X-Auth-Token': another_user_token},
+            )
 
 
-class DomainAdminTests(_TestAppCredBase,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserTests):
+class DomainAdminTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(DomainAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -505,16 +525,19 @@ class DomainAdminTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         domain_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=CONF.identity.default_domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=CONF.identity.default_domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
-            domain_id=CONF.identity.default_domain_id
+            user_id=self.user_id,
+            password=domain_admin['password'],
+            domain_id=CONF.identity.default_domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -525,12 +548,12 @@ class DomainAdminTests(_TestAppCredBase,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class DomainReaderTests(_TestAppCredBase,
-                        common_auth.AuthTestMixin,
-                        _DomainAndProjectUserTests):
+class DomainReaderTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(DomainReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -545,16 +568,19 @@ class DomainReaderTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         domain_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            domain_id=CONF.identity.default_domain_id
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            domain_id=CONF.identity.default_domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
-            domain_id=CONF.identity.default_domain_id
+            user_id=self.user_id,
+            password=domain_admin['password'],
+            domain_id=CONF.identity.default_domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -565,12 +591,12 @@ class DomainReaderTests(_TestAppCredBase,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class DomainMemberTests(_TestAppCredBase,
-                        common_auth.AuthTestMixin,
-                        _DomainAndProjectUserTests):
+class DomainMemberTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(DomainMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -585,16 +611,19 @@ class DomainMemberTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         domain_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            domain_id=CONF.identity.default_domain_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            domain_id=CONF.identity.default_domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
-            domain_id=CONF.identity.default_domain_id
+            user_id=self.user_id,
+            password=domain_admin['password'],
+            domain_id=CONF.identity.default_domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -605,12 +634,12 @@ class DomainMemberTests(_TestAppCredBase,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectAdminTests(_TestAppCredBase,
-                        common_auth.AuthTestMixin,
-                        _DomainAndProjectUserTests):
+class ProjectAdminTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -625,18 +654,20 @@ class ProjectAdminTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         project_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(project_admin)['id']
         # even project admin of project where the app credential
         # is intended for cannot perform app credential operations
         PROVIDERS.assignment_api.create_grant(
             self.bootstrapper.admin_role_id,
             user_id=self.user_id,
-            project_id=self.app_cred_project_id
+            project_id=self.app_cred_project_id,
         )
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=project_admin['password'],
-            project_id=self.app_cred_project_id
+            user_id=self.user_id,
+            password=project_admin['password'],
+            project_id=self.app_cred_project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -647,12 +678,12 @@ class ProjectAdminTests(_TestAppCredBase,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectReaderTests(_TestAppCredBase,
-                         common_auth.AuthTestMixin,
-                         _DomainAndProjectUserTests):
+class ProjectReaderTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -667,18 +698,20 @@ class ProjectReaderTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         project_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(project_admin)['id']
         # even project admin of project where the app credential
         # is intended for cannot perform app credential operations
         PROVIDERS.assignment_api.create_grant(
             self.bootstrapper.reader_role_id,
             user_id=self.user_id,
-            project_id=self.app_cred_project_id
+            project_id=self.app_cred_project_id,
         )
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=project_admin['password'],
-            project_id=self.app_cred_project_id
+            user_id=self.user_id,
+            password=project_admin['password'],
+            project_id=self.app_cred_project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -689,12 +722,12 @@ class ProjectReaderTests(_TestAppCredBase,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectMemberTests(_TestAppCredBase,
-                         common_auth.AuthTestMixin,
-                         _DomainAndProjectUserTests):
+class ProjectMemberTests(
+    _TestAppCredBase, common_auth.AuthTestMixin, _DomainAndProjectUserTests
+):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -709,18 +742,20 @@ class ProjectMemberTests(_TestAppCredBase,
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
 
         project_admin = unit.new_user_ref(
-            domain_id=CONF.identity.default_domain_id)
+            domain_id=CONF.identity.default_domain_id
+        )
         self.user_id = PROVIDERS.identity_api.create_user(project_admin)['id']
         # even project admin of project where the app credential
         # is intended for cannot perform app credential operations
         PROVIDERS.assignment_api.create_grant(
             self.bootstrapper.member_role_id,
             user_id=self.user_id,
-            project_id=self.app_cred_project_id
+            project_id=self.app_cred_project_id,
         )
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=project_admin['password'],
-            project_id=self.app_cred_project_id
+            user_id=self.user_id,
+            password=project_admin['password'],
+            project_id=self.app_cred_project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
