@@ -10,9 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
 import http.client
+import uuid
 
 from keystone.common import provider_api
 import keystone.conf
@@ -25,58 +24,62 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserOauth1ConsumerTests(object):
+class _SystemUserOauth1ConsumerTests:
     """Common default functionality for all system users."""
 
     def test_user_can_get_consumer(self):
-        ref = PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        ref = PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.get('/v3/OS-OAUTH1/consumers/%s' % ref['id'],
-                  headers=self.headers)
+            c.get(
+                '/v3/OS-OAUTH1/consumers/%s' % ref['id'], headers=self.headers
+            )
 
     def test_user_can_list_consumers(self):
-        PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.get('/v3/OS-OAUTH1/consumers',
-                  headers=self.headers)
+            c.get('/v3/OS-OAUTH1/consumers', headers=self.headers)
 
 
-class _SystemReaderAndMemberOauth1ConsumerTests(object):
+class _SystemReaderAndMemberOauth1ConsumerTests:
 
     def test_user_cannot_create_consumer(self):
         with self.test_client() as c:
-            c.post('/v3/OS-OAUTH1/consumers',
-                   json={'consumer': {}},
-                   expected_status_code=http.client.FORBIDDEN,
-                   headers=self.headers)
+            c.post(
+                '/v3/OS-OAUTH1/consumers',
+                json={'consumer': {}},
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_update_consumer(self):
-        ref = PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        ref = PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.patch('/v3/OS-OAUTH1/consumers/%s' % ref['id'],
-                    json={'consumer': {'description': uuid.uuid4().hex}},
-                    expected_status_code=http.client.FORBIDDEN,
-                    headers=self.headers)
+            c.patch(
+                '/v3/OS-OAUTH1/consumers/%s' % ref['id'],
+                json={'consumer': {'description': uuid.uuid4().hex}},
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
     def test_user_cannot_delete_consumer(self):
-        ref = PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        ref = PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.delete('/v3/OS-OAUTH1/consumers/%s' % ref['id'],
-                     expected_status_code=http.client.FORBIDDEN,
-                     headers=self.headers)
+            c.delete(
+                '/v3/OS-OAUTH1/consumers/%s' % ref['id'],
+                expected_status_code=http.client.FORBIDDEN,
+                headers=self.headers,
+            )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserOauth1ConsumerTests,
-                        _SystemReaderAndMemberOauth1ConsumerTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserOauth1ConsumerTests,
+    _SystemReaderAndMemberOauth1ConsumerTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -84,16 +87,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -104,13 +106,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserOauth1ConsumerTests,
-                        _SystemReaderAndMemberOauth1ConsumerTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserOauth1ConsumerTests,
+    _SystemReaderAndMemberOauth1ConsumerTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -118,16 +122,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -138,12 +141,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserOauth1ConsumerTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserOauth1ConsumerTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -154,7 +159,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -166,21 +171,24 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
     def test_user_can_create_consumer(self):
         with self.test_client() as c:
-            c.post('/v3/OS-OAUTH1/consumers',
-                   json={'consumer': {}},
-                   headers=self.headers)
+            c.post(
+                '/v3/OS-OAUTH1/consumers',
+                json={'consumer': {}},
+                headers=self.headers,
+            )
 
     def test_user_can_update_consumer(self):
-        ref = PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        ref = PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.patch('/v3/OS-OAUTH1/consumers/%s' % ref['id'],
-                    json={'consumer': {'description': uuid.uuid4().hex}},
-                    headers=self.headers)
+            c.patch(
+                '/v3/OS-OAUTH1/consumers/%s' % ref['id'],
+                json={'consumer': {'description': uuid.uuid4().hex}},
+                headers=self.headers,
+            )
 
     def test_user_can_delete_consumer(self):
-        ref = PROVIDERS.oauth_api.create_consumer(
-            {'id': uuid.uuid4().hex})
+        ref = PROVIDERS.oauth_api.create_consumer({'id': uuid.uuid4().hex})
         with self.test_client() as c:
-            c.delete('/v3/OS-OAUTH1/consumers/%s' % ref['id'],
-                     headers=self.headers)
+            c.delete(
+                '/v3/OS-OAUTH1/consumers/%s' % ref['id'], headers=self.headers
+            )
