@@ -10,9 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
 import http.client
+import uuid
 
 from keystone.common import provider_api
 import keystone.conf
@@ -25,24 +24,26 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserDomainRoleTests(object):
+class _SystemUserDomainRoleTests:
     """Common default functionality for all system users."""
 
     def test_user_can_list_domain_roles(self):
         PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id))
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
+        )
 
         with self.test_client() as c:
             r = c.get(
                 '/v3/roles?domain_id=%s' % CONF.identity.default_domain_id,
-                headers=self.headers)
+                headers=self.headers,
+            )
             self.assertEqual(1, len(r.json['roles']))
 
     def test_user_can_get_a_domain_role(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         with self.test_client() as c:
@@ -50,116 +51,137 @@ class _SystemUserDomainRoleTests(object):
             self.assertEqual(role['id'], r.json['role']['id'])
 
 
-class _SystemReaderAndMemberDomainRoleTests(object):
+class _SystemReaderAndMemberDomainRoleTests:
     """Common default functionality for system readers and system members."""
 
     def test_user_cannot_create_domain_roles(self):
-        create = {'role': unit.new_role_ref(
-            domain_id=CONF.identity.default_domain_id)}
+        create = {
+            'role': unit.new_role_ref(
+                domain_id=CONF.identity.default_domain_id
+            )
+        }
 
         with self.test_client() as c:
             c.post(
-                '/v3/roles', json=create, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_domain_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         update = {'role': {'description': uuid.uuid4().hex}}
 
         with self.test_client() as c:
             c.patch(
-                '/v3/roles/%s' % role['id'], json=update, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles/%s' % role['id'],
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_domain_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         with self.test_client() as c:
             c.delete(
-                '/v3/roles/%s' % role['id'], headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles/%s' % role['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserDomainRoleTests(object):
+class _DomainAndProjectUserDomainRoleTests:
     """Common functionality for all domain and project users."""
 
     def test_user_cannot_list_domain_roles(self):
         PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id))
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
+        )
 
         with self.test_client() as c:
             c.get(
-                '/v3/roles', headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_a_domain_role(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         with self.test_client() as c:
             c.get(
-                '/v3/roles/%s' % role['id'], headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles/%s' % role['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_domain_roles(self):
-        create = {'role': unit.new_role_ref(
-            domain_id=CONF.identity.default_domain_id)}
+        create = {
+            'role': unit.new_role_ref(
+                domain_id=CONF.identity.default_domain_id
+            )
+        }
 
         with self.test_client() as c:
             c.post(
-                '/v3/roles', json=create, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_domain_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         update = {'role': {'description': uuid.uuid4().hex}}
 
         with self.test_client() as c:
             c.patch(
-                '/v3/roles/%s' % role['id'], json=update, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles/%s' % role['id'],
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_domain_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         with self.test_client() as c:
             c.delete(
-                '/v3/roles/%s' % role['id'], headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/roles/%s' % role['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserDomainRoleTests,
-                        _SystemReaderAndMemberDomainRoleTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserDomainRoleTests,
+    _SystemReaderAndMemberDomainRoleTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -167,16 +189,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -187,13 +208,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserDomainRoleTests,
-                        _SystemReaderAndMemberDomainRoleTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserDomainRoleTests,
+    _SystemReaderAndMemberDomainRoleTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -201,16 +224,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -221,12 +243,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserDomainRoleTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserDomainRoleTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -237,7 +261,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -248,8 +272,11 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
     def test_user_can_create_roles(self):
-        create = {'role': unit.new_role_ref(
-            domain_id=CONF.identity.default_domain_id)}
+        create = {
+            'role': unit.new_role_ref(
+                domain_id=CONF.identity.default_domain_id
+            )
+        }
 
         with self.test_client() as c:
             c.post('/v3/roles', json=create, headers=self.headers)
@@ -257,32 +284,36 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
     def test_user_can_update_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         update = {'role': {'description': uuid.uuid4().hex}}
 
         with self.test_client() as c:
             c.patch(
-                '/v3/roles/%s' % role['id'], json=update, headers=self.headers,
+                '/v3/roles/%s' % role['id'],
+                json=update,
+                headers=self.headers,
             )
 
     def test_user_can_delete_roles(self):
         role = PROVIDERS.role_api.create_role(
             uuid.uuid4().hex,
-            unit.new_role_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_role_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         with self.test_client() as c:
             c.delete('/v3/roles/%s' % role['id'], headers=self.headers)
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserDomainRoleTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserDomainRoleTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -294,14 +325,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -312,12 +344,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserDomainRoleTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserDomainRoleTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -326,7 +360,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -338,12 +372,13 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _DomainAndProjectUserDomainRoleTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserDomainRoleTests,
+):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
 
@@ -362,14 +397,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
