@@ -10,8 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
+
 from oslo_serialization import jsonutils
-from six.moves import http_client
 
 from keystone.common.policies import base as bp
 from keystone.common import provider_api
@@ -26,7 +27,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _UserEC2CredentialTests(object):
+class _UserEC2CredentialTests:
 
     def test_user_can_get_their_ec2_credentials(self):
         project = unit.new_project_ref(
@@ -34,21 +35,26 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            r = c.post('/v3/users/%s/credentials/OS-EC2' % self.user_id,
-                       json={'tenant_id': project['id']}, headers=self.headers)
+            r = c.post(
+                '/v3/users/%s/credentials/OS-EC2' % self.user_id,
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+            )
 
             credential_id = r.json['credential']['access']
 
-            path = '/v3/users/%s/credentials/OS-EC2/%s' % (self.user_id, credential_id)
-            r = c.get(path, headers=self.headers)
-            self.assertEqual(
-                self.user_id, r.json['credential']['user_id']
+            path = '/v3/users/{}/credentials/OS-EC2/{}'.format(
+                self.user_id,
+                credential_id,
             )
+            r = c.get(path, headers=self.headers)
+            self.assertEqual(self.user_id, r.json['credential']['user_id'])
 
     def test_user_can_list_their_ec2_credentials(self):
         project = unit.new_project_ref(
@@ -56,20 +62,22 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            c.post('/v3/users/%s/credentials/OS-EC2' % self.user_id,
-                   json={'tenant_id': project['id']}, headers=self.headers)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % self.user_id,
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+            )
 
             path = '/v3/users/%s/credentials/OS-EC2' % self.user_id
             r = c.get(path, headers=self.headers)
             for credential in r.json['credentials']:
-                self.assertEqual(
-                    self.user_id, credential['user_id']
-                )
+                self.assertEqual(self.user_id, credential['user_id'])
 
     def test_user_create_their_ec2_credentials(self):
         project = unit.new_project_ref(
@@ -77,14 +85,18 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            c.post('/v3/users/%s/credentials/OS-EC2' % self.user_id,
-                   json={'tenant_id': project['id']}, headers=self.headers,
-                   expected_status_code=http_client.CREATED)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % self.user_id,
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+                expected_status_code=http.client.CREATED,
+            )
 
     def test_user_delete_their_ec2_credentials(self):
         project = unit.new_project_ref(
@@ -92,17 +104,24 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            r = c.post('/v3/users/%s/credentials/OS-EC2' % self.user_id,
-                       json={'tenant_id': project['id']}, headers=self.headers)
+            r = c.post(
+                '/v3/users/%s/credentials/OS-EC2' % self.user_id,
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+            )
             credential_id = r.json['credential']['access']
 
-            c.delete('/v3/users/%s/credentials/OS-EC2/%s' % (self.user_id, credential_id),
-                     headers=self.headers)
+            c.delete(
+                '/v3/users/%s/credentials/OS-EC2/%s'
+                % (self.user_id, credential_id),
+                headers=self.headers,
+            )
 
     def test_user_cannot_create_ec2_credentials_for_others(self):
         user = PROVIDERS.identity_api.create_user(
@@ -113,14 +132,18 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                   json={'tenant_id': project['id']}, headers=self.headers,
-                   expected_status_code=http_client.FORBIDDEN)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_delete_ec2_credentials_for_others(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -131,27 +154,36 @@ class _UserEC2CredentialTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
         user_auth = self.build_authentication_request(
-            user_id=user['id'], password=user_password,
-            project_id=project['id']
+            user_id=user['id'],
+            password=user_password,
+            project_id=project['id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=user_auth)
             token_id = r.headers['X-Subject-Token']
             headers = {'X-Auth-Token': token_id}
 
-            r = c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                       json={'tenant_id': project['id']}, headers=headers)
+            r = c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=headers,
+            )
             credential_id = r.json['credential']['access']
 
-            c.delete('/v3/users/%s/credentials/OS-EC2/%s' % (self.user_id, credential_id),
-                     headers=self.headers, expected_status_code=http_client.FORBIDDEN)
+            c.delete(
+                '/v3/users/%s/credentials/OS-EC2/%s'
+                % (self.user_id, credential_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
 
-class _SystemUserTests(object):
+class _SystemUserTests:
 
     def test_user_can_get_ec2_credentials_for_others(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -162,27 +194,37 @@ class _SystemUserTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
         user_auth = self.build_authentication_request(
-            user_id=user['id'], password=user_password,
-            project_id=project['id']
+            user_id=user['id'],
+            password=user_password,
+            project_id=project['id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=user_auth)
             token_id = r.headers['X-Subject-Token']
             headers = {'X-Auth-Token': token_id}
 
-            r = c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                       json={'tenant_id': project['id']}, headers=headers)
+            r = c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=headers,
+            )
             credential_id = r.json['credential']['access']
 
-            path = '/v3/users/%s/credentials/OS-EC2/%s' % (self.user_id, credential_id)
-            c.get(path, headers=self.headers, expected_status_code=http_client.OK)
+            path = '/v3/users/{}/credentials/OS-EC2/{}'.format(
+                self.user_id,
+                credential_id,
+            )
+            c.get(
+                path, headers=self.headers, expected_status_code=http.client.OK
+            )
 
 
-class _SystemReaderAndMemberTests(object):
+class _SystemReaderAndMemberTests:
 
     def test_user_cannot_list_ec2_credentials_for_others(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -193,33 +235,40 @@ class _SystemReaderAndMemberTests(object):
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
         user_auth = self.build_authentication_request(
-            user_id=user['id'], password=user_password,
-            project_id=project['id']
+            user_id=user['id'],
+            password=user_password,
+            project_id=project['id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=user_auth)
             token_id = r.headers['X-Subject-Token']
             headers = {'X-Auth-Token': token_id}
 
-            c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                   json={'tenant_id': project['id']}, headers=headers)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=headers,
+            )
 
             path = '/v3/users/%s/credentials/OS-EC2' % self.user_id
             r = c.get(path, headers=self.headers)
             self.assertEqual([], r.json['credentials'])
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTests,
-                        _SystemReaderAndMemberTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+    _SystemReaderAndMemberTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -227,16 +276,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -247,13 +295,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTests,
-                        _SystemReaderAndMemberTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+    _SystemReaderAndMemberTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -261,16 +311,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -281,12 +330,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -297,7 +348,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -316,20 +367,25 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
         user_auth = self.build_authentication_request(
-            user_id=user['id'], password=user_password,
-            project_id=project['id']
+            user_id=user['id'],
+            password=user_password,
+            project_id=project['id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=user_auth)
             token_id = r.headers['X-Subject-Token']
             headers = {'X-Auth-Token': token_id}
 
-            c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                   json={'tenant_id': project['id']}, headers=headers)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=headers,
+            )
 
             path = '/v3/users/%s/credentials/OS-EC2' % self.user_id
             r = c.get(path, headers=self.headers)
@@ -344,13 +400,17 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
-            c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                   json={'tenant_id': project['id']}, headers=self.headers)
+            c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=self.headers,
+            )
 
     def test_user_can_delete_ec2_credentials_for_others(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -361,30 +421,40 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         )
         project = PROVIDERS.resource_api.create_project(project['id'], project)
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
         user_auth = self.build_authentication_request(
-            user_id=user['id'], password=user_password,
-            project_id=project['id']
+            user_id=user['id'],
+            password=user_password,
+            project_id=project['id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=user_auth)
             token_id = r.headers['X-Subject-Token']
             headers = {'X-Auth-Token': token_id}
 
-            r = c.post('/v3/users/%s/credentials/OS-EC2' % user['id'],
-                       json={'tenant_id': project['id']}, headers=headers)
+            r = c.post(
+                '/v3/users/%s/credentials/OS-EC2' % user['id'],
+                json={'tenant_id': project['id']},
+                headers=headers,
+            )
             credential_id = r.json['credential']['access']
 
-            c.delete('/v3/users/%s/credentials/OS-EC2/%s' % (self.user_id, credential_id),
-                     headers=self.headers)
+            c.delete(
+                '/v3/users/%s/credentials/OS-EC2/%s'
+                % (self.user_id, credential_id),
+                headers=self.headers,
+            )
 
 
-class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _UserEC2CredentialTests,
-                        _SystemReaderAndMemberTests):
+class ProjectAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _UserEC2CredentialTests,
+    _SystemReaderAndMemberTests,
+):
 
     def _override_policy(self):
         # TODO(cmurphy): Remove this once the deprecated policies in
@@ -395,18 +465,21 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
         # update permissions or update policies without breaking users. This
         # will cause these specific tests to fail since we're trying to correct
         # this broken behavior with better scope checking.
+        reader_or_cred_owner = bp.ADMIN_OR_SYSTEM_READER_OR_CRED_OWNER
+        reader_or_owner = bp.RULE_SYSTEM_READER_OR_OWNER
+        admin_or_cred_owner = bp.ADMIN_OR_CRED_OWNER
         with open(self.policy_file_name, 'w') as f:
             overridden_policies = {
-                'identity:ec2_get_credential': bp.SYSTEM_READER_OR_CRED_OWNER,
-                'identity:ec2_list_credentials': bp.RULE_SYSTEM_READER_OR_OWNER,
-                'identity:ec2_create_credential': bp.SYSTEM_ADMIN_OR_CRED_OWNER,
-                'identity:ec2_update_credential': bp.SYSTEM_ADMIN_OR_CRED_OWNER,
-                'identity:ec2_delete_credential': bp.SYSTEM_ADMIN_OR_CRED_OWNER
+                'identity:ec2_get_credential': reader_or_cred_owner,
+                'identity:ec2_list_credentials': reader_or_owner,
+                'identity:ec2_create_credential': admin_or_cred_owner,
+                'identity:ec2_update_credential': admin_or_cred_owner,
+                'identity:ec2_delete_credential': admin_or_cred_owner,
             }
             f.write(jsonutils.dumps(overridden_policies))
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -425,7 +498,7 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
