@@ -10,10 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-from six.moves import http_client
-
 from keystone.common import provider_api
 import keystone.conf
 from keystone.tests.common import auth as common_auth
@@ -37,17 +36,17 @@ def _create_limits_and_dependencies(domain_id=None):
     registered_limit = unit.new_registered_limit_ref(
         service_id=service['id'], id=uuid.uuid4().hex
     )
-    registered_limits = (
-        PROVIDERS.unified_limit_api.create_registered_limits(
-            [registered_limit]
-        )
+    registered_limits = PROVIDERS.unified_limit_api.create_registered_limits(
+        [registered_limit]
     )
     registered_limit = registered_limits[0]
 
     domain_limit = unit.new_limit_ref(
-        domain_id=domain_id, service_id=service['id'],
+        domain_id=domain_id,
+        service_id=service['id'],
         resource_name=registered_limit['resource_name'],
-        resource_limit=10, id=uuid.uuid4().hex
+        resource_limit=10,
+        id=uuid.uuid4().hex,
     )
 
     project = PROVIDERS.resource_api.create_project(
@@ -55,9 +54,11 @@ def _create_limits_and_dependencies(domain_id=None):
     )
 
     project_limit = unit.new_limit_ref(
-        project_id=project['id'], service_id=service['id'],
+        project_id=project['id'],
+        service_id=service['id'],
         resource_name=registered_limit['resource_name'],
-        resource_limit=5, id=uuid.uuid4().hex
+        resource_limit=5,
+        id=uuid.uuid4().hex,
     )
     limits = PROVIDERS.unified_limit_api.create_limits(
         [domain_limit, project_limit]
@@ -74,7 +75,7 @@ def _create_limits_and_dependencies(domain_id=None):
     return (project_limit_id, domain_limit_id)
 
 
-class _UserLimitTests(object):
+class _UserLimitTests:
     """Common default functionality for all users except system admins."""
 
     def test_user_can_get_limit_model(self):
@@ -118,23 +119,26 @@ class _UserLimitTests(object):
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         create = {
             'limits': [
                 unit.new_limit_ref(
-                    project_id=project['id'], service_id=service['id'],
+                    project_id=project['id'],
+                    service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits(self):
@@ -144,9 +148,10 @@ class _UserLimitTests(object):
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % limit_id, json=update,
+                '/v3/limits/%s' % limit_id,
+                json=update,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits(self):
@@ -156,15 +161,17 @@ class _UserLimitTests(object):
             c.delete(
                 '/v3/limits/%s' % limit_id,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _UserLimitTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _UserLimitTests,
+):
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -172,16 +179,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -192,12 +198,14 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _UserLimitTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _UserLimitTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -205,16 +213,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -225,11 +232,12 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap, common_auth.AuthTestMixin
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -240,7 +248,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -287,15 +295,16 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         create = {
             'limits': [
                 unit.new_limit_ref(
-                    project_id=project['id'], service_id=service['id'],
+                    project_id=project['id'],
+                    service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
@@ -310,8 +319,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % limit_id, json=update,
-                headers=self.headers
+                '/v3/limits/%s' % limit_id, json=update, headers=self.headers
             )
 
     def test_user_can_delete_limits(self):
@@ -321,11 +329,12 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
             c.delete('/v3/limits/%s' % limit_id, headers=self.headers)
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap, common_auth.AuthTestMixin
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -337,14 +346,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -376,8 +386,9 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.get(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_domain_limits_for_other_domain(self):
@@ -385,8 +396,9 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.get(
-                '/v3/limits/%s' % domain_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % domain_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_can_list_limits_within_domain(self):
@@ -429,17 +441,20 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         create = {
             'limits': [
                 unit.new_limit_ref(
-                    domain_id=self.domain_id, service_id=service['id'],
+                    domain_id=self.domain_id,
+                    service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_limits_for_other_domain(self):
@@ -463,15 +478,17 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
                     domain_id=CONF.identity.default_domain_id,
                     service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_limits_for_projects_in_domain(self):
@@ -499,15 +516,17 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
                     project_id=project['id'],
                     service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_limits_for_projects_outside_domain(self):
@@ -527,7 +546,7 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         create = {
@@ -536,15 +555,17 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
                     project_id=project['id'],
                     service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits_for_domain(self):
@@ -556,9 +577,10 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % domain_limit_id, json=update,
+                '/v3/limits/%s' % domain_limit_id,
+                json=update,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits_for_other_domain(self):
@@ -568,9 +590,10 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % domain_limit_id, json=update,
+                '/v3/limits/%s' % domain_limit_id,
+                json=update,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits_for_projects_in_domain(self):
@@ -582,8 +605,10 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                json=update, expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits_for_projects_outside_domain(self):
@@ -593,8 +618,10 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                json=update, expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits_for_domain(self):
@@ -604,8 +631,9 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/limits/%s' % domain_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % domain_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits_for_other_domain(self):
@@ -613,8 +641,9 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/limits/%s' % domain_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % domain_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits_for_projects_in_domain(self):
@@ -624,8 +653,9 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits_for_projects_outside_domain(self):
@@ -633,16 +663,18 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap, common_auth.AuthTestMixin
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -653,7 +685,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -671,13 +703,14 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         # project if they actually have a role assignment on the project and
         # call the API with a project-scoped token.
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=limit['project_id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=limit['project_id'],
         )
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=limit['project_id']
+            project_id=limit['project_id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=auth)
@@ -692,8 +725,9 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.get(
-                '/v3/limits/%s' % project_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % project_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_domain_limit(self):
@@ -701,8 +735,9 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.get(
-                '/v3/limits/%s' % domain_limit_id, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits/%s' % domain_limit_id,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_can_list_limits(self):
@@ -713,13 +748,14 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         # project if they actually have a role assignment on the project and
         # call the API with a project-scoped token.
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=limit['project_id']
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=limit['project_id'],
         )
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=limit['project_id']
+            project_id=limit['project_id'],
         )
         with self.test_client() as c:
             r = c.post('/v3/auth/tokens', json=auth)
@@ -759,23 +795,26 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         create = {
             'limits': [
                 unit.new_limit_ref(
-                    project_id=project['id'], service_id=service['id'],
+                    project_id=project['id'],
+                    service_id=service['id'],
                     resource_name=registered_limit['resource_name'],
-                    resource_limit=5
+                    resource_limit=5,
                 )
             ]
         }
 
         with self.test_client() as c:
             c.post(
-                '/v3/limits', json=create, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/limits',
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_limits(self):
@@ -785,9 +824,10 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/limits/%s' % limit_id, json=update,
+                '/v3/limits/%s' % limit_id,
+                json=update,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_limits(self):
@@ -797,12 +837,12 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
             c.delete(
                 '/v3/limits/%s' % limit_id,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
 class ProjectUserTestsWithoutEnforceScope(ProjectUserTests):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.config_fixture.config(group='oslo_policy', enforce_scope=False)
