@@ -10,10 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-from six.moves import http_client
-
 from keystone.common import provider_api
 import keystone.conf
 from keystone.tests.common import auth as common_auth
@@ -25,7 +24,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserMappingTests(object):
+class _SystemUserMappingTests:
     """Common default functionality for all system users."""
 
     def test_user_can_list_mappings(self):
@@ -48,30 +47,33 @@ class _SystemUserMappingTests(object):
         with self.test_client() as c:
             c.get(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                headers=self.headers
+                headers=self.headers,
             )
 
 
-class _SystemReaderAndMemberUserMappingTests(object):
+class _SystemReaderAndMemberUserMappingTests:
     """Common default functionality for system readers and system members."""
 
     def test_user_cannot_create_mappings(self):
         create = {
             'mapping': {
                 'id': uuid.uuid4().hex,
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ],
             }
         }
         mapping_id = create['mapping']['id']
 
         with self.test_client() as c:
             c.put(
-                '/v3/OS-FEDERATION/mappings/%s' % mapping_id, json=create,
+                '/v3/OS-FEDERATION/mappings/%s' % mapping_id,
+                json=create,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_mappings(self):
@@ -82,18 +84,21 @@ class _SystemReaderAndMemberUserMappingTests(object):
 
         update = {
             'mapping': {
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ]
             }
         }
 
         with self.test_client() as c:
             c.patch(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                json=update, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_mappings(self):
@@ -106,29 +111,32 @@ class _SystemReaderAndMemberUserMappingTests(object):
             c.delete(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserMappingTests(object):
+class _DomainAndProjectUserMappingTests:
 
     def test_user_cannot_create_mappings(self):
         create = {
             'mapping': {
                 'id': uuid.uuid4().hex,
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ],
             }
         }
         mapping_id = create['mapping']['id']
 
         with self.test_client() as c:
             c.put(
-                '/v3/OS-FEDERATION/mappings/%s' % mapping_id, json=create,
+                '/v3/OS-FEDERATION/mappings/%s' % mapping_id,
+                json=create,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_mappings(self):
@@ -139,8 +147,9 @@ class _DomainAndProjectUserMappingTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/OS-FEDERATION/mappings', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/OS-FEDERATION/mappings',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_a_mapping(self):
@@ -153,7 +162,7 @@ class _DomainAndProjectUserMappingTests(object):
             c.get(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_mappings(self):
@@ -164,18 +173,21 @@ class _DomainAndProjectUserMappingTests(object):
 
         update = {
             'mapping': {
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ]
             }
         }
 
         with self.test_client() as c:
             c.patch(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                json=update, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_mappings(self):
@@ -188,17 +200,19 @@ class _DomainAndProjectUserMappingTests(object):
             c.delete(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserMappingTests,
-                        _SystemReaderAndMemberUserMappingTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserMappingTests,
+    _SystemReaderAndMemberUserMappingTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -206,16 +220,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -229,19 +242,22 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         create = {
             'mapping': {
                 'id': uuid.uuid4().hex,
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ],
             }
         }
         mapping_id = create['mapping']['id']
 
         with self.test_client() as c:
             c.put(
-                '/v3/OS-FEDERATION/mappings/%s' % mapping_id, json=create,
+                '/v3/OS-FEDERATION/mappings/%s' % mapping_id,
+                json=create,
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_mappings(self):
@@ -252,18 +268,21 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
 
         update = {
             'mapping': {
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ]
             }
         }
 
         with self.test_client() as c:
             c.patch(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                json=update, headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_mappings(self):
@@ -276,17 +295,19 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             c.delete(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserMappingTests,
-                        _SystemReaderAndMemberUserMappingTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserMappingTests,
+    _SystemReaderAndMemberUserMappingTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -294,16 +315,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -314,12 +334,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserMappingTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserMappingTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -330,7 +352,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -344,18 +366,22 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         create = {
             'mapping': {
                 'id': uuid.uuid4().hex,
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ],
             }
         }
         mapping_id = create['mapping']['id']
 
         with self.test_client() as c:
             c.put(
-                '/v3/OS-FEDERATION/mappings/%s' % mapping_id, json=create,
-                headers=self.headers, expected_status_code=http_client.CREATED
+                '/v3/OS-FEDERATION/mappings/%s' % mapping_id,
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_mappings(self):
@@ -366,17 +392,20 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         update = {
             'mapping': {
-                'rules': [{
-                    'local': [{'user': {'name': '{0}'}}],
-                    'remote': [{'type': 'UserName'}],
-                }]
+                'rules': [
+                    {
+                        'local': [{'user': {'name': '{0}'}}],
+                        'remote': [{'type': 'UserName'}],
+                    }
+                ]
             }
         }
 
         with self.test_client() as c:
             c.patch(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                json=update, headers=self.headers
+                json=update,
+                headers=self.headers,
             )
 
     def test_user_can_delete_mappings(self):
@@ -388,16 +417,18 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         with self.test_client() as c:
             c.delete(
                 '/v3/OS-FEDERATION/mappings/%s' % mapping['id'],
-                headers=self.headers
+                headers=self.headers,
             )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserMappingTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserMappingTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -409,14 +440,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -427,12 +459,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserMappingTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserMappingTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -441,7 +475,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -453,12 +487,13 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _DomainAndProjectUserMappingTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserMappingTests,
+):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
 
@@ -477,14 +512,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
