@@ -10,10 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-from six.moves import http_client
-
 from keystone.common import provider_api
 import keystone.conf
 from keystone.tests.common import auth as common_auth
@@ -25,7 +24,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserPoliciesAssociationTests(object):
+class _SystemUserPoliciesAssociationTests:
     """Common default functionality for all system users."""
 
     def test_user_can_check_policy_association_for_endpoint(self):
@@ -41,13 +40,16 @@ class _SystemUserPoliciesAssociationTests(object):
         )
 
         PROVIDERS.endpoint_policy_api.create_policy_association(
-            policy['id'], endpoint['id'])
+            policy['id'], endpoint['id']
+        )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                  % (policy['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.NO_CONTENT)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
+                % (policy['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
     def test_user_can_check_policy_association_for_service(self):
         policy = unit.new_policy_ref()
@@ -58,13 +60,16 @@ class _SystemUserPoliciesAssociationTests(object):
         )
 
         PROVIDERS.endpoint_policy_api.create_policy_association(
-            policy['id'], service_id=service['id'])
+            policy['id'], service_id=service['id']
+        )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                  % (policy['id'], service['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.NO_CONTENT)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
+                % (policy['id'], service['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
     def test_user_can_check_policy_association_for_region_and_service(self):
         policy = unit.new_policy_ref()
@@ -81,10 +86,12 @@ class _SystemUserPoliciesAssociationTests(object):
         )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                  % (policy['id'], service['id'], region['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.NO_CONTENT)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
+                % (policy['id'], service['id'], region['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
     def test_user_can_get_policy_for_endpoint(self):
         policy = unit.new_policy_ref()
@@ -100,9 +107,11 @@ class _SystemUserPoliciesAssociationTests(object):
             policy['id'], endpoint['id']
         )
         with self.test_client() as c:
-            c.get('/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
-                  % (endpoint['id']),
-                  headers=self.headers)
+            c.get(
+                '/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
+                % (endpoint['id']),
+                headers=self.headers,
+            )
 
     def test_user_list_endpoints_for_policy(self):
         policy = unit.new_policy_ref()
@@ -118,14 +127,16 @@ class _SystemUserPoliciesAssociationTests(object):
             policy['id'], endpoint['id']
         )
         with self.test_client() as c:
-            r = c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
-                      % (policy['id']),
-                      headers=self.headers)
+            r = c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
+                % (policy['id']),
+                headers=self.headers,
+            )
             for endpoint_itr in r.json['endpoints']:
                 self.assertIn(endpoint['id'], endpoint_itr['id'])
 
 
-class _SystemReaderAndMemberPoliciesAssociationTests(object):
+class _SystemReaderAndMemberPoliciesAssociationTests:
 
     def test_user_cannot_create_policy_association_for_endpoint(self):
         policy = unit.new_policy_ref()
@@ -143,7 +154,7 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_policy_association_for_endpoint(self):
@@ -162,7 +173,7 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_policy_association_for_service(self):
@@ -176,7 +187,7 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_policy_association_for_service(self):
@@ -191,10 +202,10 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
-    def test_user_cannot_create_policy_association_for_region_and_service(self):
+    def test_user_cannot_create_policy_assoc_for_region_and_service(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
         service = PROVIDERS.catalog_api.create_service(
@@ -207,10 +218,10 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
-    def test_user_cannot_delete_policy_association_for_region_and_service(self):
+    def test_user_cannot_delete_policy_assoc_for_region_and_service(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
         service = PROVIDERS.catalog_api.create_service(
@@ -223,11 +234,11 @@ class _SystemReaderAndMemberPoliciesAssociationTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserPolicyAssociationsTests(object):
+class _DomainAndProjectUserPolicyAssociationsTests:
 
     def test_user_cannot_check_policy_association_for_endpoint(self):
         policy = unit.new_policy_ref()
@@ -242,13 +253,16 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
         )
 
         PROVIDERS.endpoint_policy_api.create_policy_association(
-            policy['id'], endpoint['id'])
+            policy['id'], endpoint['id']
+        )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
-                  % (policy['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
+                % (policy['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_check_policy_association_for_service(self):
         policy = unit.new_policy_ref()
@@ -259,13 +273,16 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
         )
 
         PROVIDERS.endpoint_policy_api.create_policy_association(
-            policy['id'], service_id=service['id'])
+            policy['id'], service_id=service['id']
+        )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
-                  % (policy['id'], service['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
+                % (policy['id'], service['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_check_policy_association_for_region_and_service(self):
         policy = unit.new_policy_ref()
@@ -282,10 +299,12 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
         )
 
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
-                  % (policy['id'], service['id'], region['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
+                % (policy['id'], service['id'], region['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_get_policy_for_endpoint(self):
         policy = unit.new_policy_ref()
@@ -301,10 +320,12 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
             policy['id'], endpoint['id']
         )
         with self.test_client() as c:
-            c.get('/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
-                  % (endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/endpoints/%s/OS-ENDPOINT-POLICY/policy'
+                % (endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_list_endpoints_for_policy(self):
         policy = unit.new_policy_ref()
@@ -320,10 +341,12 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
             policy['id'], endpoint['id']
         )
         with self.test_client() as c:
-            c.get('/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
-                  % (policy['id']), headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN
-                  )
+            c.get(
+                '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints'
+                % (policy['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_create_policy_association_for_endpoint(self):
         policy = unit.new_policy_ref()
@@ -341,7 +364,7 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_policy_association_for_endpoint(self):
@@ -360,7 +383,7 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_create_policy_association_for_service(self):
@@ -374,7 +397,7 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_policy_association_for_service(self):
@@ -389,10 +412,10 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
-    def test_user_cannot_create_policy_association_for_region_and_service(self):
+    def test_user_cannot_create_policy_assoc_for_region_and_service(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
         service = PROVIDERS.catalog_api.create_service(
@@ -405,10 +428,10 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
-    def test_user_cannot_delete_policy_association_for_region_and_service(self):
+    def test_user_cannot_delete_policy_assoc_for_region_and_service(self):
         policy = unit.new_policy_ref()
         policy = PROVIDERS.policy_api.create_policy(policy['id'], policy)
         service = PROVIDERS.catalog_api.create_service(
@@ -421,17 +444,19 @@ class _DomainAndProjectUserPolicyAssociationsTests(object):
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserPoliciesAssociationTests,
-                        _SystemReaderAndMemberPoliciesAssociationTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserPoliciesAssociationTests,
+    _SystemReaderAndMemberPoliciesAssociationTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -439,16 +464,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -459,13 +483,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserPoliciesAssociationTests,
-                        _SystemReaderAndMemberPoliciesAssociationTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserPoliciesAssociationTests,
+    _SystemReaderAndMemberPoliciesAssociationTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -473,16 +499,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -493,12 +518,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserPoliciesAssociationTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserPoliciesAssociationTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -509,7 +536,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -535,7 +562,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_delete_policy_association_for_endpoint(self):
@@ -554,7 +581,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/endpoints/%s'
                 % (policy['id'], endpoint['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_create_policy_association_for_service(self):
@@ -568,7 +595,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_delete_policy_association_for_service(self):
@@ -583,7 +610,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s'
                 % (policy['id'], service['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_create_policy_association_for_region_and_service(self):
@@ -599,7 +626,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_delete_policy_association_for_region_and_service(self):
@@ -615,16 +642,18 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/policies/%s/OS-ENDPOINT-POLICY/services/%s/regions/%s'
                 % (policy['id'], service['id'], region['id']),
                 headers=self.headers,
-                expected_status_code=http_client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserPolicyAssociationsTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserPolicyAssociationsTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -636,14 +665,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -654,12 +684,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserPolicyAssociationsTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserPolicyAssociationsTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -668,7 +700,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -680,12 +712,13 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _DomainAndProjectUserPolicyAssociationsTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserPolicyAssociationsTests,
+):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
 
@@ -704,14 +737,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
