@@ -10,10 +10,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
 from oslo_serialization import jsonutils
-from six.moves import http_client
 
 from keystone.common.policies import base as bp
 from keystone.common import provider_api
@@ -28,13 +28,13 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserProjectEndpointTests(object):
+class _SystemUserProjectEndpointTests:
     """Common default functionality for all system users."""
 
     def test_user_can_list_projects_for_endpoint(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -45,17 +45,21 @@ class _SystemUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            r = c.get('/v3/OS-EP-FILTER/endpoints/%s/projects' % endpoint['id'],
-                      headers=self.headers)
+            r = c.get(
+                '/v3/OS-EP-FILTER/endpoints/%s/projects' % endpoint['id'],
+                headers=self.headers,
+            )
             for project_itr in r.json['projects']:
                 self.assertIn(project['id'], project_itr['id'])
 
     def test_user_can_check_endpoint_in_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -66,17 +70,21 @@ class _SystemUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            c.get('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                  % (project['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.NO_CONTENT)
+            c.get(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
     def test_user_can_list_endpoints_for_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -87,20 +95,24 @@ class _SystemUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            r = c.get('/v3/OS-EP-FILTER/projects/%s/endpoints' % project['id'],
-                      headers=self.headers)
+            r = c.get(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints' % project['id'],
+                headers=self.headers,
+            )
             for endpoint_itr in r.json['endpoints']:
                 self.assertIn(endpoint['id'], endpoint_itr['id'])
 
 
-class _SystemReaderAndMemberProjectEndpointTests(object):
+class _SystemReaderAndMemberProjectEndpointTests:
 
     def test_user_cannot_add_endpoint_to_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -111,15 +123,17 @@ class _SystemReaderAndMemberProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
         with self.test_client() as c:
-            c.put('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                  % (project['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.put(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_remove_endpoint_from_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -130,18 +144,20 @@ class _SystemReaderAndMemberProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
         with self.test_client() as c:
-            c.delete('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                     % (project['id'], endpoint['id']),
-                     headers=self.headers,
-                     expected_status_code=http_client.FORBIDDEN)
+            c.delete(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
 
-class _DomainAndProjectUserProjectEndpointTests(object):
+class _DomainAndProjectUserProjectEndpointTests:
 
     def test_user_cannot_list_projects_for_endpoint(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -152,16 +168,20 @@ class _DomainAndProjectUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            c.get('/v3/OS-EP-FILTER/endpoints/%s/projects' % endpoint['id'],
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/OS-EP-FILTER/endpoints/%s/projects' % endpoint['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_check_endpoint_in_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -172,17 +192,21 @@ class _DomainAndProjectUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            c.get('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                  % (project['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
     def test_user_cannot_list_endpoints_for_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -193,20 +217,26 @@ class _DomainAndProjectUserProjectEndpointTests(object):
             endpoint['id'], endpoint
         )
 
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            c.get('/v3/OS-EP-FILTER/projects/%s/endpoints' % project['id'],
-                  headers=self.headers,
-                  expected_status_code=http_client.FORBIDDEN)
+            c.get(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints' % project['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
+            )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserProjectEndpointTests,
-                        _SystemReaderAndMemberProjectEndpointTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserProjectEndpointTests,
+    _SystemReaderAndMemberProjectEndpointTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -214,16 +244,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -234,13 +263,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserProjectEndpointTests,
-                        _SystemReaderAndMemberProjectEndpointTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserProjectEndpointTests,
+    _SystemReaderAndMemberProjectEndpointTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -248,16 +279,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -268,12 +298,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserProjectEndpointTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserProjectEndpointTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -284,7 +316,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -297,7 +329,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
     def test_user_can_add_endpoint_to_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -308,15 +340,17 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
             endpoint['id'], endpoint
         )
         with self.test_client() as c:
-            c.put('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                  % (project['id'], endpoint['id']),
-                  headers=self.headers,
-                  expected_status_code=http_client.NO_CONTENT)
+            c.put(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
     def test_user_can_remove_endpoint_from_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         service = PROVIDERS.catalog_api.create_service(
@@ -326,21 +360,27 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         endpoint = PROVIDERS.catalog_api.create_endpoint(
             endpoint['id'], endpoint
         )
-        PROVIDERS.catalog_api.add_endpoint_to_project(endpoint['id'], project['id'])
+        PROVIDERS.catalog_api.add_endpoint_to_project(
+            endpoint['id'], project['id']
+        )
         with self.test_client() as c:
-            c.delete('/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
-                     % (project['id'], endpoint['id']),
-                     headers=self.headers,
-                     expected_status_code=http_client.NO_CONTENT)
+            c.delete(
+                '/v3/OS-EP-FILTER/projects/%s/endpoints/%s'
+                % (project['id'], endpoint['id']),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
+            )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserProjectEndpointTests,
-                      _SystemReaderAndMemberProjectEndpointTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserProjectEndpointTests,
+    _SystemReaderAndMemberProjectEndpointTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -352,14 +392,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -370,13 +411,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserProjectEndpointTests,
-                       _SystemReaderAndMemberProjectEndpointTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserProjectEndpointTests,
+    _SystemReaderAndMemberProjectEndpointTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -385,7 +428,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -397,10 +440,11 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _DomainAndProjectUserProjectEndpointTests,
-        _SystemReaderAndMemberProjectEndpointTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserProjectEndpointTests,
+    _SystemReaderAndMemberProjectEndpointTests,
+):
 
     def _override_policy(self):
         # TODO(cmurphy): Remove this once the deprecated policies in
@@ -417,12 +461,12 @@ class ProjectUserTestsWithoutEnforceScope(
                 'identity:add_endpoint_to_project': bp.SYSTEM_ADMIN,
                 'identity:check_endpoint_in_project': bp.SYSTEM_READER,
                 'identity:list_endpoints_for_project': bp.SYSTEM_READER,
-                'identity:remove_endpoint_from_project': bp.SYSTEM_ADMIN
+                'identity:remove_endpoint_from_project': bp.SYSTEM_ADMIN,
             }
             f.write(jsonutils.dumps(overridden_policies))
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
         self.policy_file_name = self.policy_file.file_name
@@ -447,14 +491,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
