@@ -10,9 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-import http.client
 from oslo_serialization import jsonutils
 
 from keystone.common.policies import project as pp
@@ -56,16 +56,16 @@ def _override_policy(policy_file):
             ),
             'identity:delete_project_tags': (
                 pp.SYSTEM_ADMIN_OR_DOMAIN_ADMIN_OR_PROJECT_ADMIN
-            )
+            ),
         }
         f.write(jsonutils.dumps(overridden_policies))
 
 
-class _SystemUserTests(object):
+class _SystemUserTests:
     def test_user_can_get_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -73,15 +73,15 @@ class _SystemUserTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_list_project_tags(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -95,27 +95,27 @@ class _SystemUserTests(object):
             self.assertEqual(tag, r.json['tags'][0])
 
 
-class _SystemMemberAndReaderTagTests(object):
+class _SystemMemberAndReaderTagTests:
 
     def test_user_cannot_create_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -125,14 +125,16 @@ class _SystemMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -140,33 +142,33 @@ class _SystemMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserTagTests(object):
+class _DomainAndProjectUserTagTests:
 
     def test_user_cannot_create_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -176,14 +178,16 @@ class _DomainAndProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -191,19 +195,21 @@ class _DomainAndProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTests,
-                        _SystemMemberAndReaderTagTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+    _SystemMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -211,16 +217,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -231,13 +236,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTests,
-                        _SystemMemberAndReaderTagTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+    _SystemMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -245,16 +252,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -265,12 +271,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -279,7 +287,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -292,22 +300,22 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
     def test_user_can_create_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.CREATED
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -317,15 +325,16 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
                 json=update,
-                expected_status_code=http.client.OK
+                expected_status_code=http.client.OK,
             )
 
     def test_user_can_delete_project_tag(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -333,12 +342,12 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
-                headers=self.headers
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
+                headers=self.headers,
             )
 
 
-class _DomainUserTagTests(object):
+class _DomainUserTagTests:
 
     def test_user_can_get_tag_for_project_in_domain(self):
         project = PROVIDERS.resource_api.create_project(
@@ -350,9 +359,9 @@ class _DomainUserTagTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_list_tags_for_project_in_domain(self):
@@ -373,22 +382,22 @@ class _DomainUserTagTests(object):
     def test_user_cannot_create_project_tag_outside_domain(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_project_tag_outside_domain(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -399,14 +408,16 @@ class _DomainUserTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_project_tag_outside_domain(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -414,15 +425,15 @@ class _DomainUserTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_tag_for_project_outside_domain(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -430,15 +441,15 @@ class _DomainUserTagTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_tags_for_project_outside_domain(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -448,11 +459,11 @@ class _DomainUserTagTests(object):
             c.get(
                 '/v3/projects/%s/tags' % project['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainMemberAndReaderTagTests(object):
+class _DomainMemberAndReaderTagTests:
 
     def test_user_cannot_create_project_tag_in_domain(self):
         project = PROVIDERS.resource_api.create_project(
@@ -463,9 +474,9 @@ class _DomainMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_project_tag_in_domain(self):
@@ -481,8 +492,10 @@ class _DomainMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_project_tag_in_domain(self):
@@ -495,18 +508,20 @@ class _DomainMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class DomainAdminUserTests(base_classes.TestCaseWithBootstrap,
-                           common_auth.AuthTestMixin,
-                           _DomainUserTagTests):
+class DomainAdminUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainUserTagTests,
+):
 
     def setUp(self):
-        super(DomainAdminUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -527,12 +542,14 @@ class DomainAdminUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
+            user_id=self.user_id,
+            password=domain_admin['password'],
             domain_id=self.domain_id,
         )
 
@@ -552,8 +569,9 @@ class DomainAdminUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
-                headers=self.headers, expected_status_code=http.client.CREATED
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
+                headers=self.headers,
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_project_tag_in_domain(self):
@@ -569,8 +587,10 @@ class DomainAdminUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             r = c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.OK
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.OK,
             )
             self.assertTrue(len(r.json['tags']) == 1)
             self.assertEqual(new_tag, r.json['tags'][0])
@@ -585,18 +605,20 @@ class DomainAdminUserTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
-                headers=self.headers
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
+                headers=self.headers,
             )
 
 
-class DomainMemberUserTests(base_classes.TestCaseWithBootstrap,
-                            common_auth.AuthTestMixin,
-                            _DomainUserTagTests,
-                            _DomainMemberAndReaderTagTests):
+class DomainMemberUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainUserTagTests,
+    _DomainMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(DomainMemberUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -617,12 +639,14 @@ class DomainMemberUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
+            user_id=self.user_id,
+            password=domain_admin['password'],
             domain_id=self.domain_id,
         )
 
@@ -634,13 +658,15 @@ class DomainMemberUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class DomainReaderUserTests(base_classes.TestCaseWithBootstrap,
-                            common_auth.AuthTestMixin,
-                            _DomainUserTagTests,
-                            _DomainMemberAndReaderTagTests):
+class DomainReaderUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainUserTagTests,
+    _DomainMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(DomainReaderUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -661,12 +687,14 @@ class DomainReaderUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=domain_admin['password'],
+            user_id=self.user_id,
+            password=domain_admin['password'],
             domain_id=self.domain_id,
         )
 
@@ -678,7 +706,7 @@ class DomainReaderUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class _ProjectUserTagTests(object):
+class _ProjectUserTagTests:
 
     def test_user_can_get_tag_for_project(self):
         tag = uuid.uuid4().hex
@@ -686,9 +714,9 @@ class _ProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/projects/%s/tags/%s' % (self.project_id, tag),
+                f'/v3/projects/{self.project_id}/tags/{tag}',
                 headers=self.headers,
-                expected_status_code=http.client.NO_CONTENT
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_list_tags_for_project(self):
@@ -705,22 +733,22 @@ class _ProjectUserTagTests(object):
     def test_user_cannot_create_tag_for_other_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_tag_for_other_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -730,14 +758,16 @@ class _ProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % project['id'], headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % project['id'],
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_tag_for_other_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -745,15 +775,15 @@ class _ProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_tag_for_other_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -761,15 +791,15 @@ class _ProjectUserTagTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/projects/%s/tags/%s' % (project['id'], tag),
+                '/v3/projects/{}/tags/{}'.format(project['id'], tag),
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_tags_for_other_project(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         tag = uuid.uuid4().hex
@@ -779,19 +809,19 @@ class _ProjectUserTagTests(object):
             c.get(
                 '/v3/projects/%s/tags' % project['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _ProjectMemberAndReaderTagTests(object):
+class _ProjectMemberAndReaderTagTests:
 
     def test_user_cannot_create_project_tag(self):
         tag = uuid.uuid4().hex
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (self.project_id, tag),
+                f'/v3/projects/{self.project_id}/tags/{tag}',
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_project_tag(self):
@@ -802,8 +832,10 @@ class _ProjectMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % self.project_id, headers=self.headers,
-                json=update, expected_status_code=http.client.FORBIDDEN
+                '/v3/projects/%s/tags' % self.project_id,
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_project_tag(self):
@@ -812,18 +844,20 @@ class _ProjectMemberAndReaderTagTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (self.project_id, tag),
+                f'/v3/projects/{self.project_id}/tags/{tag}',
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _ProjectUserTagTests):
+class ProjectAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _ProjectUserTagTests,
+):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -838,14 +872,16 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
 
         self.user_id = self.bootstrapper.admin_user_id
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            project_id=self.bootstrapper.project_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            project_id=self.bootstrapper.project_id,
         )
         self.project_id = self.bootstrapper.project_id
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            user_id=self.user_id,
+            password=self.bootstrapper.admin_password,
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -859,8 +895,9 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
         tag = uuid.uuid4().hex
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags/%s' % (self.project_id, tag),
-                headers=self.headers, expected_status_code=http.client.CREATED
+                f'/v3/projects/{self.project_id}/tags/{tag}',
+                headers=self.headers,
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_project_tag(self):
@@ -871,8 +908,10 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.put(
-                '/v3/projects/%s/tags' % self.project_id, headers=self.headers,
-                json=update, expected_status_code=http.client.OK
+                '/v3/projects/%s/tags' % self.project_id,
+                headers=self.headers,
+                json=update,
+                expected_status_code=http.client.OK,
             )
 
     def test_user_can_delete_project_tag(self):
@@ -881,18 +920,20 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/projects/%s/tags/%s' % (self.project_id, tag),
-                headers=self.headers
+                f'/v3/projects/{self.project_id}/tags/{tag}',
+                headers=self.headers,
             )
 
 
-class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
-                         common_auth.AuthTestMixin,
-                         _ProjectUserTagTests,
-                         _ProjectMemberAndReaderTagTests):
+class ProjectMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _ProjectUserTagTests,
+    _ProjectMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -907,19 +948,21 @@ class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
         self.project_id = project['id']
         self.user_id = self.bootstrapper.admin_user_id
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=self.bootstrapper.admin_password,
-            project_id=self.project_id
+            user_id=self.user_id,
+            password=self.bootstrapper.admin_password,
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -930,13 +973,15 @@ class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectReaderTests(base_classes.TestCaseWithBootstrap,
-                         common_auth.AuthTestMixin,
-                         _ProjectUserTagTests,
-                         _ProjectMemberAndReaderTagTests):
+class ProjectReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _ProjectUserTagTests,
+    _ProjectMemberAndReaderTagTests,
+):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
 
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
@@ -951,19 +996,21 @@ class ProjectReaderTests(base_classes.TestCaseWithBootstrap,
 
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
         self.project_id = project['id']
         self.user_id = self.bootstrapper.admin_user_id
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.reader_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=self.bootstrapper.admin_password,
-            project_id=self.project_id
+            user_id=self.user_id,
+            password=self.bootstrapper.admin_password,
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
