@@ -10,9 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
 import http.client
+import uuid
 
 from keystone.common import provider_api
 import keystone.conf
@@ -25,7 +24,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _CommonUtilities(object):
+class _CommonUtilities:
 
     def _create_protocol_and_deps(self):
         identity_provider = unit.new_identity_provider_ref()
@@ -43,7 +42,7 @@ class _CommonUtilities(object):
         return (protocol, mapping, identity_provider)
 
 
-class _SystemUserProtocolTests(object):
+class _SystemUserProtocolTests:
     """Common default functionality for all system users."""
 
     def test_user_can_list_protocols(self):
@@ -51,8 +50,8 @@ class _SystemUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols' %
-                identity_provider['id']
+                '/v3/OS-FEDERATION/identity_providers/%s/protocols'
+                % identity_provider['id']
             )
             r = c.get(path, headers=self.headers)
             self.assertEqual(1, len(r.json['protocols']))
@@ -63,13 +62,15 @@ class _SystemUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.get(path, headers=self.headers)
 
 
-class _SystemReaderAndMemberProtocolTests(object):
+class _SystemReaderAndMemberProtocolTests:
 
     def test_user_cannot_create_protocols(self):
         identity_provider = unit.new_identity_provider_ref()
@@ -86,12 +87,16 @@ class _SystemReaderAndMemberProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol_id)
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol_id,
+                )
             )
             c.put(
-                path, json=create, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_protocols(self):
@@ -104,12 +109,16 @@ class _SystemReaderAndMemberProtocolTests(object):
         update = {'protocol': {'mapping_id': new_mapping['id']}}
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.patch(
-                path, json=update, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_protocol(self):
@@ -117,16 +126,19 @@ class _SystemReaderAndMemberProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.delete(
-                path, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserProtocolTests(object):
+class _DomainAndProjectUserProtocolTests:
 
     def test_user_cannot_create_protocols(self):
         identity_provider = unit.new_identity_provider_ref()
@@ -143,12 +155,16 @@ class _DomainAndProjectUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol_id)
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol_id,
+                )
             )
             c.put(
-                path, json=create, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_protocols(self):
@@ -161,12 +177,16 @@ class _DomainAndProjectUserProtocolTests(object):
         update = {'protocol': {'mapping_id': new_mapping['id']}}
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.patch(
-                path, json=update, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                json=update,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_protocol(self):
@@ -174,12 +194,15 @@ class _DomainAndProjectUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.delete(
-                path, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_protocols(self):
@@ -187,12 +210,13 @@ class _DomainAndProjectUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols' %
-                identity_provider['id']
+                '/v3/OS-FEDERATION/identity_providers/%s/protocols'
+                % identity_provider['id']
             )
             c.get(
-                path, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_a_protocol(self):
@@ -200,23 +224,28 @@ class _DomainAndProjectUserProtocolTests(object):
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.get(
-                path, headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                path,
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _CommonUtilities,
-                        _SystemUserProtocolTests,
-                        _SystemReaderAndMemberProtocolTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _SystemUserProtocolTests,
+    _SystemReaderAndMemberProtocolTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -224,16 +253,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -244,14 +272,16 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _CommonUtilities,
-                        _SystemUserProtocolTests,
-                        _SystemReaderAndMemberProtocolTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _SystemUserProtocolTests,
+    _SystemReaderAndMemberProtocolTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -259,16 +289,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -279,13 +308,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _CommonUtilities,
-                       _SystemUserProtocolTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _SystemUserProtocolTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -296,7 +327,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -321,12 +352,16 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol_id)
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol_id,
+                )
             )
             c.put(
-                path, json=create, headers=self.headers,
-                expected_status_code=http.client.CREATED
+                path,
+                json=create,
+                headers=self.headers,
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_protocols(self):
@@ -339,8 +374,10 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         update = {'protocol': {'mapping_id': new_mapping['id']}}
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.patch(path, json=update, headers=self.headers)
 
@@ -349,19 +386,23 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             path = (
-                '/v3/OS-FEDERATION/identity_providers/%s/protocols/%s' %
-                (identity_provider['id'], protocol['id'])
+                '/v3/OS-FEDERATION/identity_providers/{}/protocols/{}'.format(
+                    identity_provider['id'],
+                    protocol['id'],
+                )
             )
             c.delete(path, headers=self.headers)
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _CommonUtilities,
-                      _DomainAndProjectUserProtocolTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _DomainAndProjectUserProtocolTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -373,14 +414,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -391,13 +433,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _CommonUtilities,
-                       _DomainAndProjectUserProtocolTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _DomainAndProjectUserProtocolTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -406,7 +450,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -418,13 +462,14 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _CommonUtilities,
-        _DomainAndProjectUserProtocolTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _CommonUtilities,
+    _DomainAndProjectUserProtocolTests,
+):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
 
@@ -443,14 +488,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
