@@ -10,9 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
 import http.client
+import uuid
 
 from keystone.common import provider_api
 import keystone.conf
@@ -25,7 +24,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserServiceProviderTests(object):
+class _SystemUserServiceProviderTests:
     """Common default functionality for all system users."""
 
     def test_user_can_list_service_providers(self):
@@ -49,16 +48,16 @@ class _SystemUserServiceProviderTests(object):
 
         with self.test_client() as c:
             r = c.get(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
-                headers=self.headers
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
+                headers=self.headers,
             )
             self.assertEqual(
                 service_provider['id'], r.json['service_provider']['id']
             )
 
 
-class _SystemReaderAndMemberUserServiceProviderTests(object):
+class _SystemReaderAndMemberUserServiceProviderTests:
     """Common default functionality for system readers and system members."""
 
     def test_user_cannot_create_service_providers(self):
@@ -74,7 +73,7 @@ class _SystemReaderAndMemberUserServiceProviderTests(object):
                 '/v3/OS-FEDERATION/service_providers/%s' % uuid.uuid4().hex,
                 headers=self.headers,
                 json=create,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_service_providers(self):
@@ -86,11 +85,11 @@ class _SystemReaderAndMemberUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.patch(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
                 json=update,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_service_providers(self):
@@ -100,14 +99,14 @@ class _SystemReaderAndMemberUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserServiceProviderTests(object):
+class _DomainAndProjectUserServiceProviderTests:
     """Common functionality for all domain and project users."""
 
     def test_user_cannot_create_service_providers(self):
@@ -123,7 +122,7 @@ class _DomainAndProjectUserServiceProviderTests(object):
                 '/v3/OS-FEDERATION/service_providers/%s' % uuid.uuid4().hex,
                 headers=self.headers,
                 json=create,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_update_service_providers(self):
@@ -135,11 +134,11 @@ class _DomainAndProjectUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.patch(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
                 json=update,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_service_providers(self):
@@ -149,8 +148,9 @@ class _DomainAndProjectUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/OS-FEDERATION/service_providers', headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/OS-FEDERATION/service_providers',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_get_a_service_provider(self):
@@ -160,10 +160,10 @@ class _DomainAndProjectUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_delete_service_providers(self):
@@ -173,20 +173,22 @@ class _DomainAndProjectUserServiceProviderTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserServiceProviderTests,
-                        _SystemReaderAndMemberUserServiceProviderTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserServiceProviderTests,
+    _SystemReaderAndMemberUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -194,16 +196,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -214,13 +215,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserServiceProviderTests,
-                        _SystemReaderAndMemberUserServiceProviderTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserServiceProviderTests,
+    _SystemReaderAndMemberUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -228,16 +231,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -248,12 +250,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserServiceProviderTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -264,7 +268,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -287,7 +291,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
                 '/v3/OS-FEDERATION/service_providers/%s' % uuid.uuid4().hex,
                 headers=self.headers,
                 json=create,
-                expected_status_code=http.client.CREATED
+                expected_status_code=http.client.CREATED,
             )
 
     def test_user_can_update_service_providers(self):
@@ -299,10 +303,10 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.patch(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
                 headers=self.headers,
-                json=update
+                json=update,
             )
 
     def test_user_can_delete_service_providers(self):
@@ -312,18 +316,20 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/OS-FEDERATION/service_providers/%s' %
-                service_provider['id'],
-                headers=self.headers
+                '/v3/OS-FEDERATION/service_providers/%s'
+                % service_provider['id'],
+                headers=self.headers,
             )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserServiceProviderTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -335,14 +341,15 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         domain_admin = unit.new_user_ref(domain_id=self.domain_id)
         self.user_id = PROVIDERS.identity_api.create_user(domain_admin)['id']
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=self.user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.admin_role_id,
+            user_id=self.user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=domain_admin['password'],
-            domain_id=self.domain_id
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -353,12 +360,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserServiceProviderTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -367,7 +376,7 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            project_id=self.bootstrapper.project_id
+            project_id=self.bootstrapper.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -379,12 +388,13 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
 
 
 class ProjectUserTestsWithoutEnforceScope(
-        base_classes.TestCaseWithBootstrap,
-        common_auth.AuthTestMixin,
-        _DomainAndProjectUserServiceProviderTests):
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserServiceProviderTests,
+):
 
     def setUp(self):
-        super(ProjectUserTestsWithoutEnforceScope, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
 
@@ -403,14 +413,15 @@ class ProjectUserTestsWithoutEnforceScope(
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.user_id,
-            project_id=self.project_id
+            self.bootstrapper.member_role_id,
+            user_id=self.user_id,
+            project_id=self.project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=user['password'],
-            project_id=self.project_id
+            project_id=self.project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
