@@ -10,9 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-import http.client
 from oslo_serialization import jsonutils
 
 from keystone.common.policies import base
@@ -28,7 +28,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserSystemAssignmentTests(object):
+class _SystemUserSystemAssignmentTests:
 
     def test_user_can_list_user_system_role_assignments(self):
         user = PROVIDERS.identity_api.create_user(
@@ -59,10 +59,10 @@ class _SystemUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.NO_CONTENT
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
             )
 
     def test_user_can_list_group_system_role_assignments(self):
@@ -77,7 +77,7 @@ class _SystemUserSystemAssignmentTests(object):
         with self.test_client() as c:
             r = c.get(
                 '/v3/system/groups/%s/roles' % group['id'],
-                headers=self.headers
+                headers=self.headers,
             )
             self.assertEqual(1, len(r.json['roles']))
             self.assertEqual(
@@ -95,14 +95,14 @@ class _SystemUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.NO_CONTENT
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.NO_CONTENT,
             )
 
 
-class _SystemMemberAndReaderSystemAssignmentTests(object):
+class _SystemMemberAndReaderSystemAssignmentTests:
 
     def test_user_cannot_grant_system_assignments(self):
         user = PROVIDERS.identity_api.create_user(
@@ -111,10 +111,10 @@ class _SystemMemberAndReaderSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_system_assignments(self):
@@ -128,10 +128,10 @@ class _SystemMemberAndReaderSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_grant_group_system_assignment(self):
@@ -141,10 +141,10 @@ class _SystemMemberAndReaderSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_group_system_assignment(self):
@@ -158,14 +158,14 @@ class _SystemMemberAndReaderSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class _DomainAndProjectUserSystemAssignmentTests(object):
+class _DomainAndProjectUserSystemAssignmentTests:
 
     def test_user_cannot_list_system_role_assignments(self):
         user = PROVIDERS.identity_api.create_user(
@@ -178,8 +178,9 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/system/users/%s/roles' % user['id'], headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles' % user['id'],
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_check_user_system_role_assignments(self):
@@ -193,10 +194,10 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_grant_system_assignments(self):
@@ -206,10 +207,10 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_system_assignments(self):
@@ -223,10 +224,10 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_list_group_system_role_assignments(self):
@@ -242,7 +243,7 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
             c.get(
                 '/v3/system/groups/%s/roles' % group['id'],
                 headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_check_group_system_role_assignments(self):
@@ -256,10 +257,10 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.get(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_grant_group_system_assignments(self):
@@ -269,10 +270,10 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_group_system_assignments(self):
@@ -286,20 +287,22 @@ class _DomainAndProjectUserSystemAssignmentTests(object):
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
-                expected_status_code=http.client.FORBIDDEN
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserSystemAssignmentTests,
-                        _SystemMemberAndReaderSystemAssignmentTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserSystemAssignmentTests,
+    _SystemMemberAndReaderSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -307,16 +310,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -327,13 +329,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserSystemAssignmentTests,
-                        _SystemMemberAndReaderSystemAssignmentTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserSystemAssignmentTests,
+    _SystemMemberAndReaderSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -341,9 +345,7 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_member = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_member
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_member)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.member_role_id
         )
@@ -352,13 +354,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             {
                 'user_id': self.user_id,
                 'system': 'all',
-                'role_id': self.bootstrapper.member_role_id
+                'role_id': self.bootstrapper.member_role_id,
             }
         ]
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_member['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_member['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -369,12 +372,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserSystemAssignmentTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -383,8 +388,9 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         self.expected = []
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=self.bootstrapper.admin_password,
-            system=True
+            user_id=self.user_id,
+            password=self.bootstrapper.admin_password,
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -401,9 +407,9 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
             )
 
     def test_user_can_revoke_system_assignments(self):
@@ -417,9 +423,9 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/users/%s/roles/%s' % (
-                    user['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers
+                '/v3/system/users/%s/roles/%s'
+                % (user['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
             )
 
     def test_user_can_grant_group_system_assignments(self):
@@ -429,9 +435,9 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.put(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers,
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
             )
 
     def test_user_can_revoke_group_system_assignments(self):
@@ -445,18 +451,20 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
 
         with self.test_client() as c:
             c.delete(
-                '/v3/system/groups/%s/roles/%s' % (
-                    group['id'], self.bootstrapper.member_role_id
-                ), headers=self.headers
+                '/v3/system/groups/%s/roles/%s'
+                % (group['id'], self.bootstrapper.member_role_id),
+                headers=self.headers,
             )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserSystemAssignmentTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -466,17 +474,19 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         )
         self.domain_id = domain['id']
         domain_user = unit.new_user_ref(domain_id=self.domain_id)
-        self.domain_user_id = PROVIDERS.identity_api.create_user(
-            domain_user
-        )['id']
+        self.domain_user_id = PROVIDERS.identity_api.create_user(domain_user)[
+            'id'
+        ]
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.domain_user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.member_role_id,
+            user_id=self.domain_user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.domain_user_id, password=domain_user['password'],
-            domain_id=self.domain_id
+            user_id=self.domain_user_id,
+            password=domain_user['password'],
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -487,12 +497,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectReaderTests(base_classes.TestCaseWithBootstrap,
-                         common_auth.AuthTestMixin,
-                         _DomainAndProjectUserSystemAssignmentTests):
+class ProjectReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(ProjectReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -503,23 +515,24 @@ class ProjectReaderTests(base_classes.TestCaseWithBootstrap,
         self.domain_id = domain['id']
 
         project_reader = unit.new_user_ref(domain_id=self.domain_id)
-        project_reader_id = PROVIDERS.identity_api.create_user(
-            project_reader
-        )['id']
+        project_reader_id = PROVIDERS.identity_api.create_user(project_reader)[
+            'id'
+        ]
         project = unit.new_project_ref(domain_id=self.domain_id)
         project_id = PROVIDERS.resource_api.create_project(
             project['id'], project
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=project_reader_id,
-            project_id=project_id
+            self.bootstrapper.reader_role_id,
+            user_id=project_reader_id,
+            project_id=project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=project_reader_id,
             password=project_reader['password'],
-            project_id=project_id
+            project_id=project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -530,12 +543,14 @@ class ProjectReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
-                         common_auth.AuthTestMixin,
-                         _DomainAndProjectUserSystemAssignmentTests):
+class ProjectMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(ProjectMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -546,23 +561,24 @@ class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
         self.domain_id = domain['id']
 
         project_member = unit.new_user_ref(domain_id=self.domain_id)
-        project_member_id = PROVIDERS.identity_api.create_user(
-            project_member
-        )['id']
+        project_member_id = PROVIDERS.identity_api.create_user(project_member)[
+            'id'
+        ]
         project = unit.new_project_ref(domain_id=self.domain_id)
         project_id = PROVIDERS.resource_api.create_project(
             project['id'], project
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=project_member_id,
-            project_id=project_id
+            self.bootstrapper.member_role_id,
+            user_id=project_member_id,
+            project_id=project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=project_member_id,
             password=project_member['password'],
-            project_id=project_id
+            project_id=project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -573,12 +589,14 @@ class ProjectMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _DomainAndProjectUserSystemAssignmentTests):
+class ProjectAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserSystemAssignmentTests,
+):
 
     def setUp(self):
-        super(ProjectAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.policy_file = self.useFixture(temporaryfile.SecureTempFile())
         self.policy_file_name = self.policy_file.file_name
@@ -596,23 +614,24 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
         self.domain_id = domain['id']
 
         project_admin = unit.new_user_ref(domain_id=self.domain_id)
-        project_admin_id = PROVIDERS.identity_api.create_user(
-            project_admin
-        )['id']
+        project_admin_id = PROVIDERS.identity_api.create_user(project_admin)[
+            'id'
+        ]
         project = unit.new_project_ref(domain_id=self.domain_id)
         project_id = PROVIDERS.resource_api.create_project(
             project['id'], project
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.admin_role_id, user_id=project_admin_id,
-            project_id=project_id
+            self.bootstrapper.admin_role_id,
+            user_id=project_admin_id,
+            project_id=project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=project_admin_id,
             password=project_admin['password'],
-            project_id=project_id
+            project_id=project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -636,6 +655,6 @@ class ProjectAdminTests(base_classes.TestCaseWithBootstrap,
                 'identity:check_system_grant_for_user': base.SYSTEM_READER,
                 'identity:list_system_grants_for_user': base.SYSTEM_READER,
                 'identity:create_system_grant_for_user': base.SYSTEM_ADMIN,
-                'identity:revoke_system_grant_for_user': base.SYSTEM_ADMIN
+                'identity:revoke_system_grant_for_user': base.SYSTEM_ADMIN,
             }
             f.write(jsonutils.dumps(overridden_policies))
