@@ -10,10 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client
 import uuid
 
-from six.moves import http_client
-
 from keystone.common import provider_api
 import keystone.conf
 from keystone.tests.common import auth as common_auth
@@ -25,7 +24,7 @@ CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
-class _SystemUserTokenTests(object):
+class _SystemUserTokenTests:
 
     def test_user_can_validate_system_scoped_token(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -36,8 +35,7 @@ class _SystemUserTokenTests(object):
         )
 
         system_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            system=True
+            user_id=user['id'], password=user['password'], system=True
         )
 
         with self.test_client() as c:
@@ -57,13 +55,15 @@ class _SystemUserTokenTests(object):
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            domain_id=domain['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            domain_id=domain['id'],
         )
 
         domain_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            domain_id=domain['id']
+            user_id=user['id'],
+            password=user['password'],
+            domain_id=domain['id'],
         )
 
         with self.test_client() as c:
@@ -77,20 +77,22 @@ class _SystemUserTokenTests(object):
     def test_user_can_validate_project_scoped_token(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         project_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            project_id=project['id']
+            user_id=user['id'],
+            password=user['password'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
@@ -102,7 +104,7 @@ class _SystemUserTokenTests(object):
             c.get('/v3/auth/tokens', headers=self.headers)
 
 
-class _SystemMemberAndReaderTokenTests(object):
+class _SystemMemberAndReaderTokenTests:
 
     def test_user_cannot_revoke_a_system_scoped_token(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -113,8 +115,7 @@ class _SystemMemberAndReaderTokenTests(object):
         )
 
         system_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            system=True
+            user_id=user['id'], password=user['password'], system=True
         )
 
         with self.test_client() as c:
@@ -124,8 +125,9 @@ class _SystemMemberAndReaderTokenTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = system_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_a_domain_scoped_token(self):
@@ -137,13 +139,15 @@ class _SystemMemberAndReaderTokenTests(object):
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            domain_id=domain['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            domain_id=domain['id'],
         )
 
         domain_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            domain_id=domain['id']
+            user_id=user['id'],
+            password=user['password'],
+            domain_id=domain['id'],
         )
 
         with self.test_client() as c:
@@ -153,27 +157,30 @@ class _SystemMemberAndReaderTokenTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = domain_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_a_project_scoped_token(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         project_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            project_id=project['id']
+            user_id=user['id'],
+            password=user['password'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
@@ -183,18 +190,21 @@ class _SystemMemberAndReaderTokenTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = project_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class SystemReaderTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTokenTests,
-                        _SystemMemberAndReaderTokenTests):
+class SystemReaderTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTokenTests,
+    _SystemMemberAndReaderTokenTests,
+):
 
     def setUp(self):
-        super(SystemReaderTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -202,16 +212,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -222,13 +231,15 @@ class SystemReaderTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemMemberTests(base_classes.TestCaseWithBootstrap,
-                        common_auth.AuthTestMixin,
-                        _SystemUserTokenTests,
-                        _SystemMemberAndReaderTokenTests):
+class SystemMemberTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTokenTests,
+    _SystemMemberAndReaderTokenTests,
+):
 
     def setUp(self):
-        super(SystemMemberTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -236,16 +247,15 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
         system_reader = unit.new_user_ref(
             domain_id=CONF.identity.default_domain_id
         )
-        self.user_id = PROVIDERS.identity_api.create_user(
-            system_reader
-        )['id']
+        self.user_id = PROVIDERS.identity_api.create_user(system_reader)['id']
         PROVIDERS.assignment_api.create_system_grant_for_user(
             self.user_id, self.bootstrapper.reader_role_id
         )
 
         auth = self.build_authentication_request(
-            user_id=self.user_id, password=system_reader['password'],
-            system=True
+            user_id=self.user_id,
+            password=system_reader['password'],
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -256,12 +266,14 @@ class SystemMemberTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class SystemAdminTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _SystemUserTokenTests):
+class SystemAdminTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _SystemUserTokenTests,
+):
 
     def setUp(self):
-        super(SystemAdminTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -270,7 +282,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         auth = self.build_authentication_request(
             user_id=self.user_id,
             password=self.bootstrapper.admin_password,
-            system=True
+            system=True,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -289,8 +301,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         )
 
         system_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            system=True
+            user_id=user['id'], password=user['password'], system=True
         )
 
         with self.test_client() as c:
@@ -310,13 +321,15 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            domain_id=domain['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            domain_id=domain['id'],
         )
 
         domain_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            domain_id=domain['id']
+            user_id=user['id'],
+            password=user['password'],
+            domain_id=domain['id'],
         )
 
         with self.test_client() as c:
@@ -330,20 +343,22 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
     def test_user_can_revoke_a_project_scoped_token(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         project_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            project_id=project['id']
+            user_id=user['id'],
+            password=user['password'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
@@ -355,7 +370,7 @@ class SystemAdminTests(base_classes.TestCaseWithBootstrap,
             c.delete('/v3/auth/tokens', headers=self.headers)
 
 
-class _DomainAndProjectUserTests(object):
+class _DomainAndProjectUserTests:
 
     def test_user_can_validate_their_own_tokens(self):
         with self.test_client() as c:
@@ -376,8 +391,7 @@ class _DomainAndProjectUserTests(object):
         )
 
         system_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            system=True
+            user_id=user['id'], password=user['password'], system=True
         )
 
         with self.test_client() as c:
@@ -387,8 +401,9 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = system_token
             c.get(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_system_scoped_token(self):
@@ -400,8 +415,7 @@ class _DomainAndProjectUserTests(object):
         )
 
         system_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            system=True
+            user_id=user['id'], password=user['password'], system=True
         )
 
         with self.test_client() as c:
@@ -411,8 +425,9 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = system_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_validate_domain_scoped_token(self):
@@ -424,13 +439,15 @@ class _DomainAndProjectUserTests(object):
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            domain_id=domain['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            domain_id=domain['id'],
         )
 
         domain_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            domain_id=domain['id']
+            user_id=user['id'],
+            password=user['password'],
+            domain_id=domain['id'],
         )
 
         with self.test_client() as c:
@@ -440,8 +457,9 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = domain_token
             c.get(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_domain_scoped_token(self):
@@ -453,13 +471,15 @@ class _DomainAndProjectUserTests(object):
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            domain_id=domain['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            domain_id=domain['id'],
         )
 
         domain_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            domain_id=domain['id']
+            user_id=user['id'],
+            password=user['password'],
+            domain_id=domain['id'],
         )
 
         with self.test_client() as c:
@@ -469,27 +489,30 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = domain_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_validate_project_scoped_token(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         project_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            project_id=project['id']
+            user_id=user['id'],
+            password=user['password'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
@@ -499,27 +522,30 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = project_token
             c.get(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
     def test_user_cannot_revoke_project_scoped_token(self):
         project = PROVIDERS.resource_api.create_project(
             uuid.uuid4().hex,
-            unit.new_project_ref(domain_id=CONF.identity.default_domain_id)
+            unit.new_project_ref(domain_id=CONF.identity.default_domain_id),
         )
 
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
         user['id'] = PROVIDERS.identity_api.create_user(user)['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=user['id'],
-            project_id=project['id']
+            self.bootstrapper.reader_role_id,
+            user_id=user['id'],
+            project_id=project['id'],
         )
 
         project_auth = self.build_authentication_request(
-            user_id=user['id'], password=user['password'],
-            project_id=project['id']
+            user_id=user['id'],
+            password=user['password'],
+            project_id=project['id'],
         )
 
         with self.test_client() as c:
@@ -529,17 +555,20 @@ class _DomainAndProjectUserTests(object):
         with self.test_client() as c:
             self.headers['X-Subject-Token'] = project_token
             c.delete(
-                '/v3/auth/tokens', headers=self.headers,
-                expected_status_code=http_client.FORBIDDEN
+                '/v3/auth/tokens',
+                headers=self.headers,
+                expected_status_code=http.client.FORBIDDEN,
             )
 
 
-class DomainUserTests(base_classes.TestCaseWithBootstrap,
-                      common_auth.AuthTestMixin,
-                      _DomainAndProjectUserTests):
+class DomainUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserTests,
+):
 
     def setUp(self):
-        super(DomainUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -549,17 +578,19 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
         )
         self.domain_id = domain['id']
         domain_user = unit.new_user_ref(domain_id=self.domain_id)
-        self.domain_user_id = PROVIDERS.identity_api.create_user(
-            domain_user
-        )['id']
+        self.domain_user_id = PROVIDERS.identity_api.create_user(domain_user)[
+            'id'
+        ]
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.member_role_id, user_id=self.domain_user_id,
-            domain_id=self.domain_id
+            self.bootstrapper.member_role_id,
+            user_id=self.domain_user_id,
+            domain_id=self.domain_id,
         )
 
         auth = self.build_authentication_request(
-            user_id=self.domain_user_id, password=domain_user['password'],
-            domain_id=self.domain_id
+            user_id=self.domain_user_id,
+            password=domain_user['password'],
+            domain_id=self.domain_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
@@ -570,12 +601,14 @@ class DomainUserTests(base_classes.TestCaseWithBootstrap,
             self.headers = {'X-Auth-Token': self.token_id}
 
 
-class ProjectUserTests(base_classes.TestCaseWithBootstrap,
-                       common_auth.AuthTestMixin,
-                       _DomainAndProjectUserTests):
+class ProjectUserTests(
+    base_classes.TestCaseWithBootstrap,
+    common_auth.AuthTestMixin,
+    _DomainAndProjectUserTests,
+):
 
     def setUp(self):
-        super(ProjectUserTests, self).setUp()
+        super().setUp()
         self.loadapp()
         self.useFixture(ksfixtures.Policy(self.config_fixture))
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
@@ -586,23 +619,24 @@ class ProjectUserTests(base_classes.TestCaseWithBootstrap,
         self.domain_id = domain['id']
 
         project_reader = unit.new_user_ref(domain_id=self.domain_id)
-        project_reader_id = PROVIDERS.identity_api.create_user(
-            project_reader
-        )['id']
+        project_reader_id = PROVIDERS.identity_api.create_user(project_reader)[
+            'id'
+        ]
         project = unit.new_project_ref(domain_id=self.domain_id)
         project_id = PROVIDERS.resource_api.create_project(
             project['id'], project
         )['id']
 
         PROVIDERS.assignment_api.create_grant(
-            self.bootstrapper.reader_role_id, user_id=project_reader_id,
-            project_id=project_id
+            self.bootstrapper.reader_role_id,
+            user_id=project_reader_id,
+            project_id=project_id,
         )
 
         auth = self.build_authentication_request(
             user_id=project_reader_id,
             password=project_reader['password'],
-            project_id=project_id
+            project_id=project_id,
         )
 
         # Grab a token using the persona we're testing and prepare headers
