@@ -20,26 +20,27 @@ from keystone.common import cache
 import keystone.conf
 from keystone.tests import unit
 
-
 CONF = keystone.conf.CONF
 
 
 class TestCacheRegion(unit.BaseTestCase):
 
     def setUp(self):
-        super(TestCacheRegion, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(config_fixture.Config(CONF))
         self.config_fixture.config(
             # TODO(morganfainberg): Make Cache Testing a separate test case
             # in tempest, and move it out of the base unit tests.
             group='cache',
-            backend='dogpile.cache.memory')
+            backend='dogpile.cache.memory',
+        )
 
         # replace existing backend since this may already be configured
         cache.CACHE_INVALIDATION_REGION.configure(
             backend='dogpile.cache.memory',
             expiration_time=None,
-            replace_existing_backend=True)
+            replace_existing_backend=True,
+        )
 
         self.region_name = uuid.uuid4().hex
         self.region0 = cache.create_region('test_region')
@@ -181,7 +182,8 @@ class TestCacheRegion(unit.BaseTestCase):
         the tests above can erroneosly pass that we need this sanity check.
         """
         region_key = cache.RegionInvalidationManager(
-            None, self.region0.name)._region_key
+            None, self.region0.name
+        )._region_key
         key = uuid.uuid4().hex
         value = uuid.uuid4().hex
 
