@@ -1,4 +1,3 @@
-# encoding: utf-8
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -11,13 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
-import fixtures
 import uuid
 
+import fixtures
 import freezegun
 from oslo_config import fixture as config_fixture
 from oslo_log import log
+from oslo_utils import timeutils
 
 from keystone.common import fernet_utils
 from keystone.common import utils as common_utils
@@ -29,7 +28,6 @@ from keystone.tests import unit
 from keystone.tests.unit import ksfixtures
 from keystone.tests.unit import utils
 
-
 CONF = keystone.conf.CONF
 
 TZ = utils.TZ
@@ -39,32 +37,31 @@ class UtilsTestCase(unit.BaseTestCase):
     OPTIONAL = object()
 
     def setUp(self):
-        super(UtilsTestCase, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(config_fixture.Config(CONF))
 
     def test_resource_uuid(self):
         # Basic uuid test, most IDs issued by keystone look like this:
-        value = u'536e28c2017e405e89b25a1ed777b952'
+        value = '536e28c2017e405e89b25a1ed777b952'
         self.assertEqual(value, common_utils.resource_uuid(value))
 
     def test_resource_64_char_uuid(self):
         # Exact 64 length string, like ones used by mapping_id backend, are not
         # valid UUIDs, so they will be UUID5 namespaced
-        value = u'f13de678ac714bb1b7d1e9a007c10db5' * 2
+        value = 'f13de678ac714bb1b7d1e9a007c10db5' * 2
         expected_id = uuid.uuid5(common_utils.RESOURCE_ID_NAMESPACE, value).hex
         self.assertEqual(expected_id, common_utils.resource_uuid(value))
 
     def test_resource_non_ascii_chars(self):
         # IDs with non-ASCII characters will be UUID5 namespaced
-        value = u'ß' * 32
+        value = 'ß' * 32
         expected_id = uuid.uuid5(common_utils.RESOURCE_ID_NAMESPACE, value).hex
         self.assertEqual(expected_id, common_utils.resource_uuid(value))
 
     def test_resource_invalid_id(self):
         # This input is invalid because it's length is more than 64.
-        value = u'x' * 65
-        self.assertRaises(ValueError, common_utils.resource_uuid,
-                          value)
+        value = 'x' * 65
+        self.assertRaises(ValueError, common_utils.resource_uuid, value)
 
     def test_hash(self):
         password = 'right'
@@ -88,8 +85,9 @@ class UtilsTestCase(unit.BaseTestCase):
         password = uuid.uuid4().hex
         hashed_password = common_utils.hash_password(password)
         new_hashed_password = common_utils.hash_password(hashed_password)
-        self.assertFalse(common_utils.check_password(password,
-                                                     new_hashed_password))
+        self.assertFalse(
+            common_utils.check_password(password, new_hashed_password)
+        )
 
     def test_verify_long_password_strict(self):
         self.config_fixture.config(strict_password_check=False)
@@ -103,12 +101,14 @@ class UtilsTestCase(unit.BaseTestCase):
         self.config_fixture.config(strict_password_check=True)
         self.config_fixture.config(group='identity', max_password_length=5)
         invalid_password = 'passw0rd'
-        self.assertRaises(exception.PasswordVerificationError,
-                          common_utils.verify_length_and_trunc_password,
-                          invalid_password)
+        self.assertRaises(
+            exception.PasswordVerificationError,
+            common_utils.verify_length_and_trunc_password,
+            invalid_password,
+        )
 
     def test_verify_length_and_trunc_password_throws_validation_error(self):
-        class SpecialObject(object):
+        class SpecialObject:
             pass
 
         special_object = SpecialObject()
@@ -117,41 +117,48 @@ class UtilsTestCase(unit.BaseTestCase):
             self.assertRaises(
                 exception.ValidationError,
                 common_utils.verify_length_and_trunc_password,
-                invalid_password
+                invalid_password,
             )
 
     def test_hash_long_password_truncation(self):
         self.config_fixture.config(strict_password_check=False)
         invalid_length_password = '0' * 9999999
         hashed = common_utils.hash_password(invalid_length_password)
-        self.assertTrue(common_utils.check_password(invalid_length_password,
-                                                    hashed))
+        self.assertTrue(
+            common_utils.check_password(invalid_length_password, hashed)
+        )
 
     def test_hash_long_password_strict(self):
         self.config_fixture.config(strict_password_check=True)
         invalid_length_password = '0' * 9999999
-        self.assertRaises(exception.PasswordVerificationError,
-                          common_utils.hash_password,
-                          invalid_length_password)
+        self.assertRaises(
+            exception.PasswordVerificationError,
+            common_utils.hash_password,
+            invalid_length_password,
+        )
 
     def test_max_algo_length_truncates_password(self):
         self.config_fixture.config(strict_password_check=True)
-        self.config_fixture.config(group='identity',
-                                   password_hash_algorithm='bcrypt')
-        self.config_fixture.config(group='identity',
-                                   max_password_length='96')
+        self.config_fixture.config(
+            group='identity', password_hash_algorithm='bcrypt'
+        )
+        self.config_fixture.config(group='identity', max_password_length='96')
         invalid_length_password = '0' * 96
-        self.assertRaises(exception.PasswordVerificationError,
-                          common_utils.hash_password,
-                          invalid_length_password)
+        self.assertRaises(
+            exception.PasswordVerificationError,
+            common_utils.hash_password,
+            invalid_length_password,
+        )
 
     def test_bcrypt_sha256_not_truncate_password(self):
         self.config_fixture.config(strict_password_check=True)
-        self.config_fixture.config(group='identity',
-                                   password_hash_algorithm='bcrypt_sha256')
+        self.config_fixture.config(
+            group='identity', password_hash_algorithm='bcrypt_sha256'
+        )
         password = '0' * 128
-        password_verified = \
-            common_utils.verify_length_and_trunc_password(password)
+        password_verified = common_utils.verify_length_and_trunc_password(
+            password
+        )
         hashed = common_utils.hash_password(password)
         self.assertTrue(common_utils.check_password(password, hashed))
         self.assertEqual(password.encode('utf-8'), password_verified)
@@ -186,7 +193,7 @@ class UtilsTestCase(unit.BaseTestCase):
         self.assertFalse(common_utils.check_password(None, hashed))
 
     def test_hash_unicode(self):
-        password = u'Comment \xe7a va'
+        password = 'Comment \xe7a va'
         wrong = 'Comment ?a va'
         hashed = common_utils.hash_password(password)
         self.assertTrue(common_utils.check_password(password, hashed))
@@ -205,33 +212,33 @@ class UtilsTestCase(unit.BaseTestCase):
             self.assertTrue(common_utils.is_not_url_safe(base_str + i))
 
     def test_url_safe_with_unicode_check(self):
-        base_str = u'i am \xe7afe'
+        base_str = 'i am \xe7afe'
         self.assertFalse(common_utils.is_not_url_safe(base_str))
         for i in common_utils.URL_RESERVED_CHARS:
             self.assertTrue(common_utils.is_not_url_safe(base_str + i))
 
     def test_isotime_returns_microseconds_when_subsecond_is_true(self):
-        time = datetime.datetime.utcnow().replace(microsecond=500000)
+        time = timeutils.utcnow().replace(microsecond=500000)
         with freezegun.freeze_time(time):
             string_time = common_utils.isotime(subsecond=True)
         expected_string_ending = str(time.second) + '.000000Z'
         self.assertTrue(string_time.endswith(expected_string_ending))
 
     def test_isotime_returns_seconds_when_subsecond_is_false(self):
-        time = datetime.datetime.utcnow().replace(microsecond=500000)
+        time = timeutils.utcnow().replace(microsecond=500000)
         with freezegun.freeze_time(time):
             string_time = common_utils.isotime(subsecond=False)
         expected_string_ending = str(time.second) + 'Z'
         self.assertTrue(string_time.endswith(expected_string_ending))
 
     def test_isotime_rounds_microseconds_of_objects_passed_in(self):
-        time = datetime.datetime.utcnow().replace(microsecond=500000)
+        time = timeutils.utcnow().replace(microsecond=500000)
         string_time = common_utils.isotime(at=time, subsecond=True)
         expected_string_ending = str(time.second) + '.000000Z'
         self.assertTrue(string_time.endswith(expected_string_ending))
 
     def test_isotime_truncates_microseconds_of_objects_passed_in(self):
-        time = datetime.datetime.utcnow().replace(microsecond=500000)
+        time = timeutils.utcnow().replace(microsecond=500000)
         string_time = common_utils.isotime(at=time, subsecond=False)
         expected_string_ending = str(time.second) + 'Z'
         self.assertTrue(string_time.endswith(expected_string_ending))
@@ -246,8 +253,9 @@ class UtilsTestCase(unit.BaseTestCase):
                 country_name='cn',
                 user_id='user_id',
                 domain_component='test.com',
-                email_address='user@test.com'
-            ))
+                email_address='user@test.com',
+            )
+        )
 
         dn = common_utils.get_certificate_subject_dn(cert_pem)
         self.assertEqual('test', dn.get('CN'))
@@ -267,8 +275,9 @@ class UtilsTestCase(unit.BaseTestCase):
                 locality_name='kawasaki',
                 organization_name='fujitsu',
                 organizational_unit_name='test',
-                common_name='root'
-            ))
+                common_name='root',
+            )
+        )
 
         cert_pem = unit.create_pem_certificate(
             unit.create_dn(
@@ -279,8 +288,11 @@ class UtilsTestCase(unit.BaseTestCase):
                 country_name='cn',
                 user_id='user_id',
                 domain_component='test.com',
-                email_address='user@test.com'
-            ), ca=root_cert, ca_key=root_key)
+                email_address='user@test.com',
+            ),
+            ca=root_cert,
+            ca_key=root_key,
+        )
 
         dn = common_utils.get_certificate_subject_dn(cert_pem)
         self.assertEqual('test', dn.get('CN'))
@@ -304,13 +316,15 @@ class UtilsTestCase(unit.BaseTestCase):
         self.assertRaises(
             exception.ValidationError,
             common_utils.get_certificate_subject_dn,
-            'MIIEkTCCAnkCFDIzsgpdRGF//5ukMuueXnRxQALhMA0GCSqGSIb3DQEBCwUAMIGC')
+            'MIIEkTCCAnkCFDIzsgpdRGF//5ukMuueXnRxQALhMA0GCSqGSIb3DQEBCwUAMIGC',
+        )
 
     def test_get_certificate_issuer_dn_not_pem_format(self):
         self.assertRaises(
             exception.ValidationError,
             common_utils.get_certificate_issuer_dn,
-            'MIIEkTCCAnkCFDIzsgpdRGF//5ukMuueXnRxQALhMA0GCSqGSIb3DQEBCwUAMIGC')
+            'MIIEkTCCAnkCFDIzsgpdRGF//5ukMuueXnRxQALhMA0GCSqGSIb3DQEBCwUAMIGC',
+        )
 
     def test_get_certificate_thumbprint(self):
         cert_pem = '''-----BEGIN CERTIFICATE-----
@@ -341,8 +355,9 @@ class UtilsTestCase(unit.BaseTestCase):
         4cJHNiTQl8bxfSgwemgSYnnyXM4k
         -----END CERTIFICATE-----'''
         thumbprint = common_utils.get_certificate_thumbprint(cert_pem)
-        self.assertEqual('dMmoJKE9MIJK9VcyahYCb417JDhDfdtTiq_krco8-tk=',
-                         thumbprint)
+        self.assertEqual(
+            'dMmoJKE9MIJK9VcyahYCb417JDhDfdtTiq_krco8-tk=', thumbprint
+        )
 
 
 class ServiceHelperTests(unit.BaseTestCase):
@@ -358,7 +373,7 @@ class ServiceHelperTests(unit.BaseTestCase):
 class FernetUtilsTestCase(unit.BaseTestCase):
 
     def setUp(self):
-        super(FernetUtilsTestCase, self).setUp()
+        super().setUp()
         self.config_fixture = self.useFixture(config_fixture.Config(CONF))
 
     def test_debug_message_logged_when_loading_fernet_token_keys(self):
@@ -366,22 +381,24 @@ class FernetUtilsTestCase(unit.BaseTestCase):
             ksfixtures.KeyRepository(
                 self.config_fixture,
                 'fernet_tokens',
-                CONF.fernet_tokens.max_active_keys
+                CONF.fernet_tokens.max_active_keys,
             )
         )
         logging_fixture = self.useFixture(fixtures.FakeLogger(level=log.DEBUG))
         fernet_utilities = fernet_utils.FernetUtils(
             CONF.fernet_tokens.key_repository,
             CONF.fernet_tokens.max_active_keys,
-            'fernet_tokens'
+            'fernet_tokens',
         )
         fernet_utilities.load_keys()
         expected_debug_message = (
             'Loaded 2 Fernet keys from %(dir)s, but `[fernet_tokens] '
             'max_active_keys = %(max)d`; perhaps there have not been enough '
-            'key rotations to reach `max_active_keys` yet?') % {
-                'dir': CONF.fernet_tokens.key_repository,
-                'max': CONF.fernet_tokens.max_active_keys}
+            'key rotations to reach `max_active_keys` yet?'
+        ) % {
+            'dir': CONF.fernet_tokens.key_repository,
+            'max': CONF.fernet_tokens.max_active_keys,
+        }
         self.assertIn(expected_debug_message, logging_fixture.output)
 
     def test_debug_message_not_logged_when_loading_fernet_credential_key(self):
@@ -389,20 +406,22 @@ class FernetUtilsTestCase(unit.BaseTestCase):
             ksfixtures.KeyRepository(
                 self.config_fixture,
                 'credential',
-                CONF.fernet_tokens.max_active_keys
+                CONF.fernet_tokens.max_active_keys,
             )
         )
         logging_fixture = self.useFixture(fixtures.FakeLogger(level=log.DEBUG))
         fernet_utilities = fernet_utils.FernetUtils(
             CONF.credential.key_repository,
             credential_fernet.MAX_ACTIVE_KEYS,
-            'credential'
+            'credential',
         )
         fernet_utilities.load_keys()
         debug_message = (
             'Loaded 2 Fernet keys from %(dir)s, but `[credential] '
             'max_active_keys = %(max)d`; perhaps there have not been enough '
-            'key rotations to reach `max_active_keys` yet?') % {
-                'dir': CONF.credential.key_repository,
-                'max': credential_fernet.MAX_ACTIVE_KEYS}
+            'key rotations to reach `max_active_keys` yet?'
+        ) % {
+            'dir': CONF.credential.key_repository,
+            'max': credential_fernet.MAX_ACTIVE_KEYS,
+        }
         self.assertNotIn(debug_message, logging_fixture.output)
