@@ -65,7 +65,7 @@ class HackingCode(fixtures.Fixture):
         'expected_errors': [
             (7, 10, 'K001'),
             (10, 15, 'K001'),
-            (10, 29, 'K001'),
+            (10, 28, 'K001'),
             (13, 15, 'K001'),
             (16, 15, 'K001'),
             (16, 31, 'K001'),
@@ -78,7 +78,8 @@ class HackingCode(fixtures.Fixture):
             (28, 26, 'K001'),
             (29, 21, 'K001'),
             (32, 10, 'K001'),
-        ]}
+        ],
+    }
 
     # NOTE(browne): This is gross, but in Python 3.4 and earlier, the ast
     # module returns the incorrect col_offset for two of the defined functions
@@ -87,6 +88,12 @@ class HackingCode(fixtures.Fixture):
         mutable_default_args['expected_errors'][12] = (28, 27, 'K001')
         mutable_default_args['expected_errors'][14] = (32, 11, 'K001')
 
+    # NOTE(gmann): Python version < 3.8.2 (before Ubuntu Focal) returns
+    # the incorrect col_offset for below function defined in above code sample
+    # def f(foo, bad=[], more_bad=[x for x in range(3)]):
+    if sys.version_info < (3, 8, 2):
+        mutable_default_args['expected_errors'][2] = (10, 29, 'K001')  # type: ignore[index]
+
     comments_begin_with_space = {
         'code': """
             # This is a good comment
@@ -99,7 +106,8 @@ class HackingCode(fixtures.Fixture):
         """,
         'expected_errors': [
             (3, 0, 'K002'),
-        ]}
+        ],
+    }
 
     asserting_none_equality = {
         'code': """
@@ -119,7 +127,8 @@ class HackingCode(fixtures.Fixture):
             (6, 8, 'K003'),
             (7, 8, 'K004'),
             (8, 8, 'K004'),
-        ]}
+        ],
+    }
 
     dict_constructor = {
         'code': """
@@ -134,7 +143,8 @@ class HackingCode(fixtures.Fixture):
             (3, 0, 'K008'),
             (4, 0, 'K008'),
             (5, 0, 'K008'),
-        ]}
+        ],
+    }
 
 
 class HackingTranslations(fixtures.Fixture):
@@ -309,7 +319,7 @@ class HackingTranslations(fixtures.Fixture):
                 try:
                     something = True
                 except AssertionError as e:
-                    LOG.warning(six.text_type(e))
+                    LOG.warning(e)
                     raise exception.Unauthorized(e)
             """,
             'expected_errors': [],
