@@ -10,10 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
 from unittest import mock
 import uuid
 
+from oslo_utils import timeutils
+
 from keystone.common.cache import _context_cache
 from keystone.common import utils as ks_utils
 from keystone import exception
@@ -24,11 +25,11 @@ from keystone.tests.unit import base_classes
 class TestReceiptSerialization(base_classes.TestCaseWithBootstrap):
 
     def setUp(self):
-        super(TestReceiptSerialization, self).setUp()
+        super().setUp()
         self.admin_user_id = self.bootstrapper.admin_user_id
 
         self.receipt_id = uuid.uuid4().hex
-        issued_at = datetime.datetime.utcnow()
+        issued_at = timeutils.utcnow()
         self.issued_at = ks_utils.isotime(at=issued_at, subsecond=True)
 
         # Reach into the cache registry and pull out an instance of the
@@ -50,11 +51,12 @@ class TestReceiptSerialization(base_classes.TestCaseWithBootstrap):
         self.assertEqual(self.exp_receipt.issued_at, receipt.issued_at)
 
     @mock.patch.object(
-        receipt_model.ReceiptModel, '__init__', side_effect=Exception)
+        receipt_model.ReceiptModel, '__init__', side_effect=Exception
+    )
     def test_error_handling_in_deserialize(self, handler_mock):
         serialized = self.receipt_handler.serialize(self.exp_receipt)
         self.assertRaises(
             exception.CacheDeserializationError,
             self.receipt_handler.deserialize,
-            serialized
+            serialized,
         )
