@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2014 IBM Corp.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -31,17 +30,19 @@ class SqlIDMappingTable(test_backend_sql.SqlModels):
     """Set of tests for checking SQL Identity ID Mapping."""
 
     def test_id_mapping(self):
-        cols = (('public_id', sql.String, 64),
-                ('domain_id', sql.String, 64),
-                ('local_id', sql.String, 64),
-                ('entity_type', sql.Enum, None))
+        cols = (
+            ('public_id', sql.String, 64),
+            ('domain_id', sql.String, 64),
+            ('local_id', sql.String, 255),
+            ('entity_type', sql.Enum, None),
+        )
         self.assertExpectedSchema('id_mapping', cols)
 
 
 class SqlIDMapping(test_backend_sql.SqlTests):
 
     def setUp(self):
-        super(SqlIDMapping, self).setUp()
+        super().setUp()
         self.load_sample_data()
 
     def load_sample_data(self):
@@ -78,12 +79,16 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         initial_mappings = len(mapping_sql.list_id_mappings())
         local_id1 = uuid.uuid4().hex
         local_id2 = uuid.uuid4().hex
-        local_entity1 = {'domain_id': self.domainA['id'],
-                         'local_id': local_id1,
-                         'entity_type': mapping.EntityType.USER}
-        local_entity2 = {'domain_id': self.domainB['id'],
-                         'local_id': local_id2,
-                         'entity_type': mapping.EntityType.GROUP}
+        local_entity1 = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id1,
+            'entity_type': mapping.EntityType.USER,
+        }
+        local_entity2 = {
+            'domain_id': self.domainB['id'],
+            'local_id': local_id2,
+            'entity_type': mapping.EntityType.GROUP,
+        }
 
         # Check no mappings for the new local entities
         self.assertIsNone(
@@ -96,12 +101,16 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         # Create the new mappings and then read them back
         public_id1 = PROVIDERS.id_mapping_api.create_id_mapping(local_entity1)
         public_id2 = PROVIDERS.id_mapping_api.create_id_mapping(local_entity2)
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 2))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 2),
+        )
         self.assertEqual(
-            public_id1, PROVIDERS.id_mapping_api.get_public_id(local_entity1))
+            public_id1, PROVIDERS.id_mapping_api.get_public_id(local_entity1)
+        )
         self.assertEqual(
-            public_id2, PROVIDERS.id_mapping_api.get_public_id(local_entity2))
+            public_id2, PROVIDERS.id_mapping_api.get_public_id(local_entity2)
+        )
 
         local_id_ref = PROVIDERS.id_mapping_api.get_id_mapping(public_id1)
         self.assertEqual(self.domainA['id'], local_id_ref['domain_id'])
@@ -120,54 +129,98 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         # Create another mappings, this time specifying a public ID to use
         new_public_id = uuid.uuid4().hex
         public_id3 = PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainB['id'], 'local_id': local_id2,
-             'entity_type': mapping.EntityType.USER},
-            public_id=new_public_id)
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id2,
+                'entity_type': mapping.EntityType.USER,
+            },
+            public_id=new_public_id,
+        )
         self.assertEqual(new_public_id, public_id3)
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 3))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 3),
+        )
 
         # Delete the mappings we created, and make sure the mapping count
         # goes back to where it was
         PROVIDERS.id_mapping_api.delete_id_mapping(public_id1)
         PROVIDERS.id_mapping_api.delete_id_mapping(public_id2)
         PROVIDERS.id_mapping_api.delete_id_mapping(public_id3)
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings),
+        )
 
     def test_id_mapping_handles_unicode(self):
         initial_mappings = len(mapping_sql.list_id_mappings())
-        local_id = u'fäké1'
-        local_entity = {'domain_id': self.domainA['id'],
-                        'local_id': local_id,
-                        'entity_type': mapping.EntityType.USER}
+        local_id = 'fäké1'
+        local_entity = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id,
+            'entity_type': mapping.EntityType.USER,
+        }
 
         # Check no mappings for the new local entity
         self.assertIsNone(PROVIDERS.id_mapping_api.get_public_id(local_entity))
 
         # Create the new mapping and then read it back
         public_id = PROVIDERS.id_mapping_api.create_id_mapping(local_entity)
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 1))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 1),
+        )
         self.assertEqual(
-            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity))
+            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity)
+        )
 
     def test_id_mapping_handles_bytes(self):
         initial_mappings = len(mapping_sql.list_id_mappings())
         local_id = b'FaKeID'
-        local_entity = {'domain_id': self.domainA['id'],
-                        'local_id': local_id,
-                        'entity_type': mapping.EntityType.USER}
+        local_entity = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id,
+            'entity_type': mapping.EntityType.USER,
+        }
 
         # Check no mappings for the new local entity
         self.assertIsNone(PROVIDERS.id_mapping_api.get_public_id(local_entity))
 
         # Create the new mapping and then read it back
         public_id = PROVIDERS.id_mapping_api.create_id_mapping(local_entity)
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 1))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 1),
+        )
         self.assertEqual(
-            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity))
+            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity)
+        )
+
+    def test_id_mapping_handles_ids_greater_than_64_characters(self):
+        initial_mappings = len(mapping_sql.list_id_mappings())
+        local_id = 'Aa' * 100
+        local_entity = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id,
+            'entity_type': mapping.EntityType.GROUP,
+        }
+
+        # Check no mappings for the new local entity
+        self.assertIsNone(PROVIDERS.id_mapping_api.get_public_id(local_entity))
+
+        # Create the new mapping and then read it back
+        public_id = PROVIDERS.id_mapping_api.create_id_mapping(local_entity)
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 1),
+        )
+        self.assertEqual(
+            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity)
+        )
+        self.assertEqual(
+            local_id,
+            PROVIDERS.id_mapping_api.get_id_mapping(public_id)['local_id'],
+        )
 
     def test_delete_public_id_is_silent(self):
         # Test that deleting an invalid public key is silent
@@ -183,59 +236,96 @@ class SqlIDMapping(test_backend_sql.SqlTests):
 
         # Create five mappings,two in domainA, three in domainB
         PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainA['id'], 'local_id': local_id1,
-             'entity_type': mapping.EntityType.USER})
+            {
+                'domain_id': self.domainA['id'],
+                'local_id': local_id1,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
         PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainA['id'], 'local_id': local_id2,
-             'entity_type': mapping.EntityType.USER})
+            {
+                'domain_id': self.domainA['id'],
+                'local_id': local_id2,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
         public_id3 = PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainB['id'], 'local_id': local_id3,
-             'entity_type': mapping.EntityType.GROUP})
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id3,
+                'entity_type': mapping.EntityType.GROUP,
+            }
+        )
         public_id4 = PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainB['id'], 'local_id': local_id4,
-             'entity_type': mapping.EntityType.USER})
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id4,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
         public_id5 = PROVIDERS.id_mapping_api.create_id_mapping(
-            {'domain_id': self.domainB['id'], 'local_id': local_id5,
-             'entity_type': mapping.EntityType.USER})
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id5,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
 
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 5))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 5),
+        )
 
         # Purge mappings for domainA, should be left with those in B
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'domain_id': self.domainA['id']})
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 3))
+            {'domain_id': self.domainA['id']}
+        )
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 3),
+        )
         PROVIDERS.id_mapping_api.get_id_mapping(public_id3)
         PROVIDERS.id_mapping_api.get_id_mapping(public_id4)
         PROVIDERS.id_mapping_api.get_id_mapping(public_id5)
 
         # Purge mappings for type Group, should purge one more
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'entity_type': mapping.EntityType.GROUP})
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 2))
+            {'entity_type': mapping.EntityType.GROUP}
+        )
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 2),
+        )
         PROVIDERS.id_mapping_api.get_id_mapping(public_id4)
         PROVIDERS.id_mapping_api.get_id_mapping(public_id5)
 
         # Purge mapping for a specific local identifier
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'domain_id': self.domainB['id'], 'local_id': local_id4,
-             'entity_type': mapping.EntityType.USER})
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings + 1))
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id4,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings + 1),
+        )
         PROVIDERS.id_mapping_api.get_id_mapping(public_id5)
 
         # Purge mappings the remaining mappings
         PROVIDERS.id_mapping_api.purge_mappings({})
-        self.assertThat(mapping_sql.list_id_mappings(),
-                        matchers.HasLength(initial_mappings))
+        self.assertThat(
+            mapping_sql.list_id_mappings(),
+            matchers.HasLength(initial_mappings),
+        )
 
     def test_create_duplicate_mapping(self):
         local_entity = {
             'domain_id': self.domainA['id'],
             'local_id': uuid.uuid4().hex,
-            'entity_type': mapping.EntityType.USER}
+            'entity_type': mapping.EntityType.USER,
+        }
         public_id1 = PROVIDERS.id_mapping_api.create_id_mapping(local_entity)
 
         # second call should be successful and return the same
@@ -246,15 +336,18 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         # even if public_id was specified, it should not be used,
         # and still the same public_id should be returned
         public_id3 = PROVIDERS.id_mapping_api.create_id_mapping(
-            local_entity, public_id=uuid.uuid4().hex)
+            local_entity, public_id=uuid.uuid4().hex
+        )
         self.assertEqual(public_id1, public_id3)
 
     @unit.skip_if_cache_disabled('identity')
     def test_cache_when_id_mapping_crud(self):
         local_id = uuid.uuid4().hex
-        local_entity = {'domain_id': self.domainA['id'],
-                        'local_id': local_id,
-                        'entity_type': mapping.EntityType.USER}
+        local_entity = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id,
+            'entity_type': mapping.EntityType.USER,
+        }
 
         # Check no mappings for the new local entity
         self.assertIsNone(PROVIDERS.id_mapping_api.get_public_id(local_entity))
@@ -262,7 +355,8 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         # Create new mappings, and it should be in the cache after created
         public_id = PROVIDERS.id_mapping_api.create_id_mapping(local_entity)
         self.assertEqual(
-            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity))
+            public_id, PROVIDERS.id_mapping_api.get_public_id(local_entity)
+        )
         local_id_ref = PROVIDERS.id_mapping_api.get_id_mapping(public_id)
         self.assertEqual(self.domainA['id'], local_id_ref['domain_id'])
         self.assertEqual(local_id, local_id_ref['local_id'])
@@ -282,21 +376,31 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         local_id5 = uuid.uuid4().hex
 
         # Create five mappings,two in domainA, three in domainB
-        local_entity1 = {'domain_id': self.domainA['id'],
-                         'local_id': local_id1,
-                         'entity_type': mapping.EntityType.USER}
-        local_entity2 = {'domain_id': self.domainA['id'],
-                         'local_id': local_id2,
-                         'entity_type': mapping.EntityType.USER}
-        local_entity3 = {'domain_id': self.domainB['id'],
-                         'local_id': local_id3,
-                         'entity_type': mapping.EntityType.GROUP}
-        local_entity4 = {'domain_id': self.domainB['id'],
-                         'local_id': local_id4,
-                         'entity_type': mapping.EntityType.USER}
-        local_entity5 = {'domain_id': self.domainB['id'],
-                         'local_id': local_id5,
-                         'entity_type': mapping.EntityType.USER}
+        local_entity1 = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id1,
+            'entity_type': mapping.EntityType.USER,
+        }
+        local_entity2 = {
+            'domain_id': self.domainA['id'],
+            'local_id': local_id2,
+            'entity_type': mapping.EntityType.USER,
+        }
+        local_entity3 = {
+            'domain_id': self.domainB['id'],
+            'local_id': local_id3,
+            'entity_type': mapping.EntityType.GROUP,
+        }
+        local_entity4 = {
+            'domain_id': self.domainB['id'],
+            'local_id': local_id4,
+            'entity_type': mapping.EntityType.USER,
+        }
+        local_entity5 = {
+            'domain_id': self.domainB['id'],
+            'local_id': local_id5,
+            'entity_type': mapping.EntityType.USER,
+        }
 
         PROVIDERS.id_mapping_api.create_id_mapping(local_entity1)
         PROVIDERS.id_mapping_api.create_id_mapping(local_entity2)
@@ -306,7 +410,8 @@ class SqlIDMapping(test_backend_sql.SqlTests):
 
         # Purge mappings for domainA, should be left with those in B
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'domain_id': self.domainA['id']})
+            {'domain_id': self.domainA['id']}
+        )
         self.assertIsNone(
             PROVIDERS.id_mapping_api.get_public_id(local_entity1)
         )
@@ -316,15 +421,20 @@ class SqlIDMapping(test_backend_sql.SqlTests):
 
         # Purge mappings for type Group, should purge one more
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'entity_type': mapping.EntityType.GROUP})
+            {'entity_type': mapping.EntityType.GROUP}
+        )
         self.assertIsNone(
             PROVIDERS.id_mapping_api.get_public_id(local_entity3)
         )
 
         # Purge mapping for a specific local identifier
         PROVIDERS.id_mapping_api.purge_mappings(
-            {'domain_id': self.domainB['id'], 'local_id': local_id4,
-             'entity_type': mapping.EntityType.USER})
+            {
+                'domain_id': self.domainB['id'],
+                'local_id': local_id4,
+                'entity_type': mapping.EntityType.USER,
+            }
+        )
         self.assertIsNone(
             PROVIDERS.id_mapping_api.get_public_id(local_entity4)
         )
@@ -339,16 +449,26 @@ class SqlIDMapping(test_backend_sql.SqlTests):
         # Create five mappings:
         # two users in domainA, one group and two users in domainB
         local_entities = [
-            {'domain_id': self.domainA['id'],
-             'entity_type': mapping.EntityType.USER},
-            {'domain_id': self.domainA['id'],
-             'entity_type': mapping.EntityType.USER},
-            {'domain_id': self.domainB['id'],
-             'entity_type': mapping.EntityType.GROUP},
-            {'domain_id': self.domainB['id'],
-             'entity_type': mapping.EntityType.USER},
-            {'domain_id': self.domainB['id'],
-             'entity_type': mapping.EntityType.USER}
+            {
+                'domain_id': self.domainA['id'],
+                'entity_type': mapping.EntityType.USER,
+            },
+            {
+                'domain_id': self.domainA['id'],
+                'entity_type': mapping.EntityType.USER,
+            },
+            {
+                'domain_id': self.domainB['id'],
+                'entity_type': mapping.EntityType.GROUP,
+            },
+            {
+                'domain_id': self.domainB['id'],
+                'entity_type': mapping.EntityType.USER,
+            },
+            {
+                'domain_id': self.domainB['id'],
+                'entity_type': mapping.EntityType.USER,
+            },
         ]
         for e in local_entities:
             e['local_id'] = uuid.uuid4().hex
@@ -368,7 +488,7 @@ class SqlIDMapping(test_backend_sql.SqlTests):
                 )
             )
             domain_a_mappings = [m.to_dict() for m in domain_a_mappings]
-        self.assertItemsEqual(local_entities[:2], domain_a_mappings)
+        self.assertCountEqual(local_entities[:2], domain_a_mappings)
 
     def test_get_domain_mapping_list_by_user_entity_type(self):
         local_entities = self._prepare_domain_mappings_for_list()
@@ -382,9 +502,10 @@ class SqlIDMapping(test_backend_sql.SqlTests):
                     self.domainB['id'], entity_type=mapping.EntityType.USER
                 )
             )
-            domain_b_mappings_user = [m.to_dict()
-                                      for m in domain_b_mappings_user]
-        self.assertItemsEqual(local_entities[-2:], domain_b_mappings_user)
+            domain_b_mappings_user = [
+                m.to_dict() for m in domain_b_mappings_user
+            ]
+        self.assertCountEqual(local_entities[-2:], domain_b_mappings_user)
 
     def test_get_domain_mapping_list_by_group_entity_type(self):
         local_entities = self._prepare_domain_mappings_for_list()
@@ -401,4 +522,4 @@ class SqlIDMapping(test_backend_sql.SqlTests):
                 )
             )
             domain_b_mappings_group = domain_b_mappings_group.first().to_dict()
-        self.assertItemsEqual(local_entities[2], domain_b_mappings_group)
+        self.assertCountEqual(local_entities[2], domain_b_mappings_group)
