@@ -22,10 +22,10 @@ from keystone.tests.unit.catalog import test_backends as catalog_tests
 from keystone.tests.unit import default_fixtures
 from keystone.tests.unit.ksfixtures import database
 
-
 PROVIDERS = provider_api.ProviderAPIs
-BROKEN_WRITE_FUNCTIONALITY_MSG = ("Templated backend doesn't correctly "
-                                  "implement write operations")
+BROKEN_WRITE_FUNCTIONALITY_MSG = (
+    "Templated backend doesn't correctly implement write operations"
+)
 
 
 class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
@@ -37,30 +37,31 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
                 'publicURL': 'http://localhost:8774/v1.1/bar',
                 'internalURL': 'http://localhost:8774/v1.1/bar',
                 'name': "'Compute Service'",
-                'id': '2'
+                'id': '2',
             },
             'identity': {
                 'adminURL': 'http://localhost:35357/v3',
                 'publicURL': 'http://localhost:5000/v3',
                 'internalURL': 'http://localhost:35357/v3',
                 'name': "'Identity Service'",
-                'id': '1'
-            }
+                'id': '1',
+            },
         }
     }
 
     def setUp(self):
-        super(TestTemplatedCatalog, self).setUp()
+        super().setUp()
         self.useFixture(database.Database())
         self.load_backends()
         self.load_fixtures(default_fixtures)
 
     def config_overrides(self):
-        super(TestTemplatedCatalog, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(
             group='catalog',
             driver='templated',
-            template_file=unit.dirs.tests('default_catalog.templates'))
+            template_file=unit.dirs.tests('default_catalog.templates'),
+        )
 
     def test_get_catalog(self):
         catalog_ref = PROVIDERS.catalog_api.get_catalog('foo', 'bar')
@@ -83,13 +84,16 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
 
     def test_get_v3_catalog_endpoint_disabled(self):
         self.skip_test_overrides(
-            "Templated backend doesn't have disabled endpoints")
+            "Templated backend doesn't have disabled endpoints"
+        )
 
     def assert_catalogs_equal(self, expected, observed):
         def sort_key(d):
             return d['id']
-        for e, o in zip(sorted(expected, key=sort_key),
-                        sorted(observed, key=sort_key)):
+
+        for e, o in zip(
+            sorted(expected, key=sort_key), sorted(observed, key=sort_key)
+        ):
             expected_endpoints = e.pop('endpoints')
             observed_endpoints = o.pop('endpoints')
             self.assertDictEqual(e, o)
@@ -100,32 +104,51 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         project_id = uuid.uuid4().hex
         catalog_ref = PROVIDERS.catalog_api.get_v3_catalog(user_id, project_id)
         exp_catalog = [
-            {'endpoints': [
-                {'interface': 'admin',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:8774/v1.1/%s' % project_id},
-                {'interface': 'public',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:8774/v1.1/%s' % project_id},
-                {'interface': 'internal',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:8774/v1.1/%s' % project_id}],
-             'type': 'compute',
-             'name': "'Compute Service'",
-             'id': '2'},
-            {'endpoints': [
-                {'interface': 'admin',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:35357/v3'},
-                {'interface': 'public',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:5000/v3'},
-                {'interface': 'internal',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:35357/v3'}],
-             'type': 'identity',
-             'name': "'Identity Service'",
-             'id': '1'}]
+            {
+                'endpoints': [
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:8774/v1.1/%s' % project_id,
+                    },
+                ],
+                'type': 'compute',
+                'name': "'Compute Service'",
+                'id': '2',
+            },
+            {
+                'endpoints': [
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:35357/v3',
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:5000/v3',
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:35357/v3',
+                    },
+                ],
+                'type': 'identity',
+                'name': "'Identity Service'",
+                'id': '1',
+            },
+        ]
         self.assert_catalogs_equal(exp_catalog, catalog_ref)
 
     def test_get_multi_region_v3_catalog(self):
@@ -136,54 +159,86 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
 
         # Load the multi-region catalog.
         catalog_api._load_templates(
-            unit.dirs.tests('default_catalog_multi_region.templates'))
+            unit.dirs.tests('default_catalog_multi_region.templates')
+        )
 
         catalog_ref = catalog_api.get_v3_catalog(user_id, project_id)
         exp_catalog = [
-            {'endpoints': [
-                {'interface': 'admin',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:8774/v1.1/%s' % project_id},
-                {'interface': 'public',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:8774/v1.1/%s' % project_id},
-                {'interface': 'internal',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:8774/v1.1/%s' % project_id},
-                {'interface': 'admin',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:8774/v1.1/%s' % project_id},
-                {'interface': 'public',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:8774/v1.1/%s' % project_id},
-                {'interface': 'internal',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:8774/v1.1/%s' % project_id}],
+            {
+                'endpoints': [
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:8774/v1.1/%s' % project_id,
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:8774/v1.1/%s' % project_id,
+                    },
+                ],
                 'type': 'compute',
                 'name': "'Compute Service'",
-                'id': '2'},
-            {'endpoints': [
-                {'interface': 'admin',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:35357/v3'},
-                {'interface': 'public',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:5000/v3'},
-                {'interface': 'internal',
-                 'region': 'RegionOne',
-                 'url': 'http://region-one:35357/v3'},
-                {'interface': 'admin',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:35357/v3'},
-                {'interface': 'public',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:5000/v3'},
-                {'interface': 'internal',
-                 'region': 'RegionTwo',
-                 'url': 'http://region-two:35357/v3'}],
+                'id': '2',
+            },
+            {
+                'endpoints': [
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:35357/v3',
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:5000/v3',
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionOne',
+                        'url': 'http://region-one:35357/v3',
+                    },
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:35357/v3',
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:5000/v3',
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionTwo',
+                        'url': 'http://region-two:35357/v3',
+                    },
+                ],
                 'type': 'identity',
                 'name': "'Identity Service'",
-                'id': '1'}]
+                'id': '1',
+            },
+        ]
         self.assert_catalogs_equal(exp_catalog, catalog_ref)
 
     def test_get_catalog_ignores_endpoints_with_invalid_urls(self):
@@ -193,23 +248,35 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         # endpoint which contains this kind of URL.
         catalog_ref = PROVIDERS.catalog_api.get_v3_catalog(user_id, project_id)
         exp_catalog = [
-            {'endpoints': [],
-             'type': 'compute',
-             'name': "'Compute Service'",
-             'id': '2'},
-            {'endpoints': [
-                {'interface': 'admin',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:35357/v3'},
-                {'interface': 'public',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:5000/v3'},
-                {'interface': 'internal',
-                 'region': 'RegionOne',
-                 'url': 'http://localhost:35357/v3'}],
-             'type': 'identity',
-             'name': "'Identity Service'",
-             'id': '1'}]
+            {
+                'endpoints': [],
+                'type': 'compute',
+                'name': "'Compute Service'",
+                'id': '2',
+            },
+            {
+                'endpoints': [
+                    {
+                        'interface': 'admin',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:35357/v3',
+                    },
+                    {
+                        'interface': 'public',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:5000/v3',
+                    },
+                    {
+                        'interface': 'internal',
+                        'region': 'RegionOne',
+                        'url': 'http://localhost:35357/v3',
+                    },
+                ],
+                'type': 'identity',
+                'name': "'Identity Service'",
+                'id': '1',
+            },
+        ]
         self.assert_catalogs_equal(exp_catalog, catalog_ref)
 
     def test_list_regions_filtered_by_parent_region_id(self):
@@ -222,16 +289,21 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         hints = {}
         services = PROVIDERS.catalog_api.list_services(hints=hints)
         exp_services = [
-            {'type': 'compute',
-             'description': '',
-             'enabled': True,
-             'name': "'Compute Service'",
-             'id': 'compute'},
-            {'type': 'identity',
-             'description': '',
-             'enabled': True,
-             'name': "'Identity Service'",
-             'id': 'identity'}]
+            {
+                'type': 'compute',
+                'description': '',
+                'enabled': True,
+                'name': "'Compute Service'",
+                'id': 'compute',
+            },
+            {
+                'type': 'identity',
+                'description': '',
+                'enabled': True,
+                'name': "'Identity Service'",
+                'id': 'identity',
+            },
+        ]
         self.assertCountEqual(exp_services, services)
 
     # NOTE(dstanek): the following methods have been overridden
@@ -263,8 +335,10 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
     def test_avoid_creating_circular_references_in_regions_update(self):
         self.skip_test_overrides(BROKEN_WRITE_FUNCTIONALITY_MSG)
 
-    @mock.patch.object(catalog_base.CatalogDriverBase,
-                       "_ensure_no_circle_in_hierarchical_regions")
+    @mock.patch.object(
+        catalog_base.CatalogDriverBase,
+        "_ensure_no_circle_in_hierarchical_regions",
+    )
     def test_circular_regions_can_be_deleted(self, mock_ensure_on_circle):
         self.skip_test_overrides(BROKEN_WRITE_FUNCTIONALITY_MSG)
 
@@ -299,7 +373,8 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
 
     def test_get_endpoint_returns_not_found(self):
         self.skip_test_overrides(
-            "Templated backend doesn't use IDs for endpoints.")
+            "Templated backend doesn't use IDs for endpoints."
+        )
 
     def test_delete_endpoint_returns_not_found(self):
         self.skip_test_overrides(BROKEN_WRITE_FUNCTIONALITY_MSG)
@@ -311,11 +386,13 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         self.skip_test_overrides(BROKEN_WRITE_FUNCTIONALITY_MSG)
 
     def test_list_endpoints(self):
-        expected_urls = set(['http://localhost:5000/v3',
-                             'http://localhost:35357/v3',
-                             'http://localhost:8774/v1.1/$(tenant_id)s'])
+        expected_urls = {
+            'http://localhost:5000/v3',
+            'http://localhost:35357/v3',
+            'http://localhost:8774/v1.1/$(tenant_id)s',
+        }
         endpoints = PROVIDERS.catalog_api.list_endpoints()
-        self.assertEqual(expected_urls, set(e['url'] for e in endpoints))
+        self.assertEqual(expected_urls, {e['url'] for e in endpoints})
 
     @unit.skip_if_cache_disabled('catalog')
     def test_invalidate_cache_when_updating_endpoint(self):
@@ -325,16 +402,15 @@ class TestTemplatedCatalog(unit.TestCase, catalog_tests.CatalogTests):
         # Deleting endpoint group association is not supported by the templated
         # driver, but it should be silent about it and not raise an error.
         PROVIDERS.catalog_api.delete_endpoint_group_association_by_project(
-            uuid.uuid4().hex)
+            uuid.uuid4().hex
+        )
 
     def test_delete_association_by_endpoint(self):
         # Deleting endpoint association is not supported by the templated
         # driver, but it should be silent about it and not raise an error.
-        PROVIDERS.catalog_api.delete_association_by_endpoint(
-            uuid.uuid4().hex)
+        PROVIDERS.catalog_api.delete_association_by_endpoint(uuid.uuid4().hex)
 
     def test_delete_association_by_project(self):
         # Deleting endpoint association is not supported by the templated
         # driver, but it should be silent about it and not raise an error.
-        PROVIDERS.catalog_api.delete_association_by_project(
-            uuid.uuid4().hex)
+        PROVIDERS.catalog_api.delete_association_by_project(uuid.uuid4().hex)
