@@ -19,18 +19,21 @@ from oslo_config import generator
 import keystone.conf
 from keystone.tests import unit
 
-
 CONF = keystone.conf.CONF
 
 
 class ConfigTestCase(unit.TestCase):
 
     def config_files(self):
-        config_files = super(ConfigTestCase, self).config_files()
+        config_files = super().config_files()
 
         sample_file = 'keystone.conf.sample'
-        args = ['--namespace', 'keystone', '--output-file',
-                unit.dirs.etc(sample_file)]
+        args = [
+            '--namespace',
+            'keystone',
+            '--output-file',
+            unit.dirs.etc(sample_file),
+        ]
 
         generator.main(args=args)
         config_files.insert(0, unit.dirs.etc(sample_file))
