@@ -12,13 +12,7 @@
 
 import textwrap
 
-try:
-    import pep8
-except ImportError:
-    # NTOE(stevemar): pycodestyle is not yet in global-requirements, but
-    # packagers have begun pycodestyle (the renamed version of pep8)
-    # See: https://github.com/PyCQA/pycodestyle/issues/466
-    import pycodestyle as pep8
+import pycodestyle
 
 from keystone.tests.hacking import checks
 from keystone.tests import unit
@@ -28,34 +22,35 @@ from keystone.tests.unit.ksfixtures import hacking as hacking_fixtures
 class BaseStyleCheck(unit.BaseTestCase):
 
     def setUp(self):
-        super(BaseStyleCheck, self).setUp()
+        super().setUp()
         self.code_ex = self.useFixture(self.get_fixture())
         self.addCleanup(delattr, self, 'code_ex')
 
     def get_checker(self):
         """Return the checker to be used for tests in this class."""
-        raise NotImplementedError('subclasses must provide '
-                                  'a real implementation')
+        raise NotImplementedError(
+            'subclasses must provide a real implementation'
+        )
 
     def get_fixture(self):
         return hacking_fixtures.HackingCode()
 
     def run_check(self, code):
-        pep8.register_check(self.get_checker())
+        pycodestyle.register_check(self.get_checker())
 
         lines = textwrap.dedent(code).strip().splitlines(True)
 
         # Load all keystone hacking checks, they are of the form Kddd,
         # where ddd can from range from 000-999
-        guide = pep8.StyleGuide(select='K')
-        checker = pep8.Checker(lines=lines, options=guide.options)
+        guide = pycodestyle.StyleGuide(select='K')
+        checker = pycodestyle.Checker(lines=lines, options=guide.options)
         checker.check_all()
         checker.report._deferred_print.sort()
         return checker.report._deferred_print
 
     def assert_has_errors(self, code, expected_errors=None):
         actual_errors = [e[:3] for e in self.run_check(code)]
-        self.assertItemsEqual(expected_errors or [], actual_errors)
+        self.assertCountEqual(expected_errors or [], actual_errors)
 
 
 class TestCheckForMutableDefaultArgs(BaseStyleCheck):
@@ -93,8 +88,9 @@ class TestTranslationChecks(BaseStyleCheck):
         actual_errors = (e[:3] for e in self.run_check(code))
         # adjust line numbers to make the fixture data more readable.
         import_lines = len(self.code_ex.shared_imports.split('\n')) - 1
-        actual_errors = [(e[0] - import_lines, e[1], e[2])
-                         for e in actual_errors]
+        actual_errors = [
+            (e[0] - import_lines, e[1], e[2]) for e in actual_errors
+        ]
         self.assertEqual(expected_errors or [], actual_errors)
 
     def test_for_translations(self):
