@@ -14,7 +14,6 @@
 # under the License.
 
 import ldap.modlist
-from six import PY2
 
 from keystone.common import provider_api
 import keystone.conf
@@ -23,20 +22,12 @@ from keystone import identity
 from keystone.tests import unit
 from keystone.tests.unit import test_ldap_livetest
 
-
 CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
 def create_object(dn, attrs):
-    if PY2:
-        # NOTE: Once https://github.com/python-ldap/python-ldap/issues/249
-        # is released, we can pass bytes_strictness='warn' as a parameter to
-        # ldap.initialize instead of setting it after ldap.initialize.
-        conn = ldap.initialize(CONF.ldap.url, bytes_mode=False)
-        conn.bytes_strictness = 'warn'
-    else:
-        conn = ldap.initialize(CONF.ldap.url)
+    conn = ldap.initialize(CONF.ldap.url)
     conn.simple_bind_s(CONF.ldap.user, CONF.ldap.password)
     ldif = ldap.modlist.addModlist(attrs)
     conn.add_s(dn, ldif)
@@ -49,19 +40,25 @@ class LiveTLSLDAPIdentity(test_ldap_livetest.LiveLDAPIdentity):
         self.skip_if_env_not_set('ENABLE_TLS_LDAP_LIVE_TEST')
 
     def config_files(self):
-        config_files = super(LiveTLSLDAPIdentity, self).config_files()
+        config_files = super().config_files()
         config_files.append(unit.dirs.tests_conf('backend_tls_liveldap.conf'))
         return config_files
 
     def test_tls_certfile_demand_option(self):
-        self.config_fixture.config(group='ldap',
-                                   use_tls=True,
-                                   tls_cacertdir=None,
-                                   tls_req_cert='demand')
+        self.config_fixture.config(
+            group='ldap',
+            use_tls=True,
+            tls_cacertdir=None,
+            tls_req_cert='demand',
+        )
         PROVIDERS.identity_api = identity.backends.ldap.Identity()
 
-        user = unit.create_user(PROVIDERS.identity_api, 'default',
-                                name='fake1', password='fakepass1')
+        user = unit.create_user(
+            PROVIDERS.identity_api,
+            'default',
+            name='fake1',
+            password='fakepass1',
+        )
         user_ref = PROVIDERS.identity_api.get_user(user['id'])
         self.assertEqual(user['id'], user_ref['id'])
 
@@ -70,21 +67,25 @@ class LiveTLSLDAPIdentity(test_ldap_livetest.LiveLDAPIdentity):
 
         PROVIDERS.identity_api.delete_user(user['id'])
         self.assertRaises(
-            exception.UserNotFound,
-            PROVIDERS.identity_api.get_user,
-            user['id']
+            exception.UserNotFound, PROVIDERS.identity_api.get_user, user['id']
         )
 
     def test_tls_certdir_demand_option(self):
-        self.config_fixture.config(group='ldap',
-                                   use_tls=True,
-                                   tls_cacertdir=None,
-                                   tls_req_cert='demand')
+        self.config_fixture.config(
+            group='ldap',
+            use_tls=True,
+            tls_cacertdir=None,
+            tls_req_cert='demand',
+        )
         PROVIDERS.identity_api = identity.backends.ldap.Identity()
 
-        user = unit.create_user(PROVIDERS.identity_api, 'default',
-                                id='fake1', name='fake1',
-                                password='fakepass1')
+        user = unit.create_user(
+            PROVIDERS.identity_api,
+            'default',
+            id='fake1',
+            name='fake1',
+            password='fakepass1',
+        )
         user_ref = PROVIDERS.identity_api.get_user('fake1')
         self.assertEqual('fake1', user_ref['id'])
 
@@ -93,9 +94,7 @@ class LiveTLSLDAPIdentity(test_ldap_livetest.LiveLDAPIdentity):
 
         PROVIDERS.identity_api.delete_user('fake1')
         self.assertRaises(
-            exception.UserNotFound,
-            PROVIDERS.identity_api.get_user,
-            'fake1'
+            exception.UserNotFound, PROVIDERS.identity_api.get_user, 'fake1'
         )
 
     def test_tls_bad_certfile(self):
@@ -104,7 +103,8 @@ class LiveTLSLDAPIdentity(test_ldap_livetest.LiveLDAPIdentity):
             use_tls=True,
             tls_req_cert='demand',
             tls_cacertfile='/etc/keystone/ssl/certs/mythicalcert.pem',
-            tls_cacertdir=None)
+            tls_cacertdir=None,
+        )
         PROVIDERS.identity_api = identity.backends.ldap.Identity()
 
         user = unit.new_user_ref('default')
@@ -116,7 +116,8 @@ class LiveTLSLDAPIdentity(test_ldap_livetest.LiveLDAPIdentity):
             use_tls=True,
             tls_cacertfile=None,
             tls_req_cert='demand',
-            tls_cacertdir='/etc/keystone/ssl/mythicalcertdir')
+            tls_cacertdir='/etc/keystone/ssl/mythicalcertdir',
+        )
         PROVIDERS.identity_api = identity.backends.ldap.Identity()
 
         user = unit.new_user_ref('default')
