@@ -14,11 +14,12 @@
 
 import copy
 import hashlib
+import http.client
+import typing as ty
 from unittest import mock
 import uuid
 
 import fixtures
-import http.client
 import webtest
 
 from keystone.auth import core as auth_core
@@ -34,33 +35,36 @@ from keystone.tests import unit
 from keystone.tests.unit import mapping_fixtures
 from keystone.tests.unit import test_backend_sql
 
-
 CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
 
 
 class MiddlewareRequestTestBase(unit.TestCase):
 
-    MIDDLEWARE_CLASS = None  # override this in subclasses
+    MIDDLEWARE_CLASS: ty.Any = None  # override this in subclasses
 
     def _application(self):
         """A base wsgi application that returns a simple response."""
+
         def app(environ, start_response):
             # WSGI requires the body of the response to be bytes
             body = uuid.uuid4().hex.encode('utf-8')
-            resp_headers = [('Content-Type', 'text/html; charset=utf8'),
-                            ('Content-Length', str(len(body)))]
+            resp_headers = [
+                ('Content-Type', 'text/html; charset=utf8'),
+                ('Content-Length', str(len(body))),
+            ]
             start_response('200 OK', resp_headers)
             return [body]
 
         return app
 
-    def _generate_app_response(self, app, headers=None, method='get',
-                               path='/', **kwargs):
+    def _generate_app_response(
+        self, app, headers=None, method='get', path='/', **kwargs
+    ):
         """Given a wsgi application wrap it in webtest and call it."""
-        return getattr(webtest.TestApp(app), method)(path,
-                                                     headers=headers or {},
-                                                     **kwargs)
+        return getattr(webtest.TestApp(app), method)(
+            path, headers=headers or {}, **kwargs
+        )
 
     def _middleware_failure(self, exc, *args, **kwargs):
         """Assert that an exception is being thrown from process_request."""
@@ -80,9 +84,9 @@ class MiddlewareRequestTestBase(unit.TestCase):
 
             def fill_context(i_self, *i_args, **i_kwargs):
                 # i_ to distinguish it from and not clobber the outer vars
-                e = self.assertRaises(exc,
-                                      super(_Failing, i_self).fill_context,
-                                      *i_args, **i_kwargs)
+                e = self.assertRaises(
+                    exc, super().fill_context, *i_args, **i_kwargs
+                )
                 i_self._called = True
                 raise e
 
@@ -105,18 +109,20 @@ class MiddlewareRequestTestBase(unit.TestCase):
         return self._do_middleware_response(*args, **kwargs).request
 
 
-class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
-                                MiddlewareRequestTestBase):
+class AuthContextMiddlewareTest(
+    test_backend_sql.SqlTests, MiddlewareRequestTestBase
+):
 
     MIDDLEWARE_CLASS = auth_context.AuthContextMiddleware
 
     def setUp(self):
-        super(AuthContextMiddlewareTest, self).setUp()
+        super().setUp()
         self.client_issuer = uuid.uuid4().hex
         self.untrusted_client_issuer = uuid.uuid4().hex
         self.trusted_issuer = self.client_issuer
-        self.config_fixture.config(group='tokenless_auth',
-                                   trusted_issuer=[self.trusted_issuer])
+        self.config_fixture.config(
+            group='tokenless_auth', trusted_issuer=[self.trusted_issuer]
+        )
 
         # client_issuer is encoded because you can't hash
         # unicode objects with hashlib.
@@ -142,16 +148,15 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         PROVIDERS.resource_api.create_project(self.project_id, self.project)
 
         # 3) Create a user in new domain.
-        self.user = unit.new_user_ref(domain_id=self.domain_id,
-                                      project_id=self.project_id)
+        self.user = unit.new_user_ref(
+            domain_id=self.domain_id, project_id=self.project_id
+        )
 
         self.user = PROVIDERS.identity_api.create_user(self.user)
 
         # Add IDP
         self.idp = self._idp_ref(id=self.idp_id)
-        PROVIDERS.federation_api.create_idp(
-            self.idp['id'], self.idp
-        )
+        PROVIDERS.federation_api.create_idp(self.idp['id'], self.idp)
 
         # Add a role
         self.role = unit.new_role_ref()
@@ -167,13 +172,15 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         PROVIDERS.assignment_api.add_role_to_user_and_project(
             user_id=self.user['id'],
             project_id=self.project_id,
-            role_id=self.role_id)
+            role_id=self.role_id,
+        )
 
         # Assign a role to the group on a project
         PROVIDERS.assignment_api.create_grant(
             role_id=self.role_id,
             group_id=self.group['id'],
-            project_id=self.project_id)
+            project_id=self.project_id,
+        )
 
     def _load_mapping_rules(self, rules):
         # Add a mapping
@@ -192,14 +199,14 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         idp = {
             'id': id or uuid.uuid4().hex,
             'enabled': True,
-            'description': uuid.uuid4().hex
+            'description': uuid.uuid4().hex,
         }
         return idp
 
     def _proto_ref(self, mapping_id=None):
         proto = {
             'id': uuid.uuid4().hex,
-            'mapping_id': mapping_id or uuid.uuid4().hex
+            'mapping_id': mapping_id or uuid.uuid4().hex,
         }
         return proto
 
@@ -211,7 +218,7 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         return {
             'id': uuid.uuid4().hex,
             'rules': mapped_rules,
-            'schema_version': "1.0"
+            'schema_version': "1.0",
         }
 
     def _assert_tokenless_auth_context(self, context, ephemeral_user=False):
@@ -220,15 +227,18 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         self.assertIn(self.role_name, context['roles'])
         if ephemeral_user:
             self.assertEqual(self.group['id'], context['group_ids'][0])
-            self.assertEqual('ephemeral',
-                             context[federation_constants.PROTOCOL])
-            self.assertEqual(self.idp_id,
-                             context[federation_constants.IDENTITY_PROVIDER])
+            self.assertEqual(
+                'ephemeral', context[federation_constants.PROTOCOL]
+            )
+            self.assertEqual(
+                self.idp_id, context[federation_constants.IDENTITY_PROVIDER]
+            )
         else:
             self.assertEqual(self.user['id'], context['user_id'])
 
-    def _assert_tokenless_request_context(self, request_context,
-                                          ephemeral_user=False):
+    def _assert_tokenless_request_context(
+        self, request_context, ephemeral_user=False
+    ):
         self.assertIsNotNone(request_context)
         self.assertEqual(self.project_id, request_context.project_id)
         self.assertIn(self.role_name, request_context.roles)
@@ -239,8 +249,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         stub_value = uuid.uuid4().hex
         env = {authorization.AUTH_CONTEXT_ENV: stub_value}
         req = self._do_middleware_request(extra_environ=env)
-        self.assertEqual(stub_value,
-                         req.environ.get(authorization.AUTH_CONTEXT_ENV))
+        self.assertEqual(
+            stub_value, req.environ.get(authorization.AUTH_CONTEXT_ENV)
+        )
 
     def test_not_applicable_to_token_request(self):
         req = self._do_middleware_request(path='/auth/tokens', method='post')
@@ -265,40 +276,39 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         # references to issuer of the client certificate.
         env['SSL_CLIENT_I_DN'] = self.client_issuer
         env['HTTP_X_PROJECT_NAME'] = uuid.uuid4().hex
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_has_only_issuer_and_project_domain_name_request(self):
         env = {}
         env['SSL_CLIENT_I_DN'] = self.client_issuer
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = uuid.uuid4().hex
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_has_only_issuer_and_project_domain_id_request(self):
         env = {}
         env['SSL_CLIENT_I_DN'] = self.client_issuer
         env['HTTP_X_PROJECT_DOMAIN_ID'] = uuid.uuid4().hex
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_missing_both_domain_and_project_request(self):
         env = {}
         env['SSL_CLIENT_I_DN'] = self.client_issuer
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_empty_trusted_issuer_list(self):
         env = {}
         env['SSL_CLIENT_I_DN'] = self.client_issuer
         env['HTTP_X_PROJECT_ID'] = uuid.uuid4().hex
 
-        self.config_fixture.config(group='tokenless_auth',
-                                   trusted_issuer=[])
+        self.config_fixture.config(group='tokenless_auth', trusted_issuer=[])
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -324,7 +334,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -340,7 +351,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -357,7 +369,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -374,7 +387,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -390,11 +404,12 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_mapping_with_userid_and_domainid_success(self):
         env = {}
@@ -405,7 +420,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_ID'] = self.domain_id
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERID_AND_DOMAINID)
+            mapping_fixtures.MAPPING_WITH_USERID_AND_DOMAINID
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -422,7 +438,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERID_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERID_AND_DOMAINNAME
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -439,7 +456,8 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_ID'] = self.domain_id
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID
+        )
 
         req = self._do_middleware_request(extra_environ=env)
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
@@ -454,12 +472,11 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_DOMAIN_ID'] = self.domain_id
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
-        self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_DOMAINNAME_ONLY)
+        self._load_mapping_rules(mapping_fixtures.MAPPING_WITH_DOMAINNAME_ONLY)
 
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_only_domain_id_fail(self):
         env = {}
@@ -468,12 +485,11 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_DOMAIN_ID'] = self.domain_id
         env['SSL_CLIENT_DOMAIN_ID'] = self.domain_id
 
-        self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_DOMAINID_ONLY)
+        self._load_mapping_rules(mapping_fixtures.MAPPING_WITH_DOMAINID_ONLY)
 
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_missing_domain_data_fail(self):
         env = {}
@@ -482,12 +498,11 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_DOMAIN_ID'] = self.domain_id
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
 
-        self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_ONLY)
+        self._load_mapping_rules(mapping_fixtures.MAPPING_WITH_USERNAME_ONLY)
 
-        self._middleware_failure(exception.ValidationError,
-                                 extra_environ=env,
-                                 status=400)
+        self._middleware_failure(
+            exception.ValidationError, extra_environ=env, status=400
+        )
 
     def test_userid_success(self):
         env = {}
@@ -513,13 +528,15 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
 
         self.domain['enabled'] = False
         self.domain = PROVIDERS.resource_api.update_domain(
-            self.domain['id'], self.domain)
+            self.domain['id'], self.domain
+        )
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID)
-        self._middleware_failure(exception.Unauthorized,
-                                 extra_environ=env,
-                                 status=401)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID
+        )
+        self._middleware_failure(
+            exception.Unauthorized, extra_environ=env, status=401
+        )
 
     def test_user_disable_fail(self):
         env = {}
@@ -535,10 +552,10 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         )
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINID
+        )
 
-        self._middleware_failure(AssertionError,
-                                 extra_environ=env)
+        self._middleware_failure(AssertionError, extra_environ=env)
 
     def test_invalid_user_fail(self):
         env = {}
@@ -549,11 +566,12 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['SSL_CLIENT_DOMAIN_NAME'] = self.domain_name
 
         self._load_mapping_rules(
-            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME)
+            mapping_fixtures.MAPPING_WITH_USERNAME_AND_DOMAINNAME
+        )
 
-        self._middleware_failure(exception.UserNotFound,
-                                 extra_environ=env,
-                                 status=404)
+        self._middleware_failure(
+            exception.UserNotFound, extra_environ=env, status=404
+        )
 
     def test_ephemeral_success(self):
         env = {}
@@ -561,8 +579,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = self.project_name
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         mapping = copy.deepcopy(mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER)
         mapping['rules'][0]['local'][0]['group']['id'] = self.group['id']
@@ -572,8 +591,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
         self._assert_tokenless_auth_context(context, ephemeral_user=True)
         request_context = req.environ.get(keystone_context.REQUEST_CONTEXT_ENV)
-        self._assert_tokenless_request_context(request_context,
-                                               ephemeral_user=True)
+        self._assert_tokenless_request_context(
+            request_context, ephemeral_user=True
+        )
 
     def test_ephemeral_and_group_domain_name_mapping_success(self):
         env = {}
@@ -581,14 +601,17 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = self.project_name
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         mapping = copy.deepcopy(
-            mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER_AND_GROUP_DOMAIN_NAME)
+            mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER_AND_GROUP_DOMAIN_NAME
+        )
         mapping['rules'][0]['local'][0]['group']['name'] = self.group['name']
-        mapping['rules'][0]['local'][0]['group']['domain']['name'] = \
+        mapping['rules'][0]['local'][0]['group']['domain']['name'] = (
             self.domain['name']
+        )
         self._load_mapping_rules(mapping)
 
         req = self._do_middleware_request(extra_environ=env)
@@ -601,14 +624,16 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = self.project_name
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         # this mapping does not have the user type defined
         # and it should defaults to 'ephemeral' which is
         # the expected type for the test case.
         mapping = copy.deepcopy(
-            mapping_fixtures.MAPPING_FOR_DEFAULT_EPHEMERAL_USER)
+            mapping_fixtures.MAPPING_FOR_DEFAULT_EPHEMERAL_USER
+        )
         mapping['rules'][0]['local'][0]['group']['id'] = self.group['id']
         self._load_mapping_rules(mapping)
 
@@ -616,8 +641,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
         self._assert_tokenless_auth_context(context, ephemeral_user=True)
         request_context = req.environ.get(keystone_context.REQUEST_CONTEXT_ENV)
-        self._assert_tokenless_request_context(request_context,
-                                               ephemeral_user=True)
+        self._assert_tokenless_request_context(
+            request_context, ephemeral_user=True
+        )
 
     def test_ephemeral_any_user_success(self):
         """Verify ephemeral user does not need a specified user.
@@ -629,8 +655,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = self.project_name
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = uuid.uuid4().hex
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         mapping = copy.deepcopy(mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER)
         mapping['rules'][0]['local'][0]['group']['id'] = self.group['id']
@@ -640,8 +667,9 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         context = req.environ.get(authorization.AUTH_CONTEXT_ENV)
         self._assert_tokenless_auth_context(context, ephemeral_user=True)
         request_context = req.environ.get(keystone_context.REQUEST_CONTEXT_ENV)
-        self._assert_tokenless_request_context(request_context,
-                                               ephemeral_user=True)
+        self._assert_tokenless_request_context(
+            request_context, ephemeral_user=True
+        )
 
     def test_ephemeral_invalid_scope_fail(self):
         env = {}
@@ -649,16 +677,17 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = uuid.uuid4().hex
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = uuid.uuid4().hex
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         mapping = copy.deepcopy(mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER)
         mapping['rules'][0]['local'][0]['group']['id'] = self.group['id']
         self._load_mapping_rules(mapping)
 
-        self._middleware_failure(exception.Unauthorized,
-                                 extra_environ=env,
-                                 status=401)
+        self._middleware_failure(
+            exception.Unauthorized, extra_environ=env, status=401
+        )
 
     def test_ephemeral_no_group_found_fail(self):
         env = {}
@@ -666,15 +695,17 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_NAME'] = self.project_name
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='ephemeral')
+        self.config_fixture.config(
+            group='tokenless_auth', protocol='ephemeral'
+        )
         self.protocol_id = 'ephemeral'
         mapping = copy.deepcopy(mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER)
         mapping['rules'][0]['local'][0]['group']['id'] = uuid.uuid4().hex
         self._load_mapping_rules(mapping)
 
-        self._middleware_failure(exception.MappedGroupNotFound,
-                                 extra_environ=env)
+        self._middleware_failure(
+            exception.MappedGroupNotFound, extra_environ=env
+        )
 
     def test_ephemeral_incorrect_mapping_fail(self):
         """Test ephemeral user picking up the non-ephemeral user mapping.
@@ -688,15 +719,15 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env['HTTP_X_PROJECT_DOMAIN_NAME'] = self.domain_name
         env['SSL_CLIENT_USER_NAME'] = self.user['name']
         # This will pick up the incorrect mapping
-        self.config_fixture.config(group='tokenless_auth',
-                                   protocol='x509')
+        self.config_fixture.config(group='tokenless_auth', protocol='x509')
         self.protocol_id = 'x509'
         mapping = copy.deepcopy(mapping_fixtures.MAPPING_FOR_EPHEMERAL_USER)
         mapping['rules'][0]['local'][0]['group']['id'] = uuid.uuid4().hex
         self._load_mapping_rules(mapping)
 
-        self._middleware_failure(exception.MappedGroupNotFound,
-                                 extra_environ=env)
+        self._middleware_failure(
+            exception.MappedGroupNotFound, extra_environ=env
+        )
 
     def test_create_idp_id_success(self):
         env = {}
@@ -709,14 +740,17 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         env = {}
         env[uuid.uuid4().hex] = self.client_issuer
         auth = tokenless_auth.TokenlessAuthHelper(env)
-        expected_msg = ('Could not determine Identity Provider ID. The '
-                        'configuration option %s was not found in the '
-                        'request environment.' %
-                        CONF.tokenless_auth.issuer_attribute)
+        expected_msg = (
+            'Could not determine Identity Provider ID. The '
+            'configuration option %s was not found in the '
+            'request environment.' % CONF.tokenless_auth.issuer_attribute
+        )
         # Check the content of the exception message as well
-        self.assertRaisesRegex(exception.TokenlessAuthConfigError,
-                               expected_msg,
-                               auth._build_idp_id)
+        self.assertRaisesRegex(
+            exception.TokenlessAuthConfigError,
+            expected_msg,
+            auth._build_idp_id,
+        )
 
     def test_admin_token_context(self):
         self.config_fixture.config(admin_token='ADMIN')
@@ -727,8 +761,7 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
         self.assertNotIn('Invalid user token', log_fix.output)
 
     def test_request_non_admin(self):
-        self.config_fixture.config(
-            admin_token='ADMIN')
+        self.config_fixture.config(admin_token='ADMIN')
         log_fix = self.useFixture(fixtures.FakeLogger())
         headers = {authorization.AUTH_TOKEN_HEADER: 'NOT-ADMIN'}
         self._do_middleware_request(headers=headers)
@@ -741,15 +774,15 @@ class AuthContextMiddlewareTest(test_backend_sql.SqlTests,
             user_id=self.user['id'], methods=['password']
         )
         token = PROVIDERS.token_provider_api.issue_token(
-            context['user_id'], context['methods'], project_id=self.project_id,
-            auth_context=context
+            context['user_id'],
+            context['methods'],
+            project_id=self.project_id,
+            auth_context=context,
         )
-        headers = {
-            authorization.AUTH_TOKEN_HEADER: token.id.encode('utf-8')
-        }
-        with mock.patch.object(PROVIDERS.token_provider_api,
-                               'validate_token',
-                               return_value=token) as token_mock:
+        headers = {authorization.AUTH_TOKEN_HEADER: token.id.encode('utf-8')}
+        with mock.patch.object(
+            PROVIDERS.token_provider_api, 'validate_token', return_value=token
+        ) as token_mock:
             self._do_middleware_request(
                 path='/v3/projects', method='get', headers=headers
             )
