@@ -15,11 +15,10 @@
 
 import os
 import subprocess
+from unittest import mock
 import uuid
 
-import mock
 from oslo_policy import policy as common_policy
-import six
 
 from keystone.common import policies
 from keystone.common.rbac_enforcer import policy
@@ -29,7 +28,6 @@ from keystone.tests import unit
 from keystone.tests.unit import ksfixtures
 from keystone.tests.unit.ksfixtures import temporaryfile
 
-
 CONF = keystone.conf.CONF
 
 
@@ -40,7 +38,7 @@ class PolicyFileTestCase(unit.TestCase):
         # the config_overrides call.
         self.tempfile = self.useFixture(temporaryfile.SecureTempFile())
         self.tmpfilename = self.tempfile.file_name
-        super(PolicyFileTestCase, self).setUp()
+        super().setUp()
         self.target = {}
 
     def _policy_fixture(self):
@@ -57,20 +55,27 @@ class PolicyFileTestCase(unit.TestCase):
         with open(self.tmpfilename, "w") as policyfile:
             policyfile.write("""{"example:test": ["false:false"]}""")
         policy._ENFORCER._enforcer.clear()
-        self.assertRaises(exception.ForbiddenAction, policy.enforce,
-                          empty_credentials, action, self.target)
+        self.assertRaises(
+            exception.ForbiddenAction,
+            policy.enforce,
+            empty_credentials,
+            action,
+            self.target,
+        )
 
 
 class PolicyTestCase(unit.TestCase):
     def setUp(self):
-        super(PolicyTestCase, self).setUp()
+        super().setUp()
         self.rules = {
             "true": [],
             "example:allowed": [],
             "example:denied": [["false:false"]],
             "example:get_http": [["http:http://www.example.com"]],
-            "example:my_file": [["role:compute_admin"],
-                                ["project_id:%(project_id)s"]],
+            "example:my_file": [
+                ["role:compute_admin"],
+                ["project_id:%(project_id)s"],
+            ],
             "example:early_and_fail": [["false:false", "rule:true"]],
             "example:early_or_success": [["rule:true"], ["false:false"]],
             "example:lowercase_admin": [["role:admin"], ["role:sysadmin"]],
@@ -88,13 +93,23 @@ class PolicyTestCase(unit.TestCase):
 
     def test_enforce_nonexistent_action_throws(self):
         action = "example:noexist"
-        self.assertRaises(exception.ForbiddenAction, policy.enforce,
-                          self.credentials, action, self.target)
+        self.assertRaises(
+            exception.ForbiddenAction,
+            policy.enforce,
+            self.credentials,
+            action,
+            self.target,
+        )
 
     def test_enforce_bad_action_throws(self):
         action = "example:denied"
-        self.assertRaises(exception.ForbiddenAction, policy.enforce,
-                          self.credentials, action, self.target)
+        self.assertRaises(
+            exception.ForbiddenAction,
+            policy.enforce,
+            self.credentials,
+            action,
+            self.target,
+        )
 
     def test_enforce_good_action(self):
         action = "example:allowed"
@@ -106,13 +121,23 @@ class PolicyTestCase(unit.TestCase):
         credentials = {'project_id': 'fake', 'roles': []}
         action = "example:my_file"
         policy.enforce(credentials, action, target_mine)
-        self.assertRaises(exception.ForbiddenAction, policy.enforce,
-                          credentials, action, target_not_mine)
+        self.assertRaises(
+            exception.ForbiddenAction,
+            policy.enforce,
+            credentials,
+            action,
+            target_not_mine,
+        )
 
     def test_early_AND_enforcement(self):
         action = "example:early_and_fail"
-        self.assertRaises(exception.ForbiddenAction, policy.enforce,
-                          self.credentials, action, self.target)
+        self.assertRaises(
+            exception.ForbiddenAction,
+            policy.enforce,
+            self.credentials,
+            action,
+            self.target,
+        )
 
     def test_early_OR_enforcement(self):
         action = "example:early_or_success"
@@ -131,11 +156,9 @@ class PolicyTestCase(unit.TestCase):
 class PolicyScopeTypesEnforcementTestCase(unit.TestCase):
 
     def setUp(self):
-        super(PolicyScopeTypesEnforcementTestCase, self).setUp()
+        super().setUp()
         rule = common_policy.RuleDefault(
-            name='foo',
-            check_str='',
-            scope_types=['system']
+            name='foo', check_str='', scope_types=['system']
         )
         policy._ENFORCER._enforcer.register_default(rule)
         self.credentials = {}
@@ -145,14 +168,17 @@ class PolicyScopeTypesEnforcementTestCase(unit.TestCase):
     def test_forbidden_is_raised_if_enforce_scope_is_true(self):
         self.config_fixture.config(group='oslo_policy', enforce_scope=True)
         self.assertRaises(
-            exception.ForbiddenAction, policy.enforce, self.credentials,
-            self.action, self.target
+            exception.ForbiddenAction,
+            policy.enforce,
+            self.credentials,
+            self.action,
+            self.target,
         )
 
     def test_warning_message_is_logged_if_enforce_scope_is_false(self):
         self.config_fixture.config(group='oslo_policy', enforce_scope=False)
         expected_msg = (
-            'Policy foo failed scope check. The token used to make the '
+            'Policy "foo": "" failed scope check. The token used to make the '
             'request was project scoped but the policy requires [\'system\'] '
             'scope. This behavior may change in the future where using the '
             'intended scope is required'
@@ -177,40 +203,60 @@ class PolicyJsonTestCase(unit.TestCase):
 
     def test_policies_loads(self):
         action = 'identity:list_projects'
-        target = {'user_id': uuid.uuid4().hex,
-                  'user.domain_id': uuid.uuid4().hex,
-                  'group.domain_id': uuid.uuid4().hex,
-                  'project.domain_id': uuid.uuid4().hex,
-                  'project_id': uuid.uuid4().hex,
-                  'domain_id': uuid.uuid4().hex}
-        credentials = {'username': uuid.uuid4().hex, 'token': uuid.uuid4().hex,
-                       'project_name': None, 'user_id': uuid.uuid4().hex,
-                       'roles': [u'admin'], 'is_admin': True,
-                       'is_admin_project': True, 'project_id': None,
-                       'domain_id': uuid.uuid4().hex}
+        target = {
+            'user_id': uuid.uuid4().hex,
+            'user.domain_id': uuid.uuid4().hex,
+            'group.domain_id': uuid.uuid4().hex,
+            'project.domain_id': uuid.uuid4().hex,
+            'project_id': uuid.uuid4().hex,
+            'domain_id': uuid.uuid4().hex,
+        }
+        credentials = {
+            'username': uuid.uuid4().hex,
+            'token': uuid.uuid4().hex,
+            'project_name': None,
+            'user_id': uuid.uuid4().hex,
+            'roles': ['admin'],
+            'is_admin': True,
+            'is_admin_project': True,
+            'project_id': None,
+            'domain_id': uuid.uuid4().hex,
+        }
 
         # The enforcer is setup behind the scenes and registers the in code
         # default policies.
-        result = policy._ENFORCER._enforcer.enforce(action, target,
-                                                    credentials)
+        result = policy._ENFORCER._enforcer.enforce(
+            action, target, credentials
+        )
         self.assertTrue(result)
 
     def test_all_targets_documented(self):
         policy_keys = self._get_default_policy_rules()
 
-        # These keys are in the policy.json but aren't targets.
+        # These keys are in the policy.yaml but aren't targets.
         policy_rule_keys = [
-            'admin_or_owner', 'admin_or_token_subject', 'admin_required',
-            'owner', 'service_admin_or_token_subject', 'service_or_admin',
-            'service_role', 'token_subject', ]
+            'admin_or_owner',
+            'admin_or_token_subject',
+            'admin_required',
+            'owner',
+            'service_admin_or_token_subject',
+            'service_or_admin',
+            'service_role',
+            'token_subject',
+            'domain_managed_target_role',
+        ]
 
         def read_doc_targets():
             # Parse the doc/source/policy_mapping.rst file and return the
             # targets.
 
             doc_path = os.path.join(
-                unit.ROOTDIR, 'doc', 'source', 'getting-started',
-                'policy_mapping.rst')
+                unit.ROOTDIR,
+                'doc',
+                'source',
+                'getting-started',
+                'policy_mapping.rst',
+            )
             with open(doc_path) as doc_file:
                 for line in doc_file:
                     if line.startswith('Target'):
@@ -226,10 +272,10 @@ class PolicyJsonTestCase(unit.TestCase):
                     if line.startswith('=='):
                         break
                     target, dummy, dummy = line.partition(' ')
-                    yield six.text_type(target)
+                    yield str(target)
 
         doc_targets = list(read_doc_targets())
-        self.assertItemsEqual(policy_keys, doc_targets + policy_rule_keys)
+        self.assertCountEqual(policy_keys, doc_targets + policy_rule_keys)
 
 
 class GeneratePolicyFileTestCase(unit.TestCase):
@@ -241,7 +287,7 @@ class GeneratePolicyFileTestCase(unit.TestCase):
         ret_val = subprocess.Popen(
             ['oslopolicy-policy-generator', '--namespace', 'keystone'],
             stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE
+            stderr=subprocess.PIPE,
         )
-        ret_val.communicate()
-        self.assertEqual(ret_val.returncode, 0)
+        output = ret_val.communicate()
+        self.assertEqual(ret_val.returncode, 0, output)
