@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from six.moves import http_client
+import http.client
+
 from testtools import matchers
 
 from keystone.common import provider_api
@@ -34,14 +35,17 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
     """
 
     def setUp(self):
-        super(EndpointPolicyTestCase, self).setUp()
+        super().setUp()
         self.policy = unit.new_policy_ref()
         PROVIDERS.policy_api.create_policy(self.policy['id'], self.policy)
         self.service = unit.new_service_ref()
         PROVIDERS.catalog_api.create_service(self.service['id'], self.service)
-        self.endpoint = unit.new_endpoint_ref(self.service['id'], enabled=True,
-                                              interface='public',
-                                              region_id=self.region_id)
+        self.endpoint = unit.new_endpoint_ref(
+            self.service['id'],
+            enabled=True,
+            interface='public',
+            region_id=self.region_id,
+        )
         PROVIDERS.catalog_api.create_endpoint(
             self.endpoint['id'], self.endpoint
         )
@@ -58,190 +62,221 @@ class EndpointPolicyTestCase(test_v3.RestfulTestCase):
         # that there is not a false negative after creation.
 
         self.assert_head_and_get_return_same_response(
-            url,
-            expected_status=http_client.NOT_FOUND)
+            url, expected_status=http.client.NOT_FOUND
+        )
 
         self.put(url)
 
         # test that the new resource is accessible.
         self.assert_head_and_get_return_same_response(
-            url,
-            expected_status=http_client.NO_CONTENT)
+            url, expected_status=http.client.NO_CONTENT
+        )
 
         self.delete(url)
 
         # test that the deleted resource is no longer accessible
         self.assert_head_and_get_return_same_response(
-            url,
-            expected_status=http_client.NOT_FOUND)
+            url, expected_status=http.client.NOT_FOUND
+        )
 
     def test_crud_for_policy_for_explicit_endpoint(self):
         """PUT, HEAD and DELETE for explicit endpoint policy."""
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/endpoints/%(endpoint_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'endpoint_id': self.endpoint['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/endpoints/%(endpoint_id)s'
+        ) % {
+            'policy_id': self.policy['id'],
+            'endpoint_id': self.endpoint['id'],
+        }
         self._crud_test(url)
 
     def test_crud_for_policy_for_service(self):
         """PUT, HEAD and DELETE for service endpoint policy."""
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s'
+        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
         self._crud_test(url)
 
     def test_crud_for_policy_for_region_and_service(self):
         """PUT, HEAD and DELETE for region and service endpoint policy."""
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s/regions/%(region_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id'],
-                   'region_id': self.region['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s/regions/%(region_id)s'
+        ) % {
+            'policy_id': self.policy['id'],
+            'service_id': self.service['id'],
+            'region_id': self.region['id'],
+        }
         self._crud_test(url)
 
     def test_get_policy_for_endpoint(self):
         """GET /endpoints/{endpoint_id}/policy."""
-        self.put('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-                 '/endpoints/%(endpoint_id)s' % {
-                     'policy_id': self.policy['id'],
-                     'endpoint_id': self.endpoint['id']})
+        self.put(
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/endpoints/%(endpoint_id)s'
+            % {
+                'policy_id': self.policy['id'],
+                'endpoint_id': self.endpoint['id'],
+            }
+        )
 
-        self.head('/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
-                  '/policy' % {
-                      'endpoint_id': self.endpoint['id']},
-                  expected_status=http_client.OK)
+        self.head(
+            '/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
+            '/policy' % {'endpoint_id': self.endpoint['id']},
+            expected_status=http.client.OK,
+        )
 
-        r = self.get('/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
-                     '/policy' % {
-                         'endpoint_id': self.endpoint['id']})
+        r = self.get(
+            '/endpoints/%(endpoint_id)s/OS-ENDPOINT-POLICY'
+            '/policy' % {'endpoint_id': self.endpoint['id']}
+        )
         self.assertValidPolicyResponse(r, ref=self.policy)
 
     def test_list_endpoints_for_policy(self):
         """GET & HEAD /policies/%(policy_id}/endpoints."""
-        url = (
-            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-            '/endpoints' % {'policy_id': self.policy['id']}
+        url = '/policies/{policy_id}/OS-ENDPOINT-POLICY/endpoints'.format(
+            policy_id=self.policy['id']
         )
         self.put(url + '/' + self.endpoint['id'])
         r = self.get(url)
         self.assertValidEndpointListResponse(r, ref=self.endpoint)
         self.assertThat(r.result.get('endpoints'), matchers.HasLength(1))
-        self.head(url, expected_status=http_client.OK)
+        self.head(url, expected_status=http.client.OK)
 
     def test_endpoint_association_cleanup_when_endpoint_deleted(self):
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/endpoints/%(endpoint_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'endpoint_id': self.endpoint['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/endpoints/%(endpoint_id)s'
+        ) % {
+            'policy_id': self.policy['id'],
+            'endpoint_id': self.endpoint['id'],
+        }
 
         self.put(url)
         self.head(url)
 
-        self.delete('/endpoints/%(endpoint_id)s' % {
-            'endpoint_id': self.endpoint['id']})
+        self.delete(
+            '/endpoints/{endpoint_id}'.format(endpoint_id=self.endpoint['id'])
+        )
 
-        self.head(url, expected_status=http_client.NOT_FOUND)
+        self.head(url, expected_status=http.client.NOT_FOUND)
 
     def test_region_service_association_cleanup_when_region_deleted(self):
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s/regions/%(region_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id'],
-                   'region_id': self.region['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s/regions/%(region_id)s'
+        ) % {
+            'policy_id': self.policy['id'],
+            'service_id': self.service['id'],
+            'region_id': self.region['id'],
+        }
 
         self.put(url)
         self.head(url)
 
-        self.delete('/regions/%(region_id)s' % {
-            'region_id': self.region['id']})
+        self.delete('/regions/{region_id}'.format(region_id=self.region['id']))
 
-        self.head(url, expected_status=http_client.NOT_FOUND)
+        self.head(url, expected_status=http.client.NOT_FOUND)
 
     def test_region_service_association_cleanup_when_service_deleted(self):
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s/regions/%(region_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id'],
-                   'region_id': self.region['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s/regions/%(region_id)s'
+        ) % {
+            'policy_id': self.policy['id'],
+            'service_id': self.service['id'],
+            'region_id': self.region['id'],
+        }
 
         self.put(url)
         self.head(url)
 
-        self.delete('/services/%(service_id)s' % {
-            'service_id': self.service['id']})
+        self.delete(
+            '/services/{service_id}'.format(service_id=self.service['id'])
+        )
 
-        self.head(url, expected_status=http_client.NOT_FOUND)
+        self.head(url, expected_status=http.client.NOT_FOUND)
 
     def test_service_association_cleanup_when_service_deleted(self):
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s'
+        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
 
         self.put(url)
-        self.get(url, expected_status=http_client.NO_CONTENT)
+        self.get(url, expected_status=http.client.NO_CONTENT)
 
-        self.delete('/policies/%(policy_id)s' % {
-            'policy_id': self.policy['id']})
+        self.delete(
+            '/policies/{policy_id}'.format(policy_id=self.policy['id'])
+        )
 
-        self.head(url, expected_status=http_client.NOT_FOUND)
+        self.head(url, expected_status=http.client.NOT_FOUND)
 
     def test_service_association_cleanup_when_policy_deleted(self):
-        url = ('/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
-               '/services/%(service_id)s') % {
-                   'policy_id': self.policy['id'],
-                   'service_id': self.service['id']}
+        url = (
+            '/policies/%(policy_id)s/OS-ENDPOINT-POLICY'
+            '/services/%(service_id)s'
+        ) % {'policy_id': self.policy['id'], 'service_id': self.service['id']}
 
         self.put(url)
-        self.get(url, expected_status=http_client.NO_CONTENT)
+        self.get(url, expected_status=http.client.NO_CONTENT)
 
-        self.delete('/services/%(service_id)s' % {
-            'service_id': self.service['id']})
+        self.delete(
+            '/services/{service_id}'.format(service_id=self.service['id'])
+        )
 
-        self.head(url, expected_status=http_client.NOT_FOUND)
+        self.head(url, expected_status=http.client.NOT_FOUND)
 
 
 class JsonHomeTests(test_v3.JsonHomeTestMixin):
-    EXTENSION_LOCATION = ('https://docs.openstack.org/api/openstack-identity/3'
-                          '/ext/OS-ENDPOINT-POLICY/1.0/rel')
-    PARAM_LOCATION = ('https://docs.openstack.org/api/openstack-identity/3/'
-                      'param')
+    EXTENSION_LOCATION = (
+        'https://docs.openstack.org/api/openstack-identity/3'
+        '/ext/OS-ENDPOINT-POLICY/1.0/rel'
+    )
+    PARAM_LOCATION = (
+        'https://docs.openstack.org/api/openstack-identity/3/param'
+    )
 
     JSON_HOME_DATA = {
-        EXTENSION_LOCATION + '/endpoint_policy': {
+        EXTENSION_LOCATION
+        + '/endpoint_policy': {
             'href-template': '/endpoints/{endpoint_id}/OS-ENDPOINT-POLICY/'
-                             'policy',
+            'policy',
             'href-vars': {
                 'endpoint_id': PARAM_LOCATION + '/endpoint_id',
             },
         },
-        EXTENSION_LOCATION + '/policy_endpoints': {
+        EXTENSION_LOCATION
+        + '/policy_endpoints': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                             'endpoints',
+            'endpoints',
             'href-vars': {
                 'policy_id': PARAM_LOCATION + '/policy_id',
             },
         },
-        EXTENSION_LOCATION + '/endpoint_policy_association': {
+        EXTENSION_LOCATION
+        + '/endpoint_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                             'endpoints/{endpoint_id}',
+            'endpoints/{endpoint_id}',
             'href-vars': {
                 'policy_id': PARAM_LOCATION + '/policy_id',
                 'endpoint_id': PARAM_LOCATION + '/endpoint_id',
             },
         },
-        EXTENSION_LOCATION + '/service_policy_association': {
+        EXTENSION_LOCATION
+        + '/service_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                             'services/{service_id}',
+            'services/{service_id}',
             'href-vars': {
                 'policy_id': PARAM_LOCATION + '/policy_id',
                 'service_id': PARAM_LOCATION + '/service_id',
             },
         },
-        EXTENSION_LOCATION + '/region_and_service_policy_association': {
+        EXTENSION_LOCATION
+        + '/region_and_service_policy_association': {
             'href-template': '/policies/{policy_id}/OS-ENDPOINT-POLICY/'
-                             'services/{service_id}/regions/{region_id}',
+            'services/{service_id}/regions/{region_id}',
             'href-vars': {
                 'policy_id': PARAM_LOCATION + '/policy_id',
                 'service_id': PARAM_LOCATION + '/service_id',
