@@ -10,10 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
+import http.client
 import uuid
 
-import http.client
+from oslo_utils import timeutils
 
 from keystone.common import provider_api
 import keystone.conf
@@ -35,17 +35,21 @@ class TestTrustOperations(test_v3.RestfulTestCase):
     """
 
     def setUp(self):
-        super(TestTrustOperations, self).setUp()
+        super().setUp()
         # create a trustee to delegate stuff to
-        self.trustee_user = unit.create_user(PROVIDERS.identity_api,
-                                             domain_id=self.domain_id)
+        self.trustee_user = unit.create_user(
+            PROVIDERS.identity_api, domain_id=self.domain_id
+        )
         self.trustee_user_id = self.trustee_user['id']
 
     def test_create_trust_bad_request(self):
         # The server returns a 403 Forbidden rather than a 400 Bad Request, see
         # bug 1133435
-        self.post('/OS-TRUST/trusts', body={'trust': {}},
-                  expected_status=http.client.FORBIDDEN)
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': {}},
+            expected_status=http.client.FORBIDDEN,
+        )
 
     def test_create_trust_with_invalid_expiration_fails(self):
         # create a new trust
@@ -53,27 +57,28 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
 
         ref['expires_at'] = 'bad'
         self.post(
             '/OS-TRUST/trusts',
             body={'trust': ref},
-            expected_status=http.client.BAD_REQUEST
+            expected_status=http.client.BAD_REQUEST,
         )
 
         ref['expires_at'] = ''
         self.post(
             '/OS-TRUST/trusts',
             body={'trust': ref},
-            expected_status=http.client.BAD_REQUEST
+            expected_status=http.client.BAD_REQUEST,
         )
 
         ref['expires_at'] = 'Z'
         self.post(
             '/OS-TRUST/trusts',
             body={'trust': ref},
-            expected_status=http.client.BAD_REQUEST
+            expected_status=http.client.BAD_REQUEST,
         )
 
     def test_trusts_do_not_implement_updates(self):
@@ -84,21 +89,26 @@ class TestTrustOperations(test_v3.RestfulTestCase):
                 trustor_user_id=self.user_id,
                 trustee_user_id=self.trustee_user_id,
                 project_id=self.project_id,
-                role_ids=[self.role_id])
-            r = c.post('/v3/OS-TRUST/trusts',
-                       json={'trust': ref},
-                       headers={'X-Auth-Token': token})
+                role_ids=[self.role_id],
+            )
+            r = c.post(
+                '/v3/OS-TRUST/trusts',
+                json={'trust': ref},
+                headers={'X-Auth-Token': token},
+            )
             trust_id = r.json['trust']['id']
             c.patch(
-                '/v3/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust_id},
+                f'/v3/OS-TRUST/trusts/{trust_id}',
                 json={'trust': ref},
                 headers={'X-Auth-Token': token},
-                expected_status_code=http.client.METHOD_NOT_ALLOWED)
+                expected_status_code=http.client.METHOD_NOT_ALLOWED,
+            )
             c.put(
-                '/v3/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust_id},
+                f'/v3/OS-TRUST/trusts/{trust_id}',
                 json={'trust': ref},
                 headers={'X-Auth-Token': token},
-                expected_status_code=http.client.METHOD_NOT_ALLOWED)
+                expected_status_code=http.client.METHOD_NOT_ALLOWED,
+            )
 
     def test_trust_crud(self):
         # create a new trust
@@ -106,30 +116,32 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         r = self.post('/OS-TRUST/trusts', body={'trust': ref})
         trust = self.assertValidTrustResponse(r, ref)
 
         # get the trust
         r = self.get(
-            '/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust['id']})
+            '/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id'])
+        )
         self.assertValidTrustResponse(r, ref)
 
         # validate roles on the trust
         r = self.get(
-            '/OS-TRUST/trusts/%(trust_id)s/roles' % {
-                'trust_id': trust['id']})
+            '/OS-TRUST/trusts/{trust_id}/roles'.format(trust_id=trust['id'])
+        )
         roles = self.assertValidRoleListResponse(r, self.role)
         self.assertIn(self.role['id'], [x['id'] for x in roles])
         self.head(
-            '/OS-TRUST/trusts/%(trust_id)s/roles/%(role_id)s' % {
-                'trust_id': trust['id'],
-                'role_id': self.role['id']},
-            expected_status=http.client.OK)
+            '/OS-TRUST/trusts/%(trust_id)s/roles/%(role_id)s'
+            % {'trust_id': trust['id'], 'role_id': self.role['id']},
+            expected_status=http.client.OK,
+        )
         r = self.get(
-            '/OS-TRUST/trusts/%(trust_id)s/roles/%(role_id)s' % {
-                'trust_id': trust['id'],
-                'role_id': self.role['id']})
+            '/OS-TRUST/trusts/%(trust_id)s/roles/%(role_id)s'
+            % {'trust_id': trust['id'], 'role_id': self.role['id']}
+        )
         self.assertValidRoleResponse(r, self.role)
 
         # list all trusts
@@ -137,13 +149,13 @@ class TestTrustOperations(test_v3.RestfulTestCase):
         self.assertValidTrustListResponse(r, trust)
 
         # delete the trust
-        self.delete(
-            '/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust['id']})
+        self.delete('/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']))
 
         # ensure the trust is not found
         self.get(
-            '/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust['id']},
-            expected_status=http.client.NOT_FOUND)
+            '/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']),
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_list_trusts(self):
         # create three trusts with the same trustor and trustee
@@ -153,10 +165,14 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             expires=dict(minutes=1),
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         for i in range(3):
-            ref['expires_at'] = datetime.datetime.utcnow().replace(
-                year=2032).strftime(unit.TIME_FORMAT)
+            ref['expires_at'] = (
+                timeutils.utcnow()
+                .replace(year=2032)
+                .strftime(unit.TIME_FORMAT)
+            )
             r = self.post('/OS-TRUST/trusts', body={'trust': ref})
             self.assertValidTrustResponse(r, ref)
 
@@ -210,13 +226,13 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             expires='2010-06-04T08:44:31.999999Z',
-            role_ids=[self.role_id]
+            role_ids=[self.role_id],
         )
 
         self.post(
             '/OS-TRUST/trusts',
             body={'trust': ref},
-            expected_status=http.client.BAD_REQUEST
+            expected_status=http.client.BAD_REQUEST,
         )
 
     def test_delete_trust(self):
@@ -227,46 +243,53 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             expires=dict(minutes=1),
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         r = self.post('/OS-TRUST/trusts', body={'trust': ref})
         trust = self.assertValidTrustResponse(r, ref)
 
         # delete the trust
-        self.delete('/OS-TRUST/trusts/%(trust_id)s' % {
-            'trust_id': trust['id']})
+        self.delete('/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']))
 
         # ensure the trust isn't found
-        self.get('/OS-TRUST/trusts/%(trust_id)s' % {
-            'trust_id': trust['id']},
-            expected_status=http.client.NOT_FOUND)
+        self.get(
+            '/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']),
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_create_trust_without_trustee_returns_bad_request(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
 
         # trustee_user_id is required to create a trust
         del ref['trustee_user_id']
 
-        self.post('/OS-TRUST/trusts',
-                  body={'trust': ref},
-                  expected_status=http.client.BAD_REQUEST)
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.BAD_REQUEST,
+        )
 
     def test_create_trust_without_impersonation_returns_bad_request(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
 
         # impersonation is required to create a trust
         del ref['impersonation']
 
-        self.post('/OS-TRUST/trusts',
-                  body={'trust': ref},
-                  expected_status=http.client.BAD_REQUEST)
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.BAD_REQUEST,
+        )
 
     def test_create_trust_with_bad_remaining_uses_returns_bad_request(self):
         # negative numbers, strings, non-integers, and 0 are not value values
@@ -276,82 +299,114 @@ class TestTrustOperations(test_v3.RestfulTestCase):
                 trustee_user_id=self.trustee_user_id,
                 project_id=self.project_id,
                 remaining_uses=value,
-                role_ids=[self.role_id])
-            self.post('/OS-TRUST/trusts',
-                      body={'trust': ref},
-                      expected_status=http.client.BAD_REQUEST)
+                role_ids=[self.role_id],
+            )
+            self.post(
+                '/OS-TRUST/trusts',
+                body={'trust': ref},
+                expected_status=http.client.BAD_REQUEST,
+            )
 
     def test_create_trust_with_non_existant_trustee_returns_not_found(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=uuid.uuid4().hex,
             project_id=self.project_id,
-            role_ids=[self.role_id])
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.NOT_FOUND)
+            role_ids=[self.role_id],
+        )
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_create_trust_with_trustee_as_trustor_returns_forbidden(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.trustee_user_id,
             trustee_user_id=self.user_id,
             project_id=self.project_id,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         # NOTE(lbragstad): This fails because the user making the request isn't
         # the trustor defined in the request.
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.FORBIDDEN)
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.FORBIDDEN,
+        )
 
     def test_create_trust_with_non_existant_project_returns_not_found(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=uuid.uuid4().hex,
-            role_ids=[self.role_id])
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.NOT_FOUND)
+            role_ids=[self.role_id],
+        )
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_create_trust_with_non_existant_role_id_returns_not_found(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_ids=[uuid.uuid4().hex])
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.NOT_FOUND)
+            role_ids=[uuid.uuid4().hex],
+        )
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_create_trust_with_extra_attributes_fails(self):
-        ref = unit.new_trust_ref(trustor_user_id=self.user_id,
-                                 trustee_user_id=self.trustee_user_id,
-                                 project_id=self.project_id,
-                                 role_ids=[self.role_id])
+        ref = unit.new_trust_ref(
+            trustor_user_id=self.user_id,
+            trustee_user_id=self.trustee_user_id,
+            project_id=self.project_id,
+            role_ids=[self.role_id],
+        )
         ref['roles'].append({'fake_key': 'fake_value'})
 
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.BAD_REQUEST)
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.BAD_REQUEST,
+        )
 
     def test_create_trust_with_non_existant_role_name_returns_not_found(self):
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_names=[uuid.uuid4().hex])
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.NOT_FOUND)
+            role_names=[uuid.uuid4().hex],
+        )
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.NOT_FOUND,
+        )
 
     def test_create_trust_with_role_name_ambiguous_returns_bad_request(self):
         # Create second role with the same name
-        role_ref = unit.new_role_ref(name=self.role['name'],
-                                     domain_id=uuid.uuid4().hex)
+        role_ref = unit.new_role_ref(
+            name=self.role['name'], domain_id=uuid.uuid4().hex
+        )
         self.post('/roles', body={'role': role_ref})
 
         ref = unit.new_trust_ref(
             trustor_user_id=self.user_id,
             trustee_user_id=self.trustee_user_id,
             project_id=self.project_id,
-            role_names=[self.role['name']]
+            role_names=[self.role['name']],
+        )
+        self.post(
+            '/OS-TRUST/trusts',
+            body={'trust': ref},
+            expected_status=http.client.BAD_REQUEST,
         )
-        self.post('/OS-TRUST/trusts', body={'trust': ref},
-                  expected_status=http.client.BAD_REQUEST)
 
     def test_exercise_trust_scoped_token_without_impersonation(self):
         # create a new trust
@@ -361,7 +416,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             expires=dict(minutes=1),
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         resp = self.post('/OS-TRUST/trusts', body={'trust': ref})
         trust = self.assertValidTrustResponse(resp)
 
@@ -369,17 +425,18 @@ class TestTrustOperations(test_v3.RestfulTestCase):
         auth_data = self.build_authentication_request(
             user_id=self.trustee_user['id'],
             password=self.trustee_user['password'],
-            trust_id=trust['id'])
+            trust_id=trust['id'],
+        )
         resp = self.v3_create_token(auth_data)
         resp_body = resp.json_body['token']
 
-        self.assertValidProjectScopedTokenResponse(resp,
-                                                   self.trustee_user)
+        self.assertValidProjectScopedTokenResponse(resp, self.trustee_user)
         self.assertEqual(self.trustee_user['id'], resp_body['user']['id'])
         self.assertEqual(self.trustee_user['name'], resp_body['user']['name'])
         self.assertEqual(self.domain['id'], resp_body['user']['domain']['id'])
-        self.assertEqual(self.domain['name'],
-                         resp_body['user']['domain']['name'])
+        self.assertEqual(
+            self.domain['name'], resp_body['user']['domain']['name']
+        )
         self.assertEqual(self.project['id'], resp_body['project']['id'])
         self.assertEqual(self.project['name'], resp_body['project']['name'])
 
@@ -391,7 +448,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=True,
             expires=dict(minutes=1),
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         resp = self.post('/OS-TRUST/trusts', body={'trust': ref})
         trust = self.assertValidTrustResponse(resp)
 
@@ -399,7 +457,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
         auth_data = self.build_authentication_request(
             user_id=self.trustee_user['id'],
             password=self.trustee_user['password'],
-            trust_id=trust['id'])
+            trust_id=trust['id'],
+        )
         resp = self.v3_create_token(auth_data)
         resp_body = resp.json_body['token']
 
@@ -407,8 +466,9 @@ class TestTrustOperations(test_v3.RestfulTestCase):
         self.assertEqual(self.user['id'], resp_body['user']['id'])
         self.assertEqual(self.user['name'], resp_body['user']['name'])
         self.assertEqual(self.domain['id'], resp_body['user']['domain']['id'])
-        self.assertEqual(self.domain['name'],
-                         resp_body['user']['domain']['name'])
+        self.assertEqual(
+            self.domain['name'], resp_body['user']['domain']['name']
+        )
         self.assertEqual(self.project['id'], resp_body['project']['id'])
         self.assertEqual(self.project['name'], resp_body['project']['name'])
 
@@ -425,7 +485,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             role_ids=[self.role_id],
-            allow_redelegation=True)
+            allow_redelegation=True,
+        )
         resp = self.post('/OS-TRUST/trusts', body={'trust': ref})
 
         trust = self.assertValidTrustResponse(resp)
@@ -433,13 +494,15 @@ class TestTrustOperations(test_v3.RestfulTestCase):
         auth_data = self.build_authentication_request(
             user_id=self.trustee_user_id,
             password=self.trustee_user['password'],
-            trust_id=trust['id'])
+            trust_id=trust['id'],
+        )
         resp = self.v3_create_token(auth_data)
 
         # create third-party user, which will be trustee in trust created from
         # redelegated trust
-        third_party_trustee = unit.create_user(PROVIDERS.identity_api,
-                                               domain_id=self.domain_id)
+        third_party_trustee = unit.create_user(
+            PROVIDERS.identity_api, domain_id=self.domain_id
+        )
         third_party_trustee_id = third_party_trustee['id']
 
         # create trust from redelegated trust
@@ -448,13 +511,16 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             trustee_user_id=third_party_trustee_id,
             project_id=self.project_id,
             impersonation=True,
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         ref['redelegated_trust_id'] = trust['id']
-        self.admin_request(path='/v3/OS-TRUST/trusts',
-                           body={'trust': ref},
-                           token=resp.headers.get('X-Subject-Token'),
-                           method='POST',
-                           expected_status=http.client.FORBIDDEN)
+        self.admin_request(
+            path='/v3/OS-TRUST/trusts',
+            body={'trust': ref},
+            token=resp.headers.get('X-Subject-Token'),
+            method='POST',
+            expected_status=http.client.FORBIDDEN,
+        )
 
     def test_trust_deleted_when_user_deleted(self):
         # create trust
@@ -464,7 +530,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             role_ids=[self.role_id],
-            allow_redelegation=True)
+            allow_redelegation=True,
+        )
         resp = self.post('/OS-TRUST/trusts', body={'trust': ref})
 
         trust = self.assertValidTrustResponse(resp)
@@ -475,15 +542,18 @@ class TestTrustOperations(test_v3.RestfulTestCase):
 
         # delete the trustee will delete the trust
         self.delete(
-            '/users/%(user_id)s' % {'user_id': trust['trustee_user_id']})
+            '/users/{user_id}'.format(user_id=trust['trustee_user_id'])
+        )
 
         self.get(
-            '/OS-TRUST/trusts/%(trust_id)s' % {'trust_id': trust['id']},
-            expected_status=http.client.NOT_FOUND)
+            '/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']),
+            expected_status=http.client.NOT_FOUND,
+        )
 
         # create another user as the new trustee
-        trustee_user = unit.create_user(PROVIDERS.identity_api,
-                                        domain_id=self.domain_id)
+        trustee_user = unit.create_user(
+            PROVIDERS.identity_api, domain_id=self.domain_id
+        )
         trustee_user_id = trustee_user['id']
         # create the trust again
         ref['trustee_user_id'] = trustee_user_id
@@ -495,13 +565,14 @@ class TestTrustOperations(test_v3.RestfulTestCase):
 
         # delete the trustor will delete the trust
         self.delete(
-            '/users/%(user_id)s' % {'user_id': trust['trustor_user_id']})
+            '/users/{user_id}'.format(user_id=trust['trustor_user_id'])
+        )
 
         # call the backend method directly to bypass authentication since the
         # user has been deleted.
-        self.assertRaises(exception.TrustNotFound,
-                          PROVIDERS.trust_api.get_trust,
-                          trust['id'])
+        self.assertRaises(
+            exception.TrustNotFound, PROVIDERS.trust_api.get_trust, trust['id']
+        )
 
     def test_trust_deleted_when_project_deleted(self):
         # create trust
@@ -511,7 +582,8 @@ class TestTrustOperations(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             role_ids=[self.role_id],
-            allow_redelegation=True)
+            allow_redelegation=True,
+        )
         resp = self.post('/OS-TRUST/trusts', body={'trust': ref})
 
         trust = self.assertValidTrustResponse(resp)
@@ -522,27 +594,30 @@ class TestTrustOperations(test_v3.RestfulTestCase):
 
         # delete the project will delete the trust.
         self.delete(
-            '/projects/%(project_id)s' % {'project_id': trust['project_id']})
+            '/projects/{project_id}'.format(project_id=trust['project_id'])
+        )
 
         # call the backend method directly to bypass authentication since the
         # user no longer has the assignment on the project.
-        self.assertRaises(exception.TrustNotFound,
-                          PROVIDERS.trust_api.get_trust,
-                          trust['id'])
+        self.assertRaises(
+            exception.TrustNotFound, PROVIDERS.trust_api.get_trust, trust['id']
+        )
 
 
 class TrustsWithApplicationCredentials(test_v3.RestfulTestCase):
 
     def setUp(self):
-        super(TrustsWithApplicationCredentials, self).setUp()
-        self.trustee_user = unit.create_user(PROVIDERS.identity_api,
-                                             domain_id=self.domain_id)
+        super().setUp()
+        self.trustee_user = unit.create_user(
+            PROVIDERS.identity_api, domain_id=self.domain_id
+        )
         self.trustee_user_id = self.trustee_user['id']
 
     def config_overrides(self):
-        super(TrustsWithApplicationCredentials, self).config_overrides()
-        self.config_fixture.config(group='auth',
-                                   methods='password,application_credential')
+        super().config_overrides()
+        self.config_fixture.config(
+            group='auth', methods='password,application_credential'
+        )
 
     def test_create_trust_with_application_credential(self):
         app_cred = {
@@ -551,23 +626,28 @@ class TrustsWithApplicationCredentials(test_v3.RestfulTestCase):
             'project_id': self.project_id,
             'name': uuid.uuid4().hex,
             'roles': [{'id': self.role_id}],
-            'secret': uuid.uuid4().hex
+            'secret': uuid.uuid4().hex,
         }
         app_cred_api = PROVIDERS.application_credential_api
         app_cred_api.create_application_credential(app_cred)
         auth_data = self.build_authentication_request(
-            app_cred_id=app_cred['id'], secret=app_cred['secret'])
-        token_data = self.v3_create_token(auth_data,
-                                          expected_status=http.client.CREATED)
-        trust_body = unit.new_trust_ref(trustor_user_id=self.user_id,
-                                        trustee_user_id=self.trustee_user_id,
-                                        project_id=self.project_id,
-                                        role_ids=[self.role_id])
+            app_cred_id=app_cred['id'], secret=app_cred['secret']
+        )
+        token_data = self.v3_create_token(
+            auth_data, expected_status=http.client.CREATED
+        )
+        trust_body = unit.new_trust_ref(
+            trustor_user_id=self.user_id,
+            trustee_user_id=self.trustee_user_id,
+            project_id=self.project_id,
+            role_ids=[self.role_id],
+        )
         self.post(
             path='/OS-TRUST/trusts',
             body={'trust': trust_body},
             token=token_data.headers['x-subject-token'],
-            expected_status=http.client.FORBIDDEN)
+            expected_status=http.client.FORBIDDEN,
+        )
 
     def test_delete_trust_with_application_credential(self):
         ref = unit.new_trust_ref(
@@ -576,7 +656,8 @@ class TrustsWithApplicationCredentials(test_v3.RestfulTestCase):
             project_id=self.project_id,
             impersonation=False,
             expires=dict(minutes=1),
-            role_ids=[self.role_id])
+            role_ids=[self.role_id],
+        )
         r = self.post('/OS-TRUST/trusts', body={'trust': ref})
         trust = self.assertValidTrustResponse(r, ref)
 
@@ -586,16 +667,19 @@ class TrustsWithApplicationCredentials(test_v3.RestfulTestCase):
             'project_id': self.project_id,
             'name': uuid.uuid4().hex,
             'roles': [{'id': self.role_id}],
-            'secret': uuid.uuid4().hex
+            'secret': uuid.uuid4().hex,
         }
         app_cred_api = PROVIDERS.application_credential_api
         app_cred_api.create_application_credential(app_cred)
         auth_data = self.build_authentication_request(
-            app_cred_id=app_cred['id'], secret=app_cred['secret'])
-        token_data = self.v3_create_token(auth_data,
-                                          expected_status=http.client.CREATED)
+            app_cred_id=app_cred['id'], secret=app_cred['secret']
+        )
+        token_data = self.v3_create_token(
+            auth_data, expected_status=http.client.CREATED
+        )
         # delete the trust
-        self.delete(path='/OS-TRUST/trusts/%(trust_id)s' % {
-            'trust_id': trust['id']},
+        self.delete(
+            path='/OS-TRUST/trusts/{trust_id}'.format(trust_id=trust['id']),
             token=token_data.headers['x-subject-token'],
-            expected_status=http.client.FORBIDDEN)
+            expected_status=http.client.FORBIDDEN,
+        )
